/* Sistemas Integrados TECNISA
   Financeiro

Nome: 1040_RECSTP_INCLUI_ERRCNABR.SQL

Descrio:
Stored procedure auxiliar para preenchimento da tabela ERRCNABR.

P_CDBANCCNAB - Cdigo oficial do banco
P_CDERRCNABR - Cdigo do erro
P_DSERRCNABR - Descrio do erro

 Criao:
 18/03/02 - Jenilson Ferreira
*/

IF EXISTS (SELECT
              *
           FROM SYSOBJECTS O, SYSUSERS U
           WHERE
              O.NAME = 'INCLUI_ERRCNABR' AND
              TYPE   = 'P'               AND
              U.UID  = O.UID             AND
              U.NAME = USER)

DROP PROCEDURE INCLUI_ERRCNABR
GO

CREATE PROCEDURE INCLUI_ERRCNABR
   @P_CDBANCCNAB VARCHAR(03),
   @P_CDERRCNABR VARCHAR(10),
   @P_DSERRCNABR VARCHAR(200)
AS
   DECLARE @V_ACHOU   INTEGER;
   DECLARE @V_CDBANCO VARCHAR(03);

BEGIN
   SELECT
      @V_ACHOU = COUNT(*)
   FROM
      ERRCNABR ER, BANCO BA
   WHERE
      (ER.CDBANCO    = BA.CDBANCO)    AND
      (BA.CDBANCCNAB = @P_CDBANCCNAB) AND
      (ER.CDERRCNABR = @P_CDERRCNABR);
   IF @V_ACHOU = 0 BEGIN
      SELECT
         @V_CDBANCO = MAX(CDBANCO)
      FROM
         BANCO
      WHERE
         (CDBANCCNAB = @P_CDBANCCNAB);
      IF NOT @V_CDBANCO IS NULL BEGIN
         INSERT INTO ERRCNABR (CDBANCO, CDERRCNABR, DSERRCNABR) VALUES (@V_CDBANCO, @P_CDERRCNABR, @P_DSERRCNABR);
      END;
   END;
END;
GO

-- BANCO BRADESCO 237

   EXEC INCLUI_ERRCNABR '237', '0200', '[ENTRADA CONFIRMADA] OCORRNCIA ACEITA';
   EXEC INCLUI_ERRCNABR '237', '0217', '[ENTRADA CONFIRMADA] DATA VENCIMENTO ANTERIOR A DATA DE EMISSO';
   EXEC INCLUI_ERRCNABR '237', '0221', '[ENTRADA CONFIRMADA] ESPCIE DO TTULO INVLIDO';
   EXEC INCLUI_ERRCNABR '237', '0224', '[ENTRADA CONFIRMADA] DATA DA EMISSO INVLIDA';
   EXEC INCLUI_ERRCNABR '237', '0238', '[ENTRADA CONFIRMADA] PRAZO PARA PROTESTO INVLIDO';
   EXEC INCLUI_ERRCNABR '237', '0239', '[ENTRADA CONFIRMADA] PEDIDO P.PROTESTO NO PERMITIDO PARA O TTULO';
   EXEC INCLUI_ERRCNABR '237', '0243', '[ENTRADA CONFIRMADA] PRAZO PARA BAIXA DEVOLUO INVLIDO';
   EXEC INCLUI_ERRCNABR '237', '0245', '[ENTRADA CONFIRMADA] NOME DO SACADO INVALIDO';
   EXEC INCLUI_ERRCNABR '237', '0246', '[ENTRADA CONFIRMADA] TIPO/NUM. DE INSCRIO DO SACADO INVLIDOS';
   EXEC INCLUI_ERRCNABR '237', '0247', '[ENTRADA CONFIRMADA] ENDEREO DO SACADO INVLIDO';
   EXEC INCLUI_ERRCNABR '237', '0248', '[ENTRADA CONFIRMADA] CEP INVLIDO';
   EXEC INCLUI_ERRCNABR '237', '0250', '[ENTRADA CONFIRMADA] CEP REFERENTE A BANCO CORRESPONDENTE';
   EXEC INCLUI_ERRCNABR '237', '0253', '[ENTRADA CONFIRMADA] N INCR. SACADOR/AVALISTA INVLIDOS (CNPJ/CPF)';
   EXEC INCLUI_ERRCNABR '237', '0254', '[ENTRADA CONFIRMADA] SACADOR/AVALISTA NO INFORMADO';
   EXEC INCLUI_ERRCNABR '237', '0267', '[ENTRADA CONFIRMADA] DB. AUTOMTICO AGENDADO';
   EXEC INCLUI_ERRCNABR '237', '0268', '[ENTRADA CONFIRMADA] DB. NO AGENDADO ERRO NOS DADOS DE REMESSA';
   EXEC INCLUI_ERRCNABR '237', '0269', '[ENTRADA CONFIRMADA] DB. NO AGENDADO - SACADO NO CONSTA NO CAD. AUTORIZANTE';
   EXEC INCLUI_ERRCNABR '237', '0270', '[ENTRADA CONFIRMADA] DB. NO AGENDADO - CEDENTE NO AUTORIZADO PELO SACADO';
   EXEC INCLUI_ERRCNABR '237', '0271', '[ENTRADA CONFIRMADA] DB. NO AGENDADO - CEDENTE NO CADASTRADO P/ DBITO AUTOMTICO';
   EXEC INCLUI_ERRCNABR '237', '0272', '[ENTRADA CONFIRMADA] DB. NO AGENDADO - CDIGO DE MOEDA DIFERENTE DE R$';
   EXEC INCLUI_ERRCNABR '237', '0273', '[ENTRADA CONFIRMADA] DB. NO AGENDADO - DATA DE VENCIMENTO INVLIDA';
   EXEC INCLUI_ERRCNABR '237', '0275', '[ENTRADA CONFIRMADA] DB. NO AGENDADO - TIPO NMERO DE INSCRIO DO DEBITADO INVLIDO';
   EXEC INCLUI_ERRCNABR '237', '0286', '[ENTRADA CONFIRMADA] SEU NMERO INVLIDO';
   EXEC INCLUI_ERRCNABR '237', '0302', '[ENTRADA REJEITADA] CDIGO DO REGISTRO DETALHE INVLIDO';
   EXEC INCLUI_ERRCNABR '237', '0303', '[ENTRADA REJEITADA] CDIGO DA OCORRNCIA INVLIDO';
   EXEC INCLUI_ERRCNABR '237', '0304', '[ENTRADA REJEITADA] CD. DA OCORR. NO PERMITIDA P/A CARTEIRA';
   EXEC INCLUI_ERRCNABR '237', '0305', '[ENTRADA REJEITADA] CD. DA OCORRNCIA NO NUMRICA';
   EXEC INCLUI_ERRCNABR '237', '0308', '[ENTRADA REJEITADA] NOSSO NMERO INVLIDO';
   EXEC INCLUI_ERRCNABR '237', '0309', '[ENTRADA REJEITADA] NOSSO NMERO DUPLICADO';
   EXEC INCLUI_ERRCNABR '237', '0310', '[ENTRADA REJEITADA] CARTEIRA INVLIDA';
   EXEC INCLUI_ERRCNABR '237', '0316', '[ENTRADA REJEITADA] DATA DE VENCIMENTO INVLIDA';
   EXEC INCLUI_ERRCNABR '237', '0318', '[ENTRADA REJEITADA] VENCIMENTO FORA DO PRAZO DE OPERAO';
   EXEC INCLUI_ERRCNABR '237', '0320', '[ENTRADA REJEITADA] VALOR DO TTULO INVLIDO';
   EXEC INCLUI_ERRCNABR '237', '0321', '[ENTRADA REJEITADA] ESPCIE DO TTULO INVLIDA';
   EXEC INCLUI_ERRCNABR '237', '0322', '[ENTRADA REJEITADA] ESPCIE NO PERMITIDA P/ CARTEIRA';
   EXEC INCLUI_ERRCNABR '237', '0324', '[ENTRADA REJEITADA] DATA DE EMISSO INVLIDA';
   EXEC INCLUI_ERRCNABR '237', '0350', '[ENTRADA REJEITADA] CEP REFERENTE A BANCO CORRESPONDENTE';
   EXEC INCLUI_ERRCNABR '237', '0363', '[ENTRADA REJEITADA] ENTRADA P/TTULO J CADASTRADO';
   EXEC INCLUI_ERRCNABR '237', '0368', '[ENTRADA REJEITADA] DB. NO AGENDADO - ERRO NOS DADOS DE REMESSA';
   EXEC INCLUI_ERRCNABR '237', '0369', '[ENTRADA REJEITADA] DB. NO AGENDADO - SACADO NO CONSTA NO CAD. DE AUTORIZANTE';
   EXEC INCLUI_ERRCNABR '237', '0370', '[ENTRADA REJEITADA] DB. NO AGENDADO - CEDENTE NO AUTORIZADO PELO SACADO';
   EXEC INCLUI_ERRCNABR '237', '0371', '[ENTRADA REJEITADA] DB. NO AGENDADO - CEDENTE NO CADASTRADO P/ DBITO AUTOMTICO';
   EXEC INCLUI_ERRCNABR '237', '0372', '[ENTRADA REJEITADA] DB. NO AGENDADO - CDIGO DE MOEDA DIFERENTE DE R$';
   EXEC INCLUI_ERRCNABR '237', '0373', '[ENTRADA REJEITADA] DB. NO AGENDADO - DATA DE VENCIMENTO INVLIDA';
   EXEC INCLUI_ERRCNABR '237', '0374', '[ENTRADA REJEITADA] DB. NO AGENDADO, CONFORME SEU PEDIDO, TTULO NO REGISTRADO';
   EXEC INCLUI_ERRCNABR '237', '0375', '[ENTRADA REJEITADA] DB. NO AGENDADO - TIPO NMERO DE INSCRIO DO DEBITADO INVLIDO';
   EXEC INCLUI_ERRCNABR '237', '06  ', '[LIQUIDAO NORMAL] SEM MOTIVO';
   EXEC INCLUI_ERRCNABR '237', '0910', '[BAIXADO AUT. VIA ARQUIVO] BAIXA COMANDADA PELO CLIENTE';
   EXEC INCLUI_ERRCNABR '237', '1000', '[BAIXADO CONF. INST. AG.] BAIXA COMANDADA';
   EXEC INCLUI_ERRCNABR '237', '1014', '[BAIXADO CONF. INST. AG.] TTULO  PROTESTADO';
   EXEC INCLUI_ERRCNABR '237', '1015', '[BAIXADO CONF. INST. AG.] TTULO EXCLUDO';
   EXEC INCLUI_ERRCNABR '237', '11  ', '[EM SER (TTULO PENDENTE)] SEM MOTIVO';
   EXEC INCLUI_ERRCNABR '237', '12  ', '[ABATIMENTO CONCEDIDO] -SEM MOTIVO';
   EXEC INCLUI_ERRCNABR '237', '13  ', '[ABATIMENTO CANCELADO] SEM MOTIVO';
   EXEC INCLUI_ERRCNABR '237', '14  ', '[VENCIMENTO ALTERADO] SEM MOTIVO';
   EXEC INCLUI_ERRCNABR '237', '15  ', '[LIQUIDAO EM CARTRIO] SEM MOTIVO';
   EXEC INCLUI_ERRCNABR '237', '17  ', '[LIQUIDAO APS BAIXA] SEM MOTIVO';
   EXEC INCLUI_ERRCNABR '237', '18  ', '[ACERTO DE DEPOSITRIA] SEM MOTIVO';
   EXEC INCLUI_ERRCNABR '237', '19  ', '[CONF.RECEB.INST. PROTESTO ] SEM MOTIVO';
   EXEC INCLUI_ERRCNABR '237', '20  ', '[CONF.RECEB.INST.SUST.PROT.] SEM MOTIVO';
   EXEC INCLUI_ERRCNABR '237', '21  ', '[ACERTO CONT. PARTICIPANTE] SEM MOTIVO';
   EXEC INCLUI_ERRCNABR '237', '23  ', '[ENTRADA TTULO EM CARTRIO] SEM MOTIVO';
   EXEC INCLUI_ERRCNABR '237', '2448', '[ENTRADA REJEITADA] CEP INVLIDO';
   EXEC INCLUI_ERRCNABR '237', '2707', '[BAIXA REJEITADA] AGNCIA/CONTA/DV. INVLIDO';
   EXEC INCLUI_ERRCNABR '237', '2708', '[BAIXA REJEITADA] NOSSO NMERO INVLIDO';
   EXEC INCLUI_ERRCNABR '237', '2710', '[BAIXA REJEITADA] CARTEIRA INVLIDA';
   EXEC INCLUI_ERRCNABR '237', '2715', '[BAIXA REJEITADA] CARTEIRA/AG./CONTA/NUM. INVLIDOS';
   EXEC INCLUI_ERRCNABR '237', '2740', '[BAIXA REJEITADA] TTULO COM ORDEM DE PROTESTO';
   EXEC INCLUI_ERRCNABR '237', '2742', '[BAIXA REJEITADA] CDIGO P/BAIXA/DEV; VIA TELEB. INVLIDO';
   EXEC INCLUI_ERRCNABR '237', '2760', '[BAIXA REJEITADA] MOVIMENTO P/TTULO NO CADASTRADO';
   EXEC INCLUI_ERRCNABR '237', '2803', '[DB. DE TARIFAS/CUSTOS] TARIFA DE SUSTAO(valor informado-posio 176  188)';
   EXEC INCLUI_ERRCNABR '237', '2808', '[DB. DE TARIFAS/CUSTOS] CUSTAS DE PROTESTO(valor informado-posio 189  201)';
   EXEC INCLUI_ERRCNABR '237', '2804', '[DB. DE TARIFAS/CUSTOS] TARIFA DE PROTESTO (valor informado-posio 176  188)';
   EXEC INCLUI_ERRCNABR '237', '3001', '[ALTERAO/DADOS REJEITADOS] CDIGO DO BANCO INVLIDO';
   EXEC INCLUI_ERRCNABR '237', '3004', '[ALTERAO/DADOS REJEITADOS] CDIGO DE OCORRNCIA NO PERMITIDO PARA CARTEIRA';
   EXEC INCLUI_ERRCNABR '237', '3005', '[ALTERAO/DADOS REJEITADOS] CDIGO DA OCORRNCIA NO NUMRICO';
   EXEC INCLUI_ERRCNABR '237', '3008', '[ALTERAO/DADOS REJEITADOS] NOSSO NMERO INVLIDO';
   EXEC INCLUI_ERRCNABR '237', '3015', '[ALTERAO/DADOS REJEITADOS] CARACTERSTICAS  DA COBRANA INCOMPATVEIS';
   EXEC INCLUI_ERRCNABR '237', '3016', '[ALTERAO/DADOS REJEITADOS] DATA DE VENCIMENTO INVLIDA';
   EXEC INCLUI_ERRCNABR '237', '3017', '[ALTERAO/DADOS REJEITADOS] DATA DE VENCIMENTO ANTERIOR A DATA DE EMISSO';
   EXEC INCLUI_ERRCNABR '237', '3018', '[ALTERAO/DADOS REJEITADOS] VENCIMENTO FORA DO PRAZO DE OPERAO';
   EXEC INCLUI_ERRCNABR '237', '3024', '[ALTERAO/DADOS REJEITADOS] DATA DA EMISSO INVLIDA';
   EXEC INCLUI_ERRCNABR '237', '3029', '[ALTERAO/DADOS REJEITADOS] VALOR DESC. MAIOR/IGUAL AO VALOR DO TTULO';
   EXEC INCLUI_ERRCNABR '237', '3030', '[ALTERAO/DADOS REJEITADOS] DESCONTO A CONCEDER NO CONFERE';
   EXEC INCLUI_ERRCNABR '237', '3031', '[ALTERAO/DADOS REJEITADOS] CONCESSO DE DESCONTO J EXISTENTE - DESCONTO ANTERIOR';
   EXEC INCLUI_ERRCNABR '237', '3033', '[ALTERAO/DADOS REJEITADOS] VALOR DO ABATIMENTO INVLIDO';
   EXEC INCLUI_ERRCNABR '237', '3034', '[ALTERAO/DADOS REJEITADOS] VALOR ABAT. MAIOR/IGUAL VALOR DO TTULO';
   EXEC INCLUI_ERRCNABR '237', '3038', '[ALTERAO/DADOS REJEITADOS] PRAZO PARA PROTESTO INVLIDO';
   EXEC INCLUI_ERRCNABR '237', '3039', '[ALTERAO/DADOS REJEITADOS] PEDIDO DE PROTESTO NO PERMITIDO PARA O TTULO';
   EXEC INCLUI_ERRCNABR '237', '3040', '[ALTERAO/DADOS REJEITADOS] TTULO COM ORDEM DE PROTESTO EMITIDO';
   EXEC INCLUI_ERRCNABR '237', '3042', '[ALTERAO/DADOS REJEITADOS] CDIGO PARA BAIXA/DEVOLUO INVLIDO';
   EXEC INCLUI_ERRCNABR '237', '3060', '[ALTERAO/DADOS REJEITADOS] MOVIMENTO PARA TTULO NO CADASTRADO';
   EXEC INCLUI_ERRCNABR '237', '3085', '[ALTERAO/DADOS REJEITADOS] TTULO COM PAGAMENTO VINCULADO';
   EXEC INCLUI_ERRCNABR '237', '3201', '[INSTRUO REJEITADA] CDIGO DO BANCO INVLIDO';
   EXEC INCLUI_ERRCNABR '237', '3204', '[INSTRUO REJEITADA] CDIGO DE OCORRNCIA NO PERMITIDO PARA A CARTEIRA';
   EXEC INCLUI_ERRCNABR '237', '3215', '[INSTRUO REJEITADA] CARACTERSTICAS DA COBRANA INCOMPATVEIS';
   EXEC INCLUI_ERRCNABR '237', '3216', '[INSTRUO REJEITADA] DATA DE VENCIMENTO INVLIDA';
   EXEC INCLUI_ERRCNABR '237', '3217', '[INSTRUO REJEITADA] DATA DE VENCIMENTO ANTERIOR A DATA DE EMISSO';
   EXEC INCLUI_ERRCNABR '237', '3218', '[INSTRUO REJEITADA] VENCIMENTO FORA DO PRAZO DE OPERAO';
   EXEC INCLUI_ERRCNABR '237', '3220', '[INSTRUO REJEITADA] VALOR DO TTULO INVLIDO';
   EXEC INCLUI_ERRCNABR '237', '3221', '[INSTRUO REJEITADA] ESPCIE DO TTULO INVLIDA';
   EXEC INCLUI_ERRCNABR '237', '3223', '[INSTRUO REJEITADA] ACEITE INVLIDO';
   EXEC INCLUI_ERRCNABR '237', '3224', '[INSTRUO REJEITADA] DATA DE EMISSO INVLIDA';
   EXEC INCLUI_ERRCNABR '237', '3228', '[INSTRUO REJEITADA] CDIGO DO DESCONTO INVLIDO';
   EXEC INCLUI_ERRCNABR '237', '3229', '[INSTRUO REJEITADA] VALOR DO DESCONTO MAIOR/IGUAL AO VALOR DO TITULO';
   EXEC INCLUI_ERRCNABR '237', '3230', '[INSTRUO REJEITADA] DESCONTO A CONCEDER NO CONFERE';
   EXEC INCLUI_ERRCNABR '237', '3231', '[INSTRUO REJEITADA] CONCESSO DE DESCONTO-J EXISTE DESCONTO ANTERIOR';
   EXEC INCLUI_ERRCNABR '237', '3233', '[INSTRUO REJEITADA] VALOR DO ABATIMENTO INVLIDO';
   EXEC INCLUI_ERRCNABR '237', '3234', '[INSTRUO REJEITADA] VALOR DO ABATIMENTO MAIOR/IGUAL AO VALOR ANTERIOR';
   EXEC INCLUI_ERRCNABR '237', '3236', '[INSTRUO REJEITADA] CONCESSO DE ABATIMENTO-J EXISTE ABATIMENTO ANTERIOR';
   EXEC INCLUI_ERRCNABR '237', '3238', '[INSTRUO REJEITADA] PRAZO PARA PROTESTO INVLIDO';
   EXEC INCLUI_ERRCNABR '237', '3239', '[INSTRUO REJEITADA] PEDIDO DE PROTESTO NO PERMITIDO PARA O TTULO';
   EXEC INCLUI_ERRCNABR '237', '3240', '[INSTRUO REJEITADA] TTULO COM ORDEM DE PROTESTO EMITIDO';
   EXEC INCLUI_ERRCNABR '237', '3241', '[INSTRUO REJEITADA] PEDIDO DE CANCELAMENTO P/ TTULOS S/INSTRUO PROTESTO';
   EXEC INCLUI_ERRCNABR '237', '3242', '[INSTRUO REJEITADA] CDIGO PARA BAIXA/DEVOLUO INVLIDO';
   EXEC INCLUI_ERRCNABR '237', '3245', '[INSTRUO REJEITADA] NOME DO SACADO NO INFORMADO';
   EXEC INCLUI_ERRCNABR '237', '3246', '[INSTRUO REJEITADA] TIPO/NMERO DE INCRIO DO SACADO INVLIDOS';
   EXEC INCLUI_ERRCNABR '237', '3247', '[INSTRUO REJEITADA] ENDEREO DO SACADO NO INFORMADO';
   EXEC INCLUI_ERRCNABR '237', '3248', '[INSTRUO REJEITADA] CEP INVLIDO';
   EXEC INCLUI_ERRCNABR '237', '3250', '[INSTRUO REJEITADA] CEP REFERENTE A BANCO CORRESPONDENTE';
   EXEC INCLUI_ERRCNABR '237', '3253', '[INSTRUO REJEITADA] TIPO/NMERO DE INSCRIO DO SACADOR AVALISTA INVLIDOS';
   EXEC INCLUI_ERRCNABR '237', '3260', '[INSTRUO REJEITADA] MOVIMENTO PARA TTULO NO CADASTRADO';
   EXEC INCLUI_ERRCNABR '237', '3285', '[INSTRUO REJEITADA] TTULO COM PAGAMENTO VINCULADO';
   EXEC INCLUI_ERRCNABR '237', '3286', '[INSTRUO REJEITADA] SEU NMERO INVLIDO';
   EXEC INCLUI_ERRCNABR '237', '33  ', '[CONFIRMAO ALTERAO DADOS] SEM MOTIVO';
   EXEC INCLUI_ERRCNABR '237', '34  ', '[RETIRADO CARTRIO E PENDENTE] SEM MOTIVO';
   EXEC INCLUI_ERRCNABR '237', '3581', '[CANCELAMENTO DEB. AUTOM.] TENTATIVAS ESGOTADAS, BAIXADO';
   EXEC INCLUI_ERRCNABR '237', '3582', '[CANCELAMENTO DEB. AUTOM.] TENTATIVAS ESGOTADAS, PENDENTE';

-- BANCO ITA 341

   EXEC INCLUI_ERRCNABR '341', '0303  ', '[Entradas Rejeitadas][AG. COBRADORA] NO FOI POSSVEL ATRIBUIR A AGNCIA  PELO CEP OU CEP INVLIDO';
   EXEC INCLUI_ERRCNABR '341', '0304  ', '[Entradas Rejeitadas][ESTADO] SIGLA DO ESTADO INVLIDA';
   EXEC INCLUI_ERRCNABR '341', '0305  ', '[Entradas Rejeitadas][DATA VENCIMENTO] PRAZO DA OPERAO MENOR QUE PRAZO MNIMO OU MAIOR QUE O MXIMO';
   EXEC INCLUI_ERRCNABR '341', '0307  ', '[Entradas Rejeitadas][VALOR DO TTULO] VALOR DO TTULO MAIOR QUE 10.000.000,00';
   EXEC INCLUI_ERRCNABR '341', '0308  ', '[Entradas Rejeitadas][NOME DO SACADO] NO INFORMADO OU DESLOCADO';
   EXEC INCLUI_ERRCNABR '341', '0309  ', '[Entradas Rejeitadas][AGNCIA/CONTA] AGNCIA ENCERRADA';
   EXEC INCLUI_ERRCNABR '341', '0310  ', '[Entradas Rejeitadas][LOGRADOURO] NO INFORMADO OU DESLOCADO';
   EXEC INCLUI_ERRCNABR '341', '0311  ', '[Entradas Rejeitadas][CEP] CEP NO NUMRICO';
   EXEC INCLUI_ERRCNABR '341', '0312  ', '[Entradas Rejeitadas][SACADOR AVALISTA] NOME NO INFORMADO OU DESLOCADO (BANCOS CORRESPONDENTES)';
   EXEC INCLUI_ERRCNABR '341', '0313  ', '[Entradas Rejeitadas][ESTADO/CEP] CEP INCOMPATVEL COM A SIGLA DO ESTADO';
   EXEC INCLUI_ERRCNABR '341', '0314  ', '[Entradas Rejeitadas][NOSSO NMERO] NOSSO NMERO J REGISTRADO NO CADASTRO DO BANCO OU FORA DA FAIXA';
   EXEC INCLUI_ERRCNABR '341', '0315  ', '[Entradas Rejeitadas][NOSSO NMERO] NOSSO NMERO EM DUPLICIDADE NO MESMO MOVIMENTO';
   EXEC INCLUI_ERRCNABR '341', '0318  ', '[Entradas Rejeitadas][DATA DE ENTRADA] DATA DE ENTRADA INVLIDA PARA O OPERAR COM ESTA CARTEIRA';
   EXEC INCLUI_ERRCNABR '341', '0319  ', '[Entradas Rejeitadas][OCORRNCIA] OCORRNCIA INVLIDA';
   EXEC INCLUI_ERRCNABR '341', '0321  ', '[Entradas Rejeitadas][AG. COBRADORA] CARTEIRA NO ACEITA DEPOSITRIA CORRESPONDENTE / ESTADO DA AGNCIA DIFERENTE DO ESTADO DO SACADO / AG. COBRADORA NO CONSTA NO CADASTRO OU  ENCERRANDO';
   EXEC INCLUI_ERRCNABR '341', '0322  ', '[Entradas Rejeitadas][CARTEIRA] CARTEIRA NO PERMITIDA (NECESSRIO CADASTRAR FAIXA LIVRE)';
   EXEC INCLUI_ERRCNABR '341', '0327  ', '[Entradas Rejeitadas][CGC INAPTO] CGC DO CEDENTE INAPTO';
   EXEC INCLUI_ERRCNABR '341', '0329  ', '[Entradas Rejeitadas][CDIGO EMPRESA] CATEGORIA DA CONTA INVLIDA';
   EXEC INCLUI_ERRCNABR '341', '0335  ', '[Entradas Rejeitadas][VALOR DO IOF] IOF MAIOR QUE 5%';
   EXEC INCLUI_ERRCNABR '341', '0336  ', '[Entradas Rejeitadas][QTDADE DE MOEDA] QUANTIDADE DE MOEDA INCOMPATVEL COM VALOR DO TTULO';
   EXEC INCLUI_ERRCNABR '341', '0337  ', '[Entradas Rejeitadas][CGC/CPF DO SACADO] NO NUMRICO OU IGUAL A ZEROS';
   EXEC INCLUI_ERRCNABR '341', '0342  ', '[Entradas Rejeitadas][NOSSO NMERO] NOSSO NMERO FORA DE FAIXA';
   EXEC INCLUI_ERRCNABR '341', '0352  ', '[Entradas Rejeitadas][AG. COBRADORA] EMPRESA NO ACEITA BANCO CORRESPONDENTE';
   EXEC INCLUI_ERRCNABR '341', '0353  ', '[Entradas Rejeitadas][AG. COBRADORA] EMPRESA NO ACEITA BANCO CORRESPONDENTE  - COBRANA MENSAGEM';
   EXEC INCLUI_ERRCNABR '341', '0354  ', '[Entradas Rejeitadas][DATA DE VENCTO] BANCO CORRESPONDENTE - TTULO COM VENCIMENTO INFERIOR A 15 DIAS';
   EXEC INCLUI_ERRCNABR '341', '0355  ', '[Entradas Rejeitadas][DEP/BCO CORRESP] CEP NO PERTENCENTE A DEPOSITRIO INFORMADO';
   EXEC INCLUI_ERRCNABR '341', '0356  ', '[Entradas Rejeitadas][DT.VENCTO/BCO CORRESP] VENCTO. SUPERIOR A 180 DIAS DA DATA DE ENTRADA';
   EXEC INCLUI_ERRCNABR '341', '0357  ', '[Entradas Rejeitadas][DATA DE VENCTO] CEP S DEPOSITRIA BCO DO BRASIL COM VENCTO INFERIOR A 8 DIAS';
   EXEC INCLUI_ERRCNABR '341', '0360  ', '[Entradas Rejeitadas][ABATIMENTO] VALOR DO ABATIMENTO INVLIDO';
   EXEC INCLUI_ERRCNABR '341', '0361  ', '[Entradas Rejeitadas][JUROS DE MORA] JUROS DE MORA MAIOR QUE O PERMITIDO';
   EXEC INCLUI_ERRCNABR '341', '0362  ', '[Entradas Rejeitadas][DESCONTO] VALOR DO DESCONTO MAIOR QUE O VALOR DO TTULO';
   EXEC INCLUI_ERRCNABR '341', '0363  ', '[Entradas Rejeitadas][IMPORTNCIA POR DIA DE DESCONTO] NO PERMITIDO';
   EXEC INCLUI_ERRCNABR '341', '0364  ', '[Entradas Rejeitadas][EMISSO DO TTULO] DATA DE EMISSO DO TTULO INVLIDA (VENDOR)';
   EXEC INCLUI_ERRCNABR '341', '0365  ', '[Entradas Rejeitadas][TAXA FINANCTO] TAXA INVLIDA (VENDOR)';
   EXEC INCLUI_ERRCNABR '341', '0366  ', '[Entradas Rejeitadas][DATA DE VENCTO] INVALIDA/FORA DE PRAZO DE OPERAO (MNIMO OU MXIMO)';
   EXEC INCLUI_ERRCNABR '341', '0367  ', '[Entradas Rejeitadas][VALOR/QTIDADE] VALOR DO TTULO/QUANTIDADE DE MOEDA INVLIDO';
   EXEC INCLUI_ERRCNABR '341', '0368  ', '[Entradas Rejeitadas][CARTEIRA] CARTEIRA INVLIDA';
   EXEC INCLUI_ERRCNABR '341', '0398  ', '[Entradas Rejeitadas][FLASH INVLIDO] REGISTRO MENSAGEM SEM FLASH CADASTRADO OU FLASH INFORMADO DIFERENTE DO CADASTRADO';
   EXEC INCLUI_ERRCNABR '341', '0399  ', '[Entradas Rejeitadas][FLASH INVLIDO] CONTA DE COBRANA COM FLASH CADASTRADO, E SEM REGISTRO DE MENSAGEM CORRESPONDENTE';
   EXEC INCLUI_ERRCNABR '341', '0391  ', '[Entradas Rejeitadas][DAC] DAC AGNCIA / CONTA CORRENTE INVLIDO';
   EXEC INCLUI_ERRCNABR '341', '0392  ', '[Entradas Rejeitadas][DAC] DAC AGNCIA/CONTA/CARTEIRA/NOSSO NMERO INVLIDO';
   EXEC INCLUI_ERRCNABR '341', '0393  ', '[Entradas Rejeitadas][ESTADO] SIGLA ESTADO INVLIDA';
   EXEC INCLUI_ERRCNABR '341', '0394  ', '[Entradas Rejeitadas][ESTADO] SIGLA ESTADO INCOMPATVEL COM CEP DO SACADO';
   EXEC INCLUI_ERRCNABR '341', '0395  ', '[Entradas Rejeitadas][CEP] CEP DO SACADO NO NUMRICO OU INVLIDO';
   EXEC INCLUI_ERRCNABR '341', '0396  ', '[Entradas Rejeitadas][ENDEREO] ENDEREO / NOME / CIDADE SACADO INVLIDO';
   EXEC INCLUI_ERRCNABR '341', '1702  ', '[Alterao de dados rejeitados] AGNCIA COBRADORA INVLIDA OU COM O MESMO CONTEDO';
   EXEC INCLUI_ERRCNABR '341', '1704  ', '[Alterao de dados rejeitados] SIGLA DO ESTADO INVLIDA';
   EXEC INCLUI_ERRCNABR '341', '1705  ', '[Alterao de dados rejeitados] DATA DE VENCIMENTO INVLIDA OU COM O MESMO CONTEDO';
   EXEC INCLUI_ERRCNABR '341', '1706  ', '[Alterao de dados rejeitados] VALOR DO TTULO COM OUTRA ALTERAO SIMULTNEA';
   EXEC INCLUI_ERRCNABR '341', '1708  ', '[Alterao de dados rejeitados] NOME DO SACADO COM O MESMO CONTEDO';
   EXEC INCLUI_ERRCNABR '341', '1709  ', '[Alterao de dados rejeitados] AGNCIA/CONTA INCORRETOS';
   EXEC INCLUI_ERRCNABR '341', '1711  ', '[Alterao de dados rejeitados] CEP INVLIDO';
   EXEC INCLUI_ERRCNABR '341', '1713  ', '[Alterao de dados rejeitados] SEU NMERO COM O MESMO CONTEDO';
   EXEC INCLUI_ERRCNABR '341', '1716  ', '[Alterao de dados rejeitados] ABATIMENTO/ALTERAO DO VALOR DO TTULO OU SOLICITAO DE BAIXA BLOQUEADA';
   EXEC INCLUI_ERRCNABR '341', '1721  ', '[Alterao de dados rejeitados] AGNCIA COBRADORA NO CONSTA NO CADASTRO DE DEPOSITRIA OU EM ENCERRAMENTO';
   EXEC INCLUI_ERRCNABR '341', '1753  ', '[Alterao de dados rejeitados] INSTRUO COM O MESMO CONTEDO';
   EXEC INCLUI_ERRCNABR '341', '1754  ', '[Alterao de dados rejeitados] DATA VENCIMENTO PARA BANCOS CORRESPONDENTES INFERIOR AO ACEITO PELO BANCO';
   EXEC INCLUI_ERRCNABR '341', '1755  ', '[Alterao de dados rejeitados] ALTERAES IGUAIS PARA O MESMO CONTROLE (AGNCIA/CONTA/CARTEIRA/NOSSO NMERO)';
   EXEC INCLUI_ERRCNABR '341', '1756  ', '[Alterao de dados rejeitados] CGC/CPF INVLIDO NO NUMRICO OU ZERADO';
   EXEC INCLUI_ERRCNABR '341', '1757  ', '[Alterao de dados rejeitados] PRAZO DE VENCIMENTO INFERIOR A 15 DIAS';
   EXEC INCLUI_ERRCNABR '341', '1760  ', '[Alterao de dados rejeitados] VALOR DE IOF - ALTERAO NO PERMITIDA PARA CARTEIRAS DE N.S. - MOEDA VARIVEL';
   EXEC INCLUI_ERRCNABR '341', '1761  ', '[Alterao de dados rejeitados] TTULO J BAIXADO OU LIQUIDADO OU NO EXISTE TTULO CORRESPONDENTE NO SISTEMA';
   EXEC INCLUI_ERRCNABR '341', '1766  ', '[Alterao de dados rejeitados] ALTERAO NO PERMITIDA PARA CARTEIRAS DE NOTAS DE SEGUROS - MOEDA VARIVEL';
   EXEC INCLUI_ERRCNABR '341', '1781  ', '[Alterao de dados rejeitados] ALTERAO BLOQUEADA - TTULO COM PROTESTO';
   EXEC INCLUI_ERRCNABR '341', '1601  ', '[Instrues rejeitadas] INSTRUO/OCORRNCIA NO EXISTENTE';
   EXEC INCLUI_ERRCNABR '341', '1606  ', '[Instrues rejeitadas] NOSSO NMERO IGUAL A ZEROS';
   EXEC INCLUI_ERRCNABR '341', '1609  ', '[Instrues rejeitadas] CGC/CPF  DO SACADOR/AVALISTA INVLIDO';
   EXEC INCLUI_ERRCNABR '341', '1610  ', '[Instrues rejeitadas] VALOR DO ABATIMENTO IGUAL OU MAIOR QUE O VALOR DO TTULO';
   EXEC INCLUI_ERRCNABR '341', '1614  ', '[Instrues rejeitadas] REGISTRO EM DUPLICIDADE';
   EXEC INCLUI_ERRCNABR '341', '1615  ', '[Instrues rejeitadas] CGC/CPF INFORMADO SEM NOME DO SACADOR/AVALISTA';
   EXEC INCLUI_ERRCNABR '341', '1621  ', '[Instrues rejeitadas] TTULO NO REGISTRADO NO SISTEMA';
   EXEC INCLUI_ERRCNABR '341', '1622  ', '[Instrues rejeitadas] TTULO BAIXADO OU LIQUIDADO';
   EXEC INCLUI_ERRCNABR '341', '1623  ', '[Instrues rejeitadas] INSTRUO NO ACEITA POR TER SIDO EMITIDO LTIMO AVISO AO SACADO';
   EXEC INCLUI_ERRCNABR '341', '1624  ', '[Instrues rejeitadas] INSTRUO INCOMPATVEL - EXISTE INSTRUO DE PROTESTO PARA O TTULO';
   EXEC INCLUI_ERRCNABR '341', '1625  ', '[Instrues rejeitadas] INSTRUO INCOMPATVEL - NO EXISTE INSTRUO DE PROTESTO PARA O TTULO';
   EXEC INCLUI_ERRCNABR '341', '1626  ', '[Instrues rejeitadas] INSTRUO NO ACEITA POR TER SIDO EMITIDO LTIMO AVISO AO SACADO';
   EXEC INCLUI_ERRCNABR '341', '1627  ', '[Instrues rejeitadas] INSTRUO NO ACEITA POR NO TER SIDO EMITIDA A ORDEM DE PROTESTO AO CARTRIO';
   EXEC INCLUI_ERRCNABR '341', '1628  ', '[Instrues rejeitadas] J EXISTE UMA MESMA INSTRUO CADASTRADA ANTERIORMENTE PARA O TTULO';
   EXEC INCLUI_ERRCNABR '341', '1629  ', '[Instrues rejeitadas] VALOR LQUIDO + VALOR DO ABATIMENTO DIFERENTE DO VALOR DO TTULO REGISTRADO';
   EXEC INCLUI_ERRCNABR '341', '1630  ', '[Instrues rejeitadas] EXISTE UMA INSTRUO DE NO PROTESTAR ATIVA PARA O TTULO';
   EXEC INCLUI_ERRCNABR '341', '1631  ', '[Instrues rejeitadas] EXISTE UMA OCORRNCIA DO SACADO QUE BLOQUEIA A INSTRUO';
   EXEC INCLUI_ERRCNABR '341', '1632  ', '[Instrues rejeitadas] DEPOSITRIA DO TTULO = 9999 OU CARTEIRA NO ACEITA PROTESTO';
   EXEC INCLUI_ERRCNABR '341', '1633  ', '[Instrues rejeitadas] ALTERAO DE VENCIMENTO IGUAL  REGISTRADA NO SISTEMA OU QUE TORNA O TTULO VENCIDO';
   EXEC INCLUI_ERRCNABR '341', '1634  ', '[Instrues rejeitadas] INSTRUO DE EMISSO DE AVISO DE COBRANA PARA TTULO VENCIDO ANTES DO VENCIMENTO';
   EXEC INCLUI_ERRCNABR '341', '1635  ', '[Instrues rejeitadas] SOLICITAO DE CANCELAMENTO DE INSTRUO INEXISTENTE';
   EXEC INCLUI_ERRCNABR '341', '1636  ', '[Instrues rejeitadas] TTULO SOFRENDO ALTERAO DE CONTROLE (AGNCIA/CONTA/CARTEIRA/NOSSO NMERO)';
   EXEC INCLUI_ERRCNABR '341', '1637  ', '[Instrues rejeitadas] INSTRUO NO PERMITIDA PARA A CARTEIRA';
   EXEC INCLUI_ERRCNABR '341', '1501  ', '[Baixas rejeitadas] CARTEIRA/N NMERO NO NUMRICO';
   EXEC INCLUI_ERRCNABR '341', '1504  ', '[Baixas rejeitadas] NOSSO NMERO EM DUPLICIDADE NUM MESMO MOVIMENTO';
   EXEC INCLUI_ERRCNABR '341', '1505  ', '[Baixas rejeitadas] SOLICITAO DE BAIXA PARA TTULO J BAIXADO OU LIQUIDADO';
   EXEC INCLUI_ERRCNABR '341', '1506  ', '[Baixas rejeitadas] SOLICITAO DE BAIXA PARA TTULO NO REGISTRADO NO SISTEMA';
   EXEC INCLUI_ERRCNABR '341', '1507  ', '[Baixas rejeitadas] COBRANA PRAZO CURTO - SOLICITAO DE BAIXA P/ TTULO NO REGISTRADO NO SISTEMA';
   EXEC INCLUI_ERRCNABR '341', '1508  ', '[Baixas rejeitadas] SOLICITAO DE BAIXA PARA TTULO EM FLOATING';
   EXEC INCLUI_ERRCNABR '341', '1816  ', '[Alterao dados cobrana contratual rejeitada] ABATIMENTO/ALTERAO DO VALOR DO TTULO OU SOLICITAO DE BAIXAS BLOQUEADOS';
   EXEC INCLUI_ERRCNABR '341', '251313', '[Alegaes do sacado] SACADO SOLICITA A PRORROGAO DO VENCIMENTO PARA:';
   EXEC INCLUI_ERRCNABR '341', '251321', '[Alegaes do sacado] SACADO SOLICITA A DISPENSA DOS JUROS DE MORA';
   EXEC INCLUI_ERRCNABR '341', '251339', '[Alegaes do sacado] SACADO ALEGA QUE NO RECEBEU A MERCADORIA';
   EXEC INCLUI_ERRCNABR '341', '251347', '[Alegaes do sacado] SACADO ALEGA QUE A MERCADORIA CHEGOU ATRASADA';
   EXEC INCLUI_ERRCNABR '341', '251354', '[Alegaes do sacado] SACADO ALEGA QUE A MERCADORIA CHEGOU AVARIADA';
   EXEC INCLUI_ERRCNABR '341', '251362', '[Alegaes do sacado] SACADO ALEGA QUE A MERCADORIA CHEGOU INCOMPLETA';
   EXEC INCLUI_ERRCNABR '341', '251370', '[Alegaes do sacado] SACADO ALEGA QUE A MERCADORIA NO CONFERE COM O PEDIDO';
   EXEC INCLUI_ERRCNABR '341', '251388', '[Alegaes do sacado] SACADO ALEGA QUE A MERCADORIA EST  DISPOSIO';
   EXEC INCLUI_ERRCNABR '341', '251396', '[Alegaes do sacado] SACADO ALEGA QUE DEVOLVEU A MERCADORIA';
   EXEC INCLUI_ERRCNABR '341', '251404', '[Alegaes do sacado] SACADO ALEGA QUE NO RECEBEU A FATURA';
   EXEC INCLUI_ERRCNABR '341', '251412', '[Alegaes do sacado] SACADO ALEGA QUE A FATURA EST EM DESACORDO COM A NOTA FISCAL';
   EXEC INCLUI_ERRCNABR '341', '251420', '[Alegaes do sacado] SACADO ALEGA QUE O PEDIDO DE COMPRA FOI CANCELADO';
   EXEC INCLUI_ERRCNABR '341', '251438', '[Alegaes do sacado] SACADO ALEGA QUE A DUPLICATA FOI CANCELADA';
   EXEC INCLUI_ERRCNABR '341', '251446', '[Alegaes do sacado] SACADO ALEGA QUE NADA DEVE OU COMPROU';
   EXEC INCLUI_ERRCNABR '341', '251453', '[Alegaes do sacado] SACADO ALEGA QUE MANTM ENTENDIMENTOS COM O SACADOR';
   EXEC INCLUI_ERRCNABR '341', '251461', '[Alegaes do sacado] SACADO ALEGA QUE PAGAR O TTULO EM:';
   EXEC INCLUI_ERRCNABR '341', '251479', '[Alegaes do sacado] SACADO ALEGA QUE PAGOU O TTULO DIRETAMENTE AO CEDENTE EM:';
   EXEC INCLUI_ERRCNABR '341', '251487', '[Alegaes do sacado] SACADO ALEGA QUE PAGAR O TTULO DIRETAMENTE AO CEDENTE EM:';
   EXEC INCLUI_ERRCNABR '341', '251495', '[Alegaes do sacado] SACADO ALEGA QUE O VENCIMENTO CORRETO :';
   EXEC INCLUI_ERRCNABR '341', '251503', '[Alegaes do sacado] SACADO ALEGA QUE TEM DESCONTO OU ABATIMENTO DE:';
   EXEC INCLUI_ERRCNABR '341', '251719', '[Alegaes do sacado] SACADO NO FOI LOCALIZADO; CONFIRMAR ENDEREO';
   EXEC INCLUI_ERRCNABR '341', '251727', '[Alegaes do sacado] SACADO EST EM REGIME DE CONCORDATA';
   EXEC INCLUI_ERRCNABR '341', '251735', '[Alegaes do sacado] SACADO EST EM REGIME DE FALNCIA';
   EXEC INCLUI_ERRCNABR '341', '251750', '[Alegaes do sacado] SACADO SE RECUSA A PAGAR JUROS BANCRIOS';
   EXEC INCLUI_ERRCNABR '341', '251768', '[Alegaes do sacado] SACADO SE RECUSA A PAGAR COMISSO DE PERMANNCIA';
   EXEC INCLUI_ERRCNABR '341', '251776', '[Alegaes do sacado] NO FOI POSSVEL A ENTREGA DO BLOQUETO AO SACADO';
   EXEC INCLUI_ERRCNABR '341', '251784', '[Alegaes do sacado] BLOQUETO NO ENTREGUE, MUDOU-SE/DESCONHECIDO';
   EXEC INCLUI_ERRCNABR '341', '251792', '[Alegaes do sacado] BLOQUETO NO ENTREGUE, CEP ERRADO/INCOMPLETO';
   EXEC INCLUI_ERRCNABR '341', '251800', '[Alegaes do sacado] BLOQUETO NO ENTREGUE, NMERO NO EXISTE/ENDEREO INCOMPLETO';
   EXEC INCLUI_ERRCNABR '341', '243111', '[Ordem de protesto sustada] SUSTAO SOLICITADA AG. CEDENTE';
   EXEC INCLUI_ERRCNABR '341', '243228', '[Ordem de protesto sustada] ATOS DA CORREGEDORIA ESTADUAL';
   EXEC INCLUI_ERRCNABR '341', '243301', '[Ordem de protesto sustada] CGC/CPF DO SACADO INVLIDO/INCORRETO';
   EXEC INCLUI_ERRCNABR '341', '243319', '[Ordem de protesto sustada] SACADOR/AVALISTA E PESSOA FSICA';
   EXEC INCLUI_ERRCNABR '341', '243327', '[Ordem de protesto sustada] CEP DO SACADO INCORRETO';
   EXEC INCLUI_ERRCNABR '341', '243335', '[Ordem de protesto sustada] DEPOSITRIA INCOMPATVEL COM CEP DO SACADO';
   EXEC INCLUI_ERRCNABR '341', '243343', '[Ordem de protesto sustada] CGC/CPF SACADOR INVALIDO/INCORRETO';
   EXEC INCLUI_ERRCNABR '341', '243350', '[Ordem de protesto sustada] ENDEREO DO SACADO INSUFICIENTE';
   EXEC INCLUI_ERRCNABR '341', '243368', '[Ordem de protesto sustada] PRAA PAGTO INCOMPATVEL COM ENDEREO';
   EXEC INCLUI_ERRCNABR '341', '243376', '[Ordem de protesto sustada] FALTA NMERO/ESPCIE DO TTULO';
   EXEC INCLUI_ERRCNABR '341', '243384', '[Ordem de protesto sustada] TTULO ACEITO S/ ASSINATURA DO SACADOR';
   EXEC INCLUI_ERRCNABR '341', '243392', '[Ordem de protesto sustada] TTULO ACEITO S/ ENDOSSO CEDENTE OU IRREGULAR';
   EXEC INCLUI_ERRCNABR '341', '243400', '[Ordem de protesto sustada] TTULO SEM LOCAL OU DATA DE EMISSO';
   EXEC INCLUI_ERRCNABR '341', '243418', '[Ordem de protesto sustada] TTULO ACEITO VALOR EXTENSO DIFERENTE DO NUMRICO';
   EXEC INCLUI_ERRCNABR '341', '243426', '[Ordem de protesto sustada] TTULO ACEITO DEFINIR ESPCIE DA DUPLICATA';
   EXEC INCLUI_ERRCNABR '341', '243434', '[Ordem de protesto sustada] DATA EMISSO POSTERIOR AO VENCIMENTO';
   EXEC INCLUI_ERRCNABR '341', '243442', '[Ordem de protesto sustada] TTULO ACEITO DOCUMENTO NO PROSTESTVEL';
   EXEC INCLUI_ERRCNABR '341', '243459', '[Ordem de protesto sustada] TTULO ACEITO EXTENSO VENCIMENTO IRREGULAR';
   EXEC INCLUI_ERRCNABR '341', '243467', '[Ordem de protesto sustada] TTULO ACEITO FALTA NOME FAVORECIDO';
   EXEC INCLUI_ERRCNABR '341', '243475', '[Ordem de protesto sustada] TTULO ACEITO FALTA PRAA DE PAGAMENTO';
   EXEC INCLUI_ERRCNABR '341', '243483', '[Ordem de protesto sustada] TTULO ACEITO FALTA CPF ASSINANTE CHEQUE';

-- BANCO HSBC 399

   EXEC INCLUI_ERRCNABR '399', '0301', '[ENTRADA REJEITADA] CDIGO DO BANCO INVLIDO';
   EXEC INCLUI_ERRCNABR '399', '0302', '[ENTRADA REJEITADA] CDIGO DO REGISTRO DETALHE INVLIDO';
   EXEC INCLUI_ERRCNABR '399', '0303', '[ENTRADA REJEITADA] CDIGO DO SEGMENTO INVLIDO';
   EXEC INCLUI_ERRCNABR '399', '0304', '[ENTRADA REJEITADA] CDIGO DO MOVIMENTO NO PERMITIDO PARA CARTEIRA';
   EXEC INCLUI_ERRCNABR '399', '0305', '[ENTRADA REJEITADA] CDIGO DE MOVIMENTO INVLIDO';
   EXEC INCLUI_ERRCNABR '399', '0306', '[ENTRADA REJEITADA] TIPO/NMERO DE INSCRIO DO CEDENTE INVLIDOS';
   EXEC INCLUI_ERRCNABR '399', '0307', '[ENTRADA REJEITADA] CDIGO DE CONVNIO INVLIDO OU NO CADASTRADO';
   EXEC INCLUI_ERRCNABR '399', '0308', '[ENTRADA REJEITADA] NOSSO NMERO INVLIDO';
   EXEC INCLUI_ERRCNABR '399', '0309', '[ENTRADA REJEITADA] NOSSO NMERO DUPLICADO';
   EXEC INCLUI_ERRCNABR '399', '0310', '[ENTRADA REJEITADA] CARTEIRA INVLIDA';
   EXEC INCLUI_ERRCNABR '399', '0311', '[ENTRADA REJEITADA] FORMA DE CADASTRAMENTO DO TTULO INVLIDO';
   EXEC INCLUI_ERRCNABR '399', '0312', '[ENTRADA REJEITADA] TIPO DE DOCUMENTO INVLIDO';
   EXEC INCLUI_ERRCNABR '399', '0313', '[ENTRADA REJEITADA] IDENTIFICAO DA EMISSO DO BLOQUETO INVLIDA';
   EXEC INCLUI_ERRCNABR '399', '0314', '[ENTRADA REJEITADA] IDENTIFICAO DA DISTRIBUIO DO BLOQUETO INVLIDA';
   EXEC INCLUI_ERRCNABR '399', '0315', '[ENTRADA REJEITADA] CARACTERSTICAS DA COBRANA INCOMPATVEIS';
   EXEC INCLUI_ERRCNABR '399', '0316', '[ENTRADA REJEITADA] DATA DE VENCIMENTO INVLIDA';
   EXEC INCLUI_ERRCNABR '399', '0320', '[ENTRADA REJEITADA] VALOR DO TTULO INVLIDO';
   EXEC INCLUI_ERRCNABR '399', '0321', '[ENTRADA REJEITADA] ESPCIE DO TTULO INVLIDA';
   EXEC INCLUI_ERRCNABR '399', '0323', '[ENTRADA REJEITADA] ACEITE INVLIDO';
   EXEC INCLUI_ERRCNABR '399', '0324', '[ENTRADA REJEITADA] DATA DA EMISSO INVLIDA';
   EXEC INCLUI_ERRCNABR '399', '0326', '[ENTRADA REJEITADA] CDIGO DE JUROS DE MORA INVLIDO';
   EXEC INCLUI_ERRCNABR '399', '0327', '[ENTRADA REJEITADA] VALOR/TAXA DE JUROS DE MORA INVLIDO';
   EXEC INCLUI_ERRCNABR '399', '0328', '[ENTRADA REJEITADA] CDIGO DO DESCONTO INVLIDO';
   EXEC INCLUI_ERRCNABR '399', '0330', '[ENTRADA REJEITADA] DESCONTO A CONCEDER NO CONFERE';
   EXEC INCLUI_ERRCNABR '399', '0333', '[ENTRADA REJEITADA] VALOR DO ABATIMENTO INVLIDO';
   EXEC INCLUI_ERRCNABR '399', '0335', '[ENTRADA REJEITADA] ABATIMENTO A CONCEDER NO CONFERE';
   EXEC INCLUI_ERRCNABR '399', '0337', '[ENTRADA REJEITADA] CDIGO PARA PROTESTO INVLIDO';
   EXEC INCLUI_ERRCNABR '399', '0338', '[ENTRADA REJEITADA] PRAZO PARA PROTESTO INVLIDO';
   EXEC INCLUI_ERRCNABR '399', '0342', '[ENTRADA REJEITADA] CDIGO PARA BAIXA/DEVOLUO INVLIDO';
   EXEC INCLUI_ERRCNABR '399', '0343', '[ENTRADA REJEITADA] PRAZO PARA BAIXA/DEVOLUO INVLIDO';
   EXEC INCLUI_ERRCNABR '399', '0344', '[ENTRADA REJEITADA] CDIGO DA MOEDA INVLIDO';
   EXEC INCLUI_ERRCNABR '399', '0345', '[ENTRADA REJEITADA] NOME DO SACADO NO INFORMADO';
   EXEC INCLUI_ERRCNABR '399', '0346', '[ENTRADA REJEITADA] TIPO/NMERO DE INSCRIO DO SACADO INVLIDOS';
   EXEC INCLUI_ERRCNABR '399', '0347', '[ENTRADA REJEITADA] ENDEREO DO SACADO NO INFORMADO';
   EXEC INCLUI_ERRCNABR '399', '0348', '[ENTRADA REJEITADA] CEP INVLIDO';
   EXEC INCLUI_ERRCNABR '399', '0349', '[ENTRADA REJEITADA] CEP SEM PRAA DE COBRANA (NO LOCALIZADO)';
   EXEC INCLUI_ERRCNABR '399', '0350', '[ENTRADA REJEITADA] CEP REFERENTE A UM BANCO CORRESPONDENTE';
   EXEC INCLUI_ERRCNABR '399', '0352', '[ENTRADA REJEITADA] UNIDADE DA FEDERAO INVLIDA';
   EXEC INCLUI_ERRCNABR '399', '0357', '[ENTRADA REJEITADA] CDIGO DA MULTA INVLIDO';
   EXEC INCLUI_ERRCNABR '399', '0358', '[ENTRADA REJEITADA] DATA DA MULTA INVLIDA';
   EXEC INCLUI_ERRCNABR '399', '0359', '[ENTRADA REJEITADA] VALOR/PERCENTUAL DA MULTA INVLIDO';
   EXEC INCLUI_ERRCNABR '399', '0362', '[ENTRADA REJEITADA] TIPO DE IMPRESSO INVLIDO';
   EXEC INCLUI_ERRCNABR '399', '0363', '[ENTRADA REJEITADA] ENTRADA PARA TTULO J CADASTRADO';
   EXEC INCLUI_ERRCNABR '399', '2601', '[ENTRADA REJEITADA] CDIGO DO BANCO INVLIDO';
   EXEC INCLUI_ERRCNABR '399', '2602', '[ENTRADA REJEITADA] CDIGO DO REGISTRO DETALHE INVLIDO';
   EXEC INCLUI_ERRCNABR '399', '2603', '[ENTRADA REJEITADA] CDIGO DO SEGMENTO INVLIDO';
   EXEC INCLUI_ERRCNABR '399', '2604', '[ENTRADA REJEITADA] CDIGO DO MOVIMENTO NO PERMITIDO PARA CARTEIRA';
   EXEC INCLUI_ERRCNABR '399', '2605', '[ENTRADA REJEITADA] CDIGO DE MOVIMENTO INVLIDO';
   EXEC INCLUI_ERRCNABR '399', '2606', '[ENTRADA REJEITADA] TIPO/NMERO DE INSCRIO DO CEDENTE INVLIDOS';
   EXEC INCLUI_ERRCNABR '399', '2607', '[ENTRADA REJEITADA] CDIGO DE CONVNIO INVLIDO OU NO CADASTRADO';
   EXEC INCLUI_ERRCNABR '399', '2608', '[ENTRADA REJEITADA] NOSSO NMERO INVLIDO';
   EXEC INCLUI_ERRCNABR '399', '2609', '[ENTRADA REJEITADA] NOSSO NMERO DUPLICADO';
   EXEC INCLUI_ERRCNABR '399', '2610', '[ENTRADA REJEITADA] CARTEIRA INVLIDA';
   EXEC INCLUI_ERRCNABR '399', '2611', '[ENTRADA REJEITADA] FORMA DE CADASTRAMENTO DO TTULO INVLIDO';
   EXEC INCLUI_ERRCNABR '399', '2612', '[ENTRADA REJEITADA] TIPO DE DOCUMENTO INVLIDO';
   EXEC INCLUI_ERRCNABR '399', '2613', '[ENTRADA REJEITADA] IDENTIFICAO DA EMISSO DO BLOQUETO INVLIDA';
   EXEC INCLUI_ERRCNABR '399', '2614', '[ENTRADA REJEITADA] IDENTIFICAO DA DISTRIBUIO DO BLOQUETO INVLIDA';
   EXEC INCLUI_ERRCNABR '399', '2615', '[ENTRADA REJEITADA] CARACTERSTICAS DA COBRANA INCOMPATVEIS';
   EXEC INCLUI_ERRCNABR '399', '2616', '[ENTRADA REJEITADA] DATA DE VENCIMENTO INVLIDA';
   EXEC INCLUI_ERRCNABR '399', '2620', '[ENTRADA REJEITADA] VALOR DO TTULO INVLIDO';
   EXEC INCLUI_ERRCNABR '399', '2621', '[ENTRADA REJEITADA] ESPCIE DO TTULO INVLIDA';
   EXEC INCLUI_ERRCNABR '399', '2623', '[ENTRADA REJEITADA] ACEITE INVLIDO';
   EXEC INCLUI_ERRCNABR '399', '2624', '[ENTRADA REJEITADA] DATA DA EMISSO INVLIDA';
   EXEC INCLUI_ERRCNABR '399', '2626', '[ENTRADA REJEITADA] CDIGO DE JUROS DE MORA INVLIDO';
   EXEC INCLUI_ERRCNABR '399', '2627', '[ENTRADA REJEITADA] VALOR/TAXA DE JUROS DE MORA INVLIDO';
   EXEC INCLUI_ERRCNABR '399', '2628', '[ENTRADA REJEITADA] CDIGO DO DESCONTO INVLIDO';
   EXEC INCLUI_ERRCNABR '399', '2630', '[ENTRADA REJEITADA] DESCONTO A CONCEDER NO CONFERE';
   EXEC INCLUI_ERRCNABR '399', '2633', '[ENTRADA REJEITADA] VALOR DO ABATIMENTO INVLIDO';
   EXEC INCLUI_ERRCNABR '399', '2635', '[ENTRADA REJEITADA] ABATIMENTO A CONCEDER NO CONFERE';
   EXEC INCLUI_ERRCNABR '399', '2637', '[ENTRADA REJEITADA] CDIGO PARA PROTESTO INVLIDO';
   EXEC INCLUI_ERRCNABR '399', '2638', '[ENTRADA REJEITADA] PRAZO PARA PROTESTO INVLIDO';
   EXEC INCLUI_ERRCNABR '399', '2642', '[ENTRADA REJEITADA] CDIGO PARA BAIXA/DEVOLUO INVLIDO';
   EXEC INCLUI_ERRCNABR '399', '2643', '[ENTRADA REJEITADA] PRAZO PARA BAIXA/DEVOLUO INVLIDO';
   EXEC INCLUI_ERRCNABR '399', '2644', '[ENTRADA REJEITADA] CDIGO DA MOEDA INVLIDO';
   EXEC INCLUI_ERRCNABR '399', '2645', '[ENTRADA REJEITADA] NOME DO SACADO NO INFORMADO';
   EXEC INCLUI_ERRCNABR '399', '2646', '[ENTRADA REJEITADA] TIPO/NMERO DE INSCRIO DO SACADO INVLIDOS';
   EXEC INCLUI_ERRCNABR '399', '2647', '[ENTRADA REJEITADA] ENDEREO DO SACADO NO INFORMADO';
   EXEC INCLUI_ERRCNABR '399', '2648', '[ENTRADA REJEITADA] CEP INVLIDO';
   EXEC INCLUI_ERRCNABR '399', '2649', '[ENTRADA REJEITADA] CEP SEM PRAA DE COBRANA (NO LOCALIZADO)';
   EXEC INCLUI_ERRCNABR '399', '2650', '[ENTRADA REJEITADA] CEP REFERENTE A UM BANCO CORRESPONDENTE';
   EXEC INCLUI_ERRCNABR '399', '2652', '[ENTRADA REJEITADA] UNIDADE DA FEDERAO INVLIDA';
   EXEC INCLUI_ERRCNABR '399', '2657', '[ENTRADA REJEITADA] CDIGO DA MULTA INVLIDO';
   EXEC INCLUI_ERRCNABR '399', '2658', '[ENTRADA REJEITADA] DATA DA MULTA INVLIDA';
   EXEC INCLUI_ERRCNABR '399', '2659', '[ENTRADA REJEITADA] VALOR/PERCENTUAL DA MULTA INVLIDO';
   EXEC INCLUI_ERRCNABR '399', '2662', '[ENTRADA REJEITADA] TIPO DE IMPRESSO INVLIDO';
   EXEC INCLUI_ERRCNABR '399', '2663', '[ENTRADA REJEITADA] ENTRADA PARA TTULO J CADASTRADO';
   EXEC INCLUI_ERRCNABR '399', '3001', '[ENTRADA REJEITADA] CDIGO DO BANCO INVLIDO';
   EXEC INCLUI_ERRCNABR '399', '3002', '[ENTRADA REJEITADA] CDIGO DO REGISTRO DETALHE INVLIDO';
   EXEC INCLUI_ERRCNABR '399', '3003', '[ENTRADA REJEITADA] CDIGO DO SEGMENTO INVLIDO';
   EXEC INCLUI_ERRCNABR '399', '3004', '[ENTRADA REJEITADA] CDIGO DO MOVIMENTO NO PERMITIDO PARA CARTEIRA';
   EXEC INCLUI_ERRCNABR '399', '3005', '[ENTRADA REJEITADA] CDIGO DE MOVIMENTO INVLIDO';
   EXEC INCLUI_ERRCNABR '399', '3006', '[ENTRADA REJEITADA] TIPO/NMERO DE INSCRIO DO CEDENTE INVLIDOS';
   EXEC INCLUI_ERRCNABR '399', '3007', '[ENTRADA REJEITADA] CDIGO DE CONVNIO INVLIDO OU NO CADASTRADO';
   EXEC INCLUI_ERRCNABR '399', '3008', '[ENTRADA REJEITADA] NOSSO NMERO INVLIDO';
   EXEC INCLUI_ERRCNABR '399', '3009', '[ENTRADA REJEITADA] NOSSO NMERO DUPLICADO';
   EXEC INCLUI_ERRCNABR '399', '3010', '[ENTRADA REJEITADA] CARTEIRA INVLIDA';
   EXEC INCLUI_ERRCNABR '399', '3011', '[ENTRADA REJEITADA] FORMA DE CADASTRAMENTO DO TTULO INVLIDO';
   EXEC INCLUI_ERRCNABR '399', '3012', '[ENTRADA REJEITADA] TIPO DE DOCUMENTO INVLIDO';
   EXEC INCLUI_ERRCNABR '399', '3013', '[ENTRADA REJEITADA] IDENTIFICAO DA EMISSO DO BLOQUETO INVLIDA';
   EXEC INCLUI_ERRCNABR '399', '3014', '[ENTRADA REJEITADA] IDENTIFICAO DA DISTRIBUIO DO BLOQUETO INVLIDA';
   EXEC INCLUI_ERRCNABR '399', '3015', '[ENTRADA REJEITADA] CARACTERSTICAS DA COBRANA INCOMPATVEIS';
   EXEC INCLUI_ERRCNABR '399', '3016', '[ENTRADA REJEITADA] DATA DE VENCIMENTO INVLIDA';
   EXEC INCLUI_ERRCNABR '399', '3020', '[ENTRADA REJEITADA] VALOR DO TTULO INVLIDO';
   EXEC INCLUI_ERRCNABR '399', '3021', '[ENTRADA REJEITADA] ESPCIE DO TTULO INVLIDA';
   EXEC INCLUI_ERRCNABR '399', '3023', '[ENTRADA REJEITADA] ACEITE INVLIDO';
   EXEC INCLUI_ERRCNABR '399', '3024', '[ENTRADA REJEITADA] DATA DA EMISSO INVLIDA';
   EXEC INCLUI_ERRCNABR '399', '3026', '[ENTRADA REJEITADA] CDIGO DE JUROS DE MORA INVLIDO';
   EXEC INCLUI_ERRCNABR '399', '3027', '[ENTRADA REJEITADA] VALOR/TAXA DE JUROS DE MORA INVLIDO';
   EXEC INCLUI_ERRCNABR '399', '3028', '[ENTRADA REJEITADA] CDIGO DO DESCONTO INVLIDO';
   EXEC INCLUI_ERRCNABR '399', '3030', '[ENTRADA REJEITADA] DESCONTO A CONCEDER NO CONFERE';
   EXEC INCLUI_ERRCNABR '399', '3033', '[ENTRADA REJEITADA] VALOR DO ABATIMENTO INVLIDO';
   EXEC INCLUI_ERRCNABR '399', '3035', '[ENTRADA REJEITADA] ABATIMENTO A CONCEDER NO CONFERE';
   EXEC INCLUI_ERRCNABR '399', '3037', '[ENTRADA REJEITADA] CDIGO PARA PROTESTO INVLIDO';
   EXEC INCLUI_ERRCNABR '399', '3038', '[ENTRADA REJEITADA] PRAZO PARA PROTESTO INVLIDO';
   EXEC INCLUI_ERRCNABR '399', '3042', '[ENTRADA REJEITADA] CDIGO PARA BAIXA/DEVOLUO INVLIDO';
   EXEC INCLUI_ERRCNABR '399', '3043', '[ENTRADA REJEITADA] PRAZO PARA BAIXA/DEVOLUO INVLIDO';
   EXEC INCLUI_ERRCNABR '399', '3044', '[ENTRADA REJEITADA] CDIGO DA MOEDA INVLIDO';
   EXEC INCLUI_ERRCNABR '399', '3045', '[ENTRADA REJEITADA] NOME DO SACADO NO INFORMADO';
   EXEC INCLUI_ERRCNABR '399', '3046', '[ENTRADA REJEITADA] TIPO/NMERO DE INSCRIO DO SACADO INVLIDOS';
   EXEC INCLUI_ERRCNABR '399', '3047', '[ENTRADA REJEITADA] ENDEREO DO SACADO NO INFORMADO';
   EXEC INCLUI_ERRCNABR '399', '3048', '[ENTRADA REJEITADA] CEP INVLIDO';
   EXEC INCLUI_ERRCNABR '399', '3049', '[ENTRADA REJEITADA] CEP SEM PRAA DE COBRANA (NO LOCALIZADO)';
   EXEC INCLUI_ERRCNABR '399', '3050', '[ENTRADA REJEITADA] CEP REFERENTE A UM BANCO CORRESPONDENTE';
   EXEC INCLUI_ERRCNABR '399', '3052', '[ENTRADA REJEITADA] UNIDADE DA FEDERAO INVLIDA';
   EXEC INCLUI_ERRCNABR '399', '3057', '[ENTRADA REJEITADA] CDIGO DA MULTA INVLIDO';
   EXEC INCLUI_ERRCNABR '399', '3058', '[ENTRADA REJEITADA] DATA DA MULTA INVLIDA';
   EXEC INCLUI_ERRCNABR '399', '3059', '[ENTRADA REJEITADA] VALOR/PERCENTUAL DA MULTA INVLIDO';
   EXEC INCLUI_ERRCNABR '399', '3062', '[ENTRADA REJEITADA] TIPO DE IMPRESSO INVLIDO';
   EXEC INCLUI_ERRCNABR '399', '3063', '[ENTRADA REJEITADA] ENTRADA PARA TTULO J CADASTRADO';

-- BANCO SAFRA 422

   EXEC INCLUI_ERRCNABR '422', '001', 'MOEDA INVLIDA';
   EXEC INCLUI_ERRCNABR '422', '002', 'MOEDA INVLIDA PARA CARTEIRA';
   EXEC INCLUI_ERRCNABR '422', '003', 'CARTEIRA 3 INVLIDA PARA TIPO DE MOEDA';
   EXEC INCLUI_ERRCNABR '422', '004', 'TIPO DE IOF INVLIDO PARA COBRAA DE SEGUROS';
   EXEC INCLUI_ERRCNABR '422', '005', 'TIPO DE IOF INVLIDO PARA VALOR DE IOF(SEGUROS)';
   EXEC INCLUI_ERRCNABR '422', '006', 'VALOR DE IOF INVLIDO(SEGUROS)';
   EXEC INCLUI_ERRCNABR '422', '007', 'CEP NO CORRESPONDENDE UF';
   EXEC INCLUI_ERRCNABR '422', '008', 'VALOR JUROS MAIOR QUE 5% DO VALOR DO TTULO';
   EXEC INCLUI_ERRCNABR '422', '009', 'SEU NUMERO - NO NUMRICO PARA CHEQUE';
   EXEC INCLUI_ERRCNABR '422', '010', 'USO EXCLUSIVO NO NUMRICO PARA COBRANA EXPRESS';
   EXEC INCLUI_ERRCNABR '422', '011', 'NOSSO NMERO FORA DA CAIXA';
   EXEC INCLUI_ERRCNABR '422', '012', 'CEP DE CIDADE INEXISTENTE';
   EXEC INCLUI_ERRCNABR '422', '013', 'CEP FORA DE FAIXA DA CIDADE';
   EXEC INCLUI_ERRCNABR '422', '014', 'UF INVLIDO PARA CEP DA CIDADE';
   EXEC INCLUI_ERRCNABR '422', '015', 'CEP ZERADO';
   EXEC INCLUI_ERRCNABR '422', '016', 'CEP NO CONSTA NA TABELA SAFRA';
   EXEC INCLUI_ERRCNABR '422', '017', 'CEP NO CONSTA TABELA BCO CORRESPONDENTE';
   EXEC INCLUI_ERRCNABR '422', '018', 'DADOS DO CHEQUE NO NUMRICO';
   EXEC INCLUI_ERRCNABR '422', '019', 'PROTESTO IMPRATICVEL';
   EXEC INCLUI_ERRCNABR '422', '020', 'PRIMEIRA INSTRUO DE COBRANA INVLIDA';
   EXEC INCLUI_ERRCNABR '422', '021', 'SEGUNDA INSTRUO DE COBRANA INVLIDA';
   EXEC INCLUI_ERRCNABR '422', '022', 'SEGUNDA INSTR(10) E TERCEIRA INSTR INVLIDA';
   EXEC INCLUI_ERRCNABR '422', '023', 'TERCEIRA INTRUO DE COBRANA INVLIDA ';
   EXEC INCLUI_ERRCNABR '422', '024', 'DIGITO VERIFICADOR C1 INVLIDO';
   EXEC INCLUI_ERRCNABR '422', '025', 'DIGITO VERIFICADOR C2 INVLIDO';
   EXEC INCLUI_ERRCNABR '422', '026', 'CDIGO DE OPERAO/ OCORRNCIA INVLIDO';
   EXEC INCLUI_ERRCNABR '422', '027', 'OPERAO INVLIDA PARA O CLIENTE';
   EXEC INCLUI_ERRCNABR '422', '028', 'NOSSO NMERO NO NMERICO OU ZERADO';
   EXEC INCLUI_ERRCNABR '422', '029', 'NOSSO NMERO COM DGITO DE CONTROLE ERRADO';
   EXEC INCLUI_ERRCNABR '422', '030', 'VALOR DE ABATIMENTO NO NMERICO OU ZERADO';
   EXEC INCLUI_ERRCNABR '422', '031', 'SEU NMERO EM BRANCO';
   EXEC INCLUI_ERRCNABR '422', '032', 'CDIGO DA CARTEIRA INVLIDO';
   EXEC INCLUI_ERRCNABR '422', '033', 'DIGITO VERIFICADOR C3 INVLIDO';
   EXEC INCLUI_ERRCNABR '422', '034', 'CDIGO DO TTULO INVLIDO';
   EXEC INCLUI_ERRCNABR '422', '035', 'DATA DE MOVIMENTO INVLIDA';
   EXEC INCLUI_ERRCNABR '422', '036', 'DATA DE EMISSO';
   EXEC INCLUI_ERRCNABR '422', '037', 'DATA DE VENCIMENTO INVLIDA';
   EXEC INCLUI_ERRCNABR '422', '038', 'DEPOSITRIA INVLIDA';
   EXEC INCLUI_ERRCNABR '422', '039', 'DEPOSITRIA INVLIDA PARA O CLIENTE';
   EXEC INCLUI_ERRCNABR '422', '040', 'DEPOSITRIA NO CADASTRADA NO BANCO';
   EXEC INCLUI_ERRCNABR '422', '041', 'CDIGO DE ACEITE INVLIDO';
   EXEC INCLUI_ERRCNABR '422', '042', 'ESPCIE DE TTULO INVLIDO';
   EXEC INCLUI_ERRCNABR '422', '043', 'INSTRUO DE COBRANA INVLIDA';
   EXEC INCLUI_ERRCNABR '422', '044', 'VALOR DO TTULO NO NUMRICO OU ZERADO';
   EXEC INCLUI_ERRCNABR '422', '045', 'DATA DE OPERAO ';
   EXEC INCLUI_ERRCNABR '422', '046', 'VALOR DE JUROS NO NMERICO OU ZERADO';
   EXEC INCLUI_ERRCNABR '422', '047', 'DATA LIMITE PARA DESCONTO INVLIDA';
   EXEC INCLUI_ERRCNABR '422', '048', 'VALOR DO DESCONTO INVLIDO';
   EXEC INCLUI_ERRCNABR '422', '049', 'VALOR IOF NO NUMRICO OU ZERADO(SEGUROS)';
   EXEC INCLUI_ERRCNABR '422', '050', 'ABATIMENTO COM VALOR PARA OPERAO "01"(ENTRADA DE TTULO)';
   EXEC INCLUI_ERRCNABR '422', '051', 'CDIGO DE INSCRIO DO SACADO INVLIDO';
   EXEC INCLUI_ERRCNABR '422', '052', 'CDIGO DE INSCRIO / NMERO DE INSCRIO DO SACADO INVLIDO';
   EXEC INCLUI_ERRCNABR '422', '053', 'NMERO DE INSCRIO DO SACADO NO NUMRICO OU DGITO ERRADO';
   EXEC INCLUI_ERRCNABR '422', '054', 'NOME DO SACADO EM BRANCO';
   EXEC INCLUI_ERRCNABR '422', '055', 'ENDEREO DO SACADO EM BRANCO';
   EXEC INCLUI_ERRCNABR '422', '056', 'CLIENTE NO RECADASTRADO';
   EXEC INCLUI_ERRCNABR '422', '057', 'CLIENTE BLOQUEADO';
   EXEC INCLUI_ERRCNABR '422', '058', 'PROCESSO DE CARTRIO INVLIDO';
   EXEC INCLUI_ERRCNABR '422', '059', 'ESTADO DO SACADO INVLIDO';
   EXEC INCLUI_ERRCNABR '422', '060', 'CEP / ENDEREO DIVERGEM DO CORREIO ';
   EXEC INCLUI_ERRCNABR '422', '061', 'INSTRUO AGENDADA PARA AGNCIA';
   EXEC INCLUI_ERRCNABR '422', '062', 'OPERAO INVLIDA PARA A CARTEIRA';
   EXEC INCLUI_ERRCNABR '422', '063', 'CDIGO NO PREVISTO';
   EXEC INCLUI_ERRCNABR '422', '064', 'TTULO INEXISTENTE(TFC)';
   EXEC INCLUI_ERRCNABR '422', '065', 'OPERAO EXISTENTE PARA O TTULO';
   EXEC INCLUI_ERRCNABR '422', '066', 'TTULO J EXISTE (TFC)';
   EXEC INCLUI_ERRCNABR '422', '067', 'DATA DE VENCIMENTO INVLIDA PARA PROTESTO';
   EXEC INCLUI_ERRCNABR '422', '068', 'CEP DO SACADO NO CONSTA NA TABELA';
   EXEC INCLUI_ERRCNABR '422', '069', 'PRAA NO ATENDIA PELO SERVIO CARTRIO';
   EXEC INCLUI_ERRCNABR '422', '070', 'AGNCIA INVLIDA';
   EXEC INCLUI_ERRCNABR '422', '071', 'CLIENTE NO CADSATRADO';
   EXEC INCLUI_ERRCNABR '422', '072', 'TTULO J EXISTE (COB)';
   EXEC INCLUI_ERRCNABR '422', '073', 'TAXA OPERAO NO NUMRICA OU ZERADA (VENDOR)';
   EXEC INCLUI_ERRCNABR '422', '074', 'TTULO FORA DA SEQNCIA';
   EXEC INCLUI_ERRCNABR '422', '075', 'TAXA DE OPERAO ZERADA (VENDOR)';
   EXEC INCLUI_ERRCNABR '422', '076', 'EQUALIZAO NO NUMRICA OU INVLIDA (VENDOR)';
   EXEC INCLUI_ERRCNABR '422', '077', 'TAXA NEGOCIADA NO NUMRICA OU ZERDA (VENDOR)';
   EXEC INCLUI_ERRCNABR '422', '078', 'TTULO INEXISTENTE (COB)';
   EXEC INCLUI_ERRCNABR '422', '079', 'OPERAO NO CONCLUDA';
   EXEC INCLUI_ERRCNABR '422', '080', 'TTULO J CADASTRADO';
   EXEC INCLUI_ERRCNABR '422', '081', 'TTULO NO DESCONTADO';
   EXEC INCLUI_ERRCNABR '422', '082', 'INTERVALO ENTRE DATA DE OPRERAO E DATA VCTO MENOR QUE UM DIA';
   EXEC INCLUI_ERRCNABR '422', '083', 'PRORROGAO / ALTERAO DE VENCIMENTO INVLIDA';
   EXEC INCLUI_ERRCNABR '422', '084', 'MOVIMENTO IGUAL AO CADASTRADO DE EXISTNCIA DO COB';
   EXEC INCLUI_ERRCNABR '422', '085', 'CDIGO OPERAO COM PCB INVLIDO (OPREAO INVLIDA P/ CARTEIRA)';
   EXEC INCLUI_ERRCNABR '422', '086', 'ABATIMENTO MAIOR QUE O VALOR DO TTULO';
   EXEC INCLUI_ERRCNABR '422', '087', 'ALTERAO DE CATRIO INVLIDA';
   EXEC INCLUI_ERRCNABR '422', '088', 'TTULO RECUSADO COMO GARANTIA';
   EXEC INCLUI_ERRCNABR '422', '089', 'ALTERAO DE DATA DE PROTESTO INVLIDA';
   EXEC INCLUI_ERRCNABR '422', '090', 'MODALIDADE DE VENDOR INVLIDO';
   EXEC INCLUI_ERRCNABR '422', '091', 'PCB CTO INVLIDA';
   EXEC INCLUI_ERRCNABR '422', '092', 'DATA DE OPERAO CTO INVLIDA';
   EXEC INCLUI_ERRCNABR '422', '093', 'BAIXA DE TTULO DE OUTRA AGNCIA';
   EXEC INCLUI_ERRCNABR '422', '094', 'ENTRADA TTULO COBRANA DIRETA INVLIDA';
   EXEC INCLUI_ERRCNABR '422', '095', 'BAIXA DO TTULO INVLIDO';
   EXEC INCLUI_ERRCNABR '422', '096', 'VALOR DO TTULO INVLIDO';
   EXEC INCLUI_ERRCNABR '422', '097', 'MOEDA INVLIDA PARA BANCO CORRESPONDENTE';
   EXEC INCLUI_ERRCNABR '422', '098', 'PCB DO TFC DIVERGEMDA PCB DO COB';
   EXEC INCLUI_ERRCNABR '422', '099', 'INCLUSO DE TERCEIRA MOEDA INVLIDA';

-- Banco UNIBANCO 409

   EXEC INCLUI_ERRCNABR '409', '05', 'TIPO DE TRANSAO / CDIGO DO MOVIMENTO INVLIDO';
   EXEC INCLUI_ERRCNABR '409', '07', 'AGNCIA / CONTA E DGITO INVLIDO';
   EXEC INCLUI_ERRCNABR '409', '08', 'NOSSO NMERO INVLIDO';
   EXEC INCLUI_ERRCNABR '409', '09', 'NOSSO NMERO DUPLICADO';
   EXEC INCLUI_ERRCNABR '409', '10', 'CARTEIRA INVLIDA';
   EXEC INCLUI_ERRCNABR '409', '11', 'FORMA DE CADASTRAMENTO DO TTULO INVLIDA(CLIENTE NO  TROCA DE FITAS)';
   EXEC INCLUI_ERRCNABR '409', '12', 'TIPO DE DOCUMENTO INVLIDO';
   EXEC INCLUI_ERRCNABR '409', '13', 'IDENTIFICAO DE EMISSO DE BLOQUETO INVLIDO';
   EXEC INCLUI_ERRCNABR '409', '15', 'CARACTERSTICA COBRANA INCOMPATVEL';
   EXEC INCLUI_ERRCNABR '409', '16', 'DATA DE VENCIMENTO INVLIDA';
   EXEC INCLUI_ERRCNABR '409', '18', 'VENCIMENTO FORA DO PRAZO DE OPERAO';
   EXEC INCLUI_ERRCNABR '409', '20', 'VALOR DO TTULO INVLIDO';
   EXEC INCLUI_ERRCNABR '409', '21', 'ESPCIE DO TTULO INVLIDA';
   EXEC INCLUI_ERRCNABR '409', '23', 'ACEITE INVLIDO';
   EXEC INCLUI_ERRCNABR '409', '24', 'DATA DA EMISSO INVLIDA';
   EXEC INCLUI_ERRCNABR '409', '26', 'CDIGO DE JUROS DE MORA INVLIDO';
   EXEC INCLUI_ERRCNABR '409', '27', 'VALOR/TAXA JUROS DE MORA INVLIDO';
   EXEC INCLUI_ERRCNABR '409', '30', 'DESCONTO A CONCEDER NO CONFERE';
   EXEC INCLUI_ERRCNABR '409', '32', 'VALOR DO IOF INVLIDO';
   EXEC INCLUI_ERRCNABR '409', '33', 'VALOR DO ABATIMENTO INVLIDO';
   EXEC INCLUI_ERRCNABR '409', '34', 'VALOR DO ABATIMENTO MAIOR OU IGUAL AO VALOR DO TTULO';
   EXEC INCLUI_ERRCNABR '409', '35', 'ABATIMENTO A CONCEDER NO CONFERE';
   EXEC INCLUI_ERRCNABR '409', '36', 'ABATIMENTO J CONCEDIDO';
   EXEC INCLUI_ERRCNABR '409', '37', 'CDIGO PARA PROTESTO INVLIDO';
   EXEC INCLUI_ERRCNABR '409', '38', 'PRAZO PARA PROTESTO INVLIDO';
   EXEC INCLUI_ERRCNABR '409', '39', 'PEDIDO DE PROTESTO NO PERMITIDO PARA O TTULO';
   EXEC INCLUI_ERRCNABR '409', '41', 'PEDIDO DE CANCELAMENTO/SITUAO DE PROTESTO PARA TTULOS SEM INSTRUO DE PROTESTO';
   EXEC INCLUI_ERRCNABR '409', '42', 'CDIGO PARA BAIXA/DEVOLUO INVLIDA';
   EXEC INCLUI_ERRCNABR '409', '43', 'PRAZO PARA BAIXA/DEVOLUO INVLIDA ';
   EXEC INCLUI_ERRCNABR '409', '44', 'CDIGO DA MOEDA INVLIDA';
   EXEC INCLUI_ERRCNABR '409', '46', 'TIPO/NMERO DE INSCRIO INVLIDO';
   EXEC INCLUI_ERRCNABR '409', '48', 'CEP INVLIDO';
   EXEC INCLUI_ERRCNABR '409', '53', 'TIPO/NMERO DE INCRIO DO SACADOR/AVALISTA INVLIDOS';
   EXEC INCLUI_ERRCNABR '409', '57', 'CDIGO DA MULTA INVLIDO';
   EXEC INCLUI_ERRCNABR '409', '58', 'DATA DA MULTA INVLIDA';
   EXEC INCLUI_ERRCNABR '409', '60', 'MOVIMENTO PARA TTULO NO CADSTRADO';
   EXEC INCLUI_ERRCNABR '409', '61', 'AGNCIA ENCARREGADA DA COBRANA INVLIDA / BANCO DEPOSITRIO  BANCO CORRESPONDENTE';
   EXEC INCLUI_ERRCNABR '409', '99', 'OUTROS';

   -- Banco de Boston 479

   EXEC INCLUI_ERRCNABR '479','101','DATA DE EMISSO INVLIDA';
   EXEC INCLUI_ERRCNABR '479','102','DATA DE EMISSO MAIOR QUE A DATA DA OPERAO';
   EXEC INCLUI_ERRCNABR '479','103','DATA DE VENCIMENTO INVLIDA';
   EXEC INCLUI_ERRCNABR '479','105','PRMIO LQUIDO NO NUMRICO';
   EXEC INCLUI_ERRCNABR '479','106','PRMIO LQUIDO INCOMPATVEL COM ESPCIE';
   EXEC INCLUI_ERRCNABR '479','107','PRMIO LQUIDO NO INFORMADO';
   EXEC INCLUI_ERRCNABR '479','108','IOF NO NUMRICO';
   EXEC INCLUI_ERRCNABR '479','109','IOF INCOMPATVEL COM ESPCIE';
   EXEC INCLUI_ERRCNABR '479','110','VALOR DO TTULO INVLIDO';
   EXEC INCLUI_ERRCNABR '479','111','ACEITE INVLIDO';
   EXEC INCLUI_ERRCNABR '479','112','ACEITE NO PERMITIDO PARA ESPCIE';
   EXEC INCLUI_ERRCNABR '479','113','VALORES DE DESCONTOS NO NUMRICOS';
   EXEC INCLUI_ERRCNABR '479','114','ORDEM DO VALORES DESCONTOS INCOMPATVEIS';
   EXEC INCLUI_ERRCNABR '479','115','DATA DE VENCIMENTO MAIOR QUE DATA NEGOC. PARA DESCONTO';
   EXEC INCLUI_ERRCNABR '479','116','PERCENTUAL NO PERMITE VALOR ABATIMENTO';
   EXEC INCLUI_ERRCNABR '479','117','PERCENTUAL EXIGE DATA LIMITE';
   EXEC INCLUI_ERRCNABR '479','118','DATA DE DESCONTO INVLIDA';
   EXEC INCLUI_ERRCNABR '479','119','DATA DE DESCONTO MAIOR QUE DATA DE VENCIMENTO';
   EXEC INCLUI_ERRCNABR '479','120','DATA DE DESCONTO MENOR QUE DATA DE NEGOCIAO';
   EXEC INCLUI_ERRCNABR '479','121','DATA DESCONTO EXIGE ALGUM VALOR OU PERCENTUAL';
   EXEC INCLUI_ERRCNABR '479','122','VALOR BASE NO PERMITE VALOR DE ABATIMENTO';
   EXEC INCLUI_ERRCNABR '479','123','VALOE BASE EXIGE VALOR PERCENTUAL';
   EXEC INCLUI_ERRCNABR '479','124','VALOR BASE EXIGE DATA LIMITE';
   EXEC INCLUI_ERRCNABR '479','125','VALOR DO DESCONTO EXIGE DATA LIMITE';
   EXEC INCLUI_ERRCNABR '479','126','VALOR DO ABATIMENTO DEVE SER MENOR QUE O VALOR DO TTULO';
   EXEC INCLUI_ERRCNABR '479','127','VALOR DO ABATIMENTO NO PERMITE PERCENTUAL E VALOR BASE';
   EXEC INCLUI_ERRCNABR '479','128','NOME DO SACADO OBRIGATRIO';
   EXEC INCLUI_ERRCNABR '479','132','NOME DO SACADO NO DEVE SER INFORMADO PARA NOTA DE SEGURO';
   EXEC INCLUI_ERRCNABR '479','134','ENDEREO DO SACADO INVLIDO';
   EXEC INCLUI_ERRCNABR '479','137','CEP DO SACADO INVLIDO';
   EXEC INCLUI_ERRCNABR '479','138','IDENTIFICADOR DE REGISTRO INVLIDO';
   EXEC INCLUI_ERRCNABR '479','139','DIAS JURO/MULTA 1 MAIOR QUE DIAS JURO/MULTA 2';
   EXEC INCLUI_ERRCNABR '479','140','DIAS JURO/MULTA 2 MAIOR QUE DIAS JURO/MULTA 3';
   EXEC INCLUI_ERRCNABR '479','145','INSTRUO NA ENTRADA DO TTULO INVLIDA';
   EXEC INCLUI_ERRCNABR '479','146','NMERO DE DIAS NA ENTRADA INVLIDO';
   EXEC INCLUI_ERRCNABR '479','147','VALOR DE ABATIMENTO ENTRADA INVLIDO';
   EXEC INCLUI_ERRCNABR '479','148','VALOR DE ABATIMENTO ENTRADA TEM QUE SER MENOR QUE VALOR TTULO';
   EXEC INCLUI_ERRCNABR '479','156','TTULO DESCONTO  VISTA OU CONTRA APRESENTAO';
   EXEC INCLUI_ERRCNABR '479','158','NO EXISTE COTAO PARA MOEDA NA DATA DE EMISSO';
   EXEC INCLUI_ERRCNABR '479','159','DGITO DO NOSSO NMERO NO CONFERE';
   EXEC INCLUI_ERRCNABR '479','160','INTRUO INVLIDA - TTULO COM INSTRUO PROTESTAR';
   EXEC INCLUI_ERRCNABR '479','166','CEP NO PERTENCE AO BOSTON';
   EXEC INCLUI_ERRCNABR '479','181','MOEDA OU FATOR INVLIDO';
   EXEC INCLUI_ERRCNABR '479','187','CORR N/ TRAB C/ MOEDA FATOR OU CONTA N/ CAD CORRESPONDENTE';
   EXEC INCLUI_ERRCNABR '479','200','NOSSO NMERO NO RESERVADO PARA COBRANA RPIDA';
   EXEC INCLUI_ERRCNABR '479','202','CEP NO CADASTRADO';
   EXEC INCLUI_ERRCNABR '479','204','DATA DE NEGOCIAO NO  DIA TIL';
   EXEC INCLUI_ERRCNABR '479','205','ESPCIE TTULO PARA DESCONTO FUNC. ALTERADO PARA NP';
   EXEC INCLUI_ERRCNABR '479','207','TAXA DE DESCONTO INFORMADA PARA BORDER DE COBRANA/CAUO';
   EXEC INCLUI_ERRCNABR '479','208','CONTRATO NO LIGADO  CLIENTE';
   EXEC INCLUI_ERRCNABR '479','209','CONTRATO NO PERTENCE AO CLIENTE BORDER';
   EXEC INCLUI_ERRCNABR '479','210','TIPO DE BEM(FINANCIADO) NO CADASTRADO';
   EXEC INCLUI_ERRCNABR '479','213','NO FOI POSSVEL ENCONTRAR AG COBRADORA';
   EXEC INCLUI_ERRCNABR '479','214','NO EXISTE ESTADO-MUNICIPIO PARA O CEP';
   EXEC INCLUI_ERRCNABR '479','300','CDIGO DE MOVIMENTO INVLIDO';
   EXEC INCLUI_ERRCNABR '479','301','NOSSO NMERO INVLIDO';
   EXEC INCLUI_ERRCNABR '479','302','VALOR DO TTULO INVLIDO';
   EXEC INCLUI_ERRCNABR '479','303','DESCONTO/ABATIMENTO INVLIDO ';
   EXEC INCLUI_ERRCNABR '479','304','OUTRAS REDUES INVLIDA';
   EXEC INCLUI_ERRCNABR '479','305','LIQUIDAO / BAIXA / INSTRUO INIBIDA';
   EXEC INCLUI_ERRCNABR '479','306','RESSARCIMENTO INVLIDO';
   EXEC INCLUI_ERRCNABR '479','307','VALOR LQUIDO INVLIDO';
   EXEC INCLUI_ERRCNABR '479','308','JUROS / MULTA INVLIDO';
   EXEC INCLUI_ERRCNABR '479','309','OUTROS ACRSCIMOS INVLIDO';
   EXEC INCLUI_ERRCNABR '479','310','CDIGO DE MOVIMENTO DIFERENTE DE 0407';
   EXEC INCLUI_ERRCNABR '479','311','SEU NMERO OBRIGATRIO';
   EXEC INCLUI_ERRCNABR '479','312','INSTRUO VIA FITA INVLIDA';
   EXEC INCLUI_ERRCNABR '479','313','VALOR DA INSTRUO INVLIDO';
   EXEC INCLUI_ERRCNABR '479','314','DATA DE VENCIMENTO INSTRUO INVLIDA';
   EXEC INCLUI_ERRCNABR '479','315','SEU NMERO DA ISNTRUO OBRIGATRIO';
   EXEC INCLUI_ERRCNABR '479','316','USO DA EMPRESA OBRIGATRIO';
   EXEC INCLUI_ERRCNABR '479','317','CLCULO DGITO MDULO 11 NO REALIZADO';
   EXEC INCLUI_ERRCNABR '479','318','BAIXA / LIQUIDAO DE TTULO INEXISTENTE';
   EXEC INCLUI_ERRCNABR '479','319','INSTRUO PARA TTULO INEXISTENTE';
   EXEC INCLUI_ERRCNABR '479','321','INSTRUO PRORROGAO DE VENCTO. P/ TTULO LIQUIDADO';
   EXEC INCLUI_ERRCNABR '479','322','TTULO J CADASTRADO';
   EXEC INCLUI_ERRCNABR '479','324','INSTRUO PRORROGAO DE VENCTO. P/ TTULO BAIXADO';
   EXEC INCLUI_ERRCNABR '479','325','INSTRUO PRORROGAO DE VENCTO. P/ TTULO PROTESTADO';
   EXEC INCLUI_ERRCNABR '479','326','INSTRUO PRORROGAO DE VENCTO. P/ TTULO EM CARTRIO';
   EXEC INCLUI_ERRCNABR '479','332','VALOR DESCONTO/ABATIMENTO NO CONFERE COM O SISTEMA';
   EXEC INCLUI_ERRCNABR '479','333','BAIXA CRDITO DIRETO NO PERMITIDO PARA DESCONTO';
   EXEC INCLUI_ERRCNABR '479','334','INSTRUO NO PERMITIDA PARA BATCH-USE ONLINE';
   EXEC INCLUI_ERRCNABR '479','335','DESCONTO/ABATIMENTO NO PERMITINDO PARA LIQ. PARCIAL';
   EXEC INCLUI_ERRCNABR '479','336','JUROS/MULTA NO PERMITIDO P/ LIQUIDAO PARCIAL';
   EXEC INCLUI_ERRCNABR '479','338','INSTRUO NO ACATADA';
   EXEC INCLUI_ERRCNABR '479','340','VALOR LQUIDO DIFERE DP PAGAMENTO PARCIAL';
   EXEC INCLUI_ERRCNABR '479','341','TTULO NO EST EM CARTRIO';
   EXEC INCLUI_ERRCNABR '479','342','TTULO EST EM CARTRIO';
   EXEC INCLUI_ERRCNABR '479','343','TTULO J LIQUIDADO';
   EXEC INCLUI_ERRCNABR '479','344','TTULO J LIQUIDADO NESTE MOVIMENTO';
   EXEC INCLUI_ERRCNABR '479','345','CDIGO DE AVALISTA (1 OU 2) NO NUMRICO';
   EXEC INCLUI_ERRCNABR '479','346','AVALISTA NO EXISTE COMO CLIENTE';
   EXEC INCLUI_ERRCNABR '479','347','AVALISTA NO CADASTRADO COMO CLIENTE';
   EXEC INCLUI_ERRCNABR '479','352','VALOR DO TTULO INFORMADO NO BATE COM SALDO DEVEDOR';
   EXEC INCLUI_ERRCNABR '479','355','VERIFICAR DATA DE VENCIMENTO/TAXA TT. S/ CRED. CED.';
   EXEC INCLUI_ERRCNABR '479','356','MOME DO SACADO CONTEM CARACTER INVLIDO';
   EXEC INCLUI_ERRCNABR '479','357','ENTARDA TTULO FITA/MICRO P/ CEP NO BKB';
   EXEC INCLUI_ERRCNABR '479','358','PRODUTO NO EXISTE NO CORRESPONDENTE';
   EXEC INCLUI_ERRCNABR '479','360','FILIAL NO CADASTRADA P/ CORRESPONDENTE INFORMADO';
   EXEC INCLUI_ERRCNABR '479','361','TTULO NO PERTENCE AP CONVNIO INFORMADO';
   EXEC INCLUI_ERRCNABR '479','366','DATA DE EMISSO MAIOR QUE A DATA DE VENCIMENTO';

   -- Banco Real 275

   EXEC INCLUI_ERRCNABR '275','01','CDIGO DO BANCO INVLIDO';
   EXEC INCLUI_ERRCNABR '275','02','CDIGO DO REGISTRO DETALHE INVLIDO';
   EXEC INCLUI_ERRCNABR '275','03','CDIGO DO SEGMENTO INVLIDO';
   EXEC INCLUI_ERRCNABR '275','04','CDIGO DE MOVIMENTO NO PERMITIDO PARA CARTEIRA';
   EXEC INCLUI_ERRCNABR '275','05','CDIGO DE MOVIMENTO INVLIDO';
   EXEC INCLUI_ERRCNABR '275','06','TIPO/NMERO DE INSCRIO DO CEDENTE INVLIDOS';
   EXEC INCLUI_ERRCNABR '275','07','AGNCIA/CONTA/DV INVLIDO';
   EXEC INCLUI_ERRCNABR '275','08','NOSSO NMERO INVLIDO';
   EXEC INCLUI_ERRCNABR '275','09','NOSSO NMERO DUPLICADO';
   EXEC INCLUI_ERRCNABR '275','10','CARTEIRA INVLIDA';
   EXEC INCLUI_ERRCNABR '275','11','FORMA DE CADASTRAMENTO DO TTULO INVLIDO';
   EXEC INCLUI_ERRCNABR '275','12','TIPO DE DOCUMENTO INVLIDO';
   EXEC INCLUI_ERRCNABR '275','13','IDENTIFICAO DA EMISSO DO BLOQUETO INVLIDA';
   EXEC INCLUI_ERRCNABR '275','14','IDENTIFICAO DA DISTRIBUIO DO BLOQUETO INVLIDA';
   EXEC INCLUI_ERRCNABR '275','15','CARACTERSTICAS DA COBRANA INCOMPATVEIS';
   EXEC INCLUI_ERRCNABR '275','16','DATA DE VENCIMENTO INVLIDA';
   EXEC INCLUI_ERRCNABR '275','17','DATA DE VENCIMENTO ANTERIOR A DATA DE EMISSO';
   EXEC INCLUI_ERRCNABR '275','18','VENCIMENTO FORA DO PRAZO DE OPERAO';
   EXEC INCLUI_ERRCNABR '275','19','TTULO A CARGO DE BANCOS CORRESPONDENTES COM VENCIMENTO INFERIOR A XX DIAS';
   EXEC INCLUI_ERRCNABR '275','20','VALOR DO TTULO INVLIDO';
   EXEC INCLUI_ERRCNABR '275','21','ESPCIE DO TTULO INVLIDA';
   EXEC INCLUI_ERRCNABR '275','22','ESPCIE DO TTULO NO PERMITIDA PARA A CARTEIRA';
   EXEC INCLUI_ERRCNABR '275','23','ACEITE INVLIDO';
   EXEC INCLUI_ERRCNABR '275','24','DATA DA EMISSO INVLIDA';
   EXEC INCLUI_ERRCNABR '275','25','DATA DA EMISSO POSTERIOR A DATA DE ENTRADA';
   EXEC INCLUI_ERRCNABR '275','26','CDIGO DE JUROS DE MORA INVLIDO';
   EXEC INCLUI_ERRCNABR '275','27','VALOR/TAXA DE JUROS DE MORA INVLIDO';
   EXEC INCLUI_ERRCNABR '275','28','CDIGO DO DESCONTO INVLIDO';
   EXEC INCLUI_ERRCNABR '275','29','VALOR DO DESCONTO MAIOR OU IGUAL AO VALOR DO TTULO';
   EXEC INCLUI_ERRCNABR '275','30','DESCONTO A CONCEDER NO CONFERE';
   EXEC INCLUI_ERRCNABR '275','31','CONCESSO DE DESCONTO - J EXISTE DESCONTO ANTERIOR';
   EXEC INCLUI_ERRCNABR '275','32','VALOR DO IOF INVLIDO';
   EXEC INCLUI_ERRCNABR '275','33','VALOR DO ABATIMENTO INVLIDO';
   EXEC INCLUI_ERRCNABR '275','34','VALOR DO ABATIMENTO MAIOR OU IGUAL AO VALOR DO TTULO';
   EXEC INCLUI_ERRCNABR '275','35','VALOR A CONCEDER NO CONFERE';
   EXEC INCLUI_ERRCNABR '275','36','CONCESSO DE ABATIMENTO - J EXISTE ABATIMENTO ANTERIOR';
   EXEC INCLUI_ERRCNABR '275','37','CDIGO PARA PROTESTO INVLIDO';
   EXEC INCLUI_ERRCNABR '275','38','PRAZO PARA PROTESTO INVLIDO';
   EXEC INCLUI_ERRCNABR '275','39','PEDIDO DE PROTESTO NO PERMITIDO PARA O TTULO';
   EXEC INCLUI_ERRCNABR '275','40','TTULO COM ORDEM DE PROTESTO EMITIDA';
   EXEC INCLUI_ERRCNABR '275','41','PEDIDO DE CANCELAMENTO/SUSTAO PARA TTULOS SEM INSTRUO DE PROTESTO';
   EXEC INCLUI_ERRCNABR '275','42','CDIGO PARA BAIXA/DEVOLUO INVLIDO';
   EXEC INCLUI_ERRCNABR '275','43','PRAZO PARA BAIXA/DEVOLUO INVLIDO';
   EXEC INCLUI_ERRCNABR '275','44','CDIGO DA MOEDA INVLIDO ';
   EXEC INCLUI_ERRCNABR '275','45','NOME DO SACADO NO INFORMADO';
   EXEC INCLUI_ERRCNABR '275','46','TIPO/NMERO DE INSCRIO DO SACADO INVLIDOS';
   EXEC INCLUI_ERRCNABR '275','47','ENDEREO DO SACADO NO INFORMADO';
   EXEC INCLUI_ERRCNABR '275','48','CEP INVLIDO';
   EXEC INCLUI_ERRCNABR '275','49','CEP SEM PRAA DE COBRANA (NO LOCALIZADO)';
   EXEC INCLUI_ERRCNABR '275','50','CEP REFERENTE A UM BANCO CORRESPONDENTE';
   EXEC INCLUI_ERRCNABR '275','51','CEP INCOMPATVEL COM A UNIDADE DA FEDERAO';
   EXEC INCLUI_ERRCNABR '275','52','UNIDADE DA FEDERAO INVLIDA';
   EXEC INCLUI_ERRCNABR '275','53','TIPO/NMERO DE INSCRIO DO SACADOR/AVALISTA INVLIDOS';
   EXEC INCLUI_ERRCNABR '275','54','SACADOR/AVALISTA NO INFORMADO';
   EXEC INCLUI_ERRCNABR '275','55','NOSSO NMERO NO BANCO CORRESPONDENTE NO INFORMADO';
   EXEC INCLUI_ERRCNABR '275','56','CDIGO DO BANCO CORRESPONDENTE NO INFORMADO';
   EXEC INCLUI_ERRCNABR '275','57','CDIGO DA MULTA INVLIDO';
   EXEC INCLUI_ERRCNABR '275','58','DATA DA MULTA INVLIDA';
   EXEC INCLUI_ERRCNABR '275','59','VALOR/PERCENTUAL DA MULTA INVLIDO';
   EXEC INCLUI_ERRCNABR '275','60','MOVIMENTO PARA TTULO NO CADASTRADO';
   EXEC INCLUI_ERRCNABR '275','61','ALTERAO DA AGNCIA COBRADORA/DV INVLIDA';
   EXEC INCLUI_ERRCNABR '275','62','TIPO DE IMPRESSO INVLIDO';
   EXEC INCLUI_ERRCNABR '275','63','ENTRADA PARA TTULO J CADASTRADO';
   EXEC INCLUI_ERRCNABR '275','64','NMERO DA LINHA INVLIDO';
   EXEC INCLUI_ERRCNABR '275','65','CDIGO DO BANCO PARA DBITO INVLIDO';
   EXEC INCLUI_ERRCNABR '275','66','AGNCIA/CONTA/DV PARA DBITO INVLIDO';
   EXEC INCLUI_ERRCNABR '275','67','DADOS PARA DBITO INCOMPATVEL COM A IDENTIFICAO DA EMISSO DO BLOQUETO';
   EXEC INCLUI_ERRCNABR '275','68','DBITO AUTOMTICO AGENDADO';
   EXEC INCLUI_ERRCNABR '275','69','DBITO NO AGENDADO - ERRO NOS DADOS DA REMESSA';
   EXEC INCLUI_ERRCNABR '275','70','DBITO NO AGENDADO - SACADO NO CONSTA DO CADASTRO DE AUTORIZANTE';
   EXEC INCLUI_ERRCNABR '275','71','DBITO NO AGENDADO - CEDENTE NO AUTORIZADO PELO SACADO ';
   EXEC INCLUI_ERRCNABR '275','72','DBITO NO AGENDADO - CEDENTE NO PARTICIPA DA MODALIDADE DBITO AUTOMTICO';
   EXEC INCLUI_ERRCNABR '275','73','DBITO NO AGENDADO - CDIGO DE MOEDA DIFERENTE DE REAL (R$)';
   EXEC INCLUI_ERRCNABR '275','74','DBITO NO AGENDADO - DATA VENCIMENTO INVLIDA';
   EXEC INCLUI_ERRCNABR '275','75','DBITO NO AGENDADO, CONFORME SEU PEDIDO, TTULO NO REGISTRADO';
   EXEC INCLUI_ERRCNABR '275','76','DBITO NO AGENDADO, TIPO/NUM. INSCRIO DO DEBITADO, INVLIDO';
   EXEC INCLUI_ERRCNABR '275','77','TRANSFERNCIA PARA DESCONTO NO PERMITIDA PARA A CARTEIRA DO TTULO';
   EXEC INCLUI_ERRCNABR '275','78','DATA INFERIOR OU IGUAL AO VENCIMENTO PARA DBITO AUTOMTICO';
   EXEC INCLUI_ERRCNABR '275','79','DATA JUROS DE MORA INVLIDO';
   EXEC INCLUI_ERRCNABR '275','80','DATA DO DESCONTO INVLIDA';
   EXEC INCLUI_ERRCNABR '275','81','TENTATIVAS DE DBITO ESGOTADAS - BAIXADO';
   EXEC INCLUI_ERRCNABR '275','82','TENTATIVAS DE DBITO ESGOTADAS - PENDENTE';
   EXEC INCLUI_ERRCNABR '275','83','LIMITE EXCEDIDO';
   EXEC INCLUI_ERRCNABR '275','84','NMERO AUTORIZAO INEXISTENTE';
   EXEC INCLUI_ERRCNABR '275','85','TTULO COM PAGAMENTO VINCULADO';
   EXEC INCLUI_ERRCNABR '275','86','SEU NMERO INVLIDO';

   -- Banco Real 356

   EXEC INCLUI_ERRCNABR '356','01','CDIGO DO BANCO INVLIDO';
   EXEC INCLUI_ERRCNABR '356','02','CDIGO DO REGISTRO DETALHE INVLIDO';
   EXEC INCLUI_ERRCNABR '356','03','CDIGO DO SEGMENTO INVLIDO';
   EXEC INCLUI_ERRCNABR '356','04','CDIGO DE MOVIMENTO NO PERMITIDO PARA CARTEIRA';
   EXEC INCLUI_ERRCNABR '356','05','CDIGO DE MOVIMENTO INVLIDO';
   EXEC INCLUI_ERRCNABR '356','06','TIPO/NMERO DE INSCRIO DO CEDENTE INVLIDOS';
   EXEC INCLUI_ERRCNABR '356','07','AGNCIA/CONTA/DV INVLIDO';
   EXEC INCLUI_ERRCNABR '356','08','NOSSO NMERO INVLIDO';
   EXEC INCLUI_ERRCNABR '356','09','NOSSO NMERO DUPLICADO';
   EXEC INCLUI_ERRCNABR '356','10','CARTEIRA INVLIDA';
   EXEC INCLUI_ERRCNABR '356','11','FORMA DE CADASTRAMENTO DO TTULO INVLIDO';
   EXEC INCLUI_ERRCNABR '356','12','TIPO DE DOCUMENTO INVLIDO';
   EXEC INCLUI_ERRCNABR '356','13','IDENTIFICAO DA EMISSO DO BLOQUETO INVLIDA';
   EXEC INCLUI_ERRCNABR '356','14','IDENTIFICAO DA DISTRIBUIO DO BLOQUETO INVLIDA';
   EXEC INCLUI_ERRCNABR '356','15','CARACTERSTICAS DA COBRANA INCOMPATVEIS';
   EXEC INCLUI_ERRCNABR '356','16','DATA DE VENCIMENTO INVLIDA';
   EXEC INCLUI_ERRCNABR '356','17','DATA DE VENCIMENTO ANTERIOR A DATA DE EMISSO';
   EXEC INCLUI_ERRCNABR '356','18','VENCIMENTO FORA DO PRAZO DE OPERAO';
   EXEC INCLUI_ERRCNABR '356','19','TTULO A CARGO DE BANCOS CORRESPONDENTES COM VENCIMENTO INFERIOR A XX DIAS';
   EXEC INCLUI_ERRCNABR '356','20','VALOR DO TTULO INVLIDO';
   EXEC INCLUI_ERRCNABR '356','21','ESPCIE DO TTULO INVLIDA';
   EXEC INCLUI_ERRCNABR '356','22','ESPCIE DO TTULO NO PERMITIDA PARA A CARTEIRA';
   EXEC INCLUI_ERRCNABR '356','23','ACEITE INVLIDO';
   EXEC INCLUI_ERRCNABR '356','24','DATA DA EMISSO INVLIDA';
   EXEC INCLUI_ERRCNABR '356','25','DATA DA EMISSO POSTERIOR A DATA DE ENTRADA';
   EXEC INCLUI_ERRCNABR '356','26','CDIGO DE JUROS DE MORA INVLIDO';
   EXEC INCLUI_ERRCNABR '356','27','VALOR/TAXA DE JUROS DE MORA INVLIDO';
   EXEC INCLUI_ERRCNABR '356','28','CDIGO DO DESCONTO INVLIDO';
   EXEC INCLUI_ERRCNABR '356','29','VALOR DO DESCONTO MAIOR OU IGUAL AO VALOR DO TTULO';
   EXEC INCLUI_ERRCNABR '356','30','DESCONTO A CONCEDER NO CONFERE';
   EXEC INCLUI_ERRCNABR '356','31','CONCESSO DE DESCONTO - J EXISTE DESCONTO ANTERIOR';
   EXEC INCLUI_ERRCNABR '356','32','VALOR DO IOF INVLIDO';
   EXEC INCLUI_ERRCNABR '356','33','VALOR DO ABATIMENTO INVLIDO';
   EXEC INCLUI_ERRCNABR '356','34','VALOR DO ABATIMENTO MAIOR OU IGUAL AO VALOR DO TTULO';
   EXEC INCLUI_ERRCNABR '356','35','VALOR A CONCEDER NO CONFERE';
   EXEC INCLUI_ERRCNABR '356','36','CONCESSO DE ABATIMENTO - J EXISTE ABATIMENTO ANTERIOR';
   EXEC INCLUI_ERRCNABR '356','37','CDIGO PARA PROTESTO INVLIDO';
   EXEC INCLUI_ERRCNABR '356','38','PRAZO PARA PROTESTO INVLIDO';
   EXEC INCLUI_ERRCNABR '356','39','PEDIDO DE PROTESTO NO PERMITIDO PARA O TTULO';
   EXEC INCLUI_ERRCNABR '356','40','TTULO COM ORDEM DE PROTESTO EMITIDA';
   EXEC INCLUI_ERRCNABR '356','41','PEDIDO DE CANCELAMENTO/SUSTAO PARA TTULOS SEM INSTRUO DE PROTESTO';
   EXEC INCLUI_ERRCNABR '356','42','CDIGO PARA BAIXA/DEVOLUO INVLIDO';
   EXEC INCLUI_ERRCNABR '356','43','PRAZO PARA BAIXA/DEVOLUO INVLIDO';
   EXEC INCLUI_ERRCNABR '356','44','CDIGO DA MOEDA INVLIDO ';
   EXEC INCLUI_ERRCNABR '356','45','NOME DO SACADO NO INFORMADO';
   EXEC INCLUI_ERRCNABR '356','46','TIPO/NMERO DE INSCRIO DO SACADO INVLIDOS';
   EXEC INCLUI_ERRCNABR '356','47','ENDEREO DO SACADO NO INFORMADO';
   EXEC INCLUI_ERRCNABR '356','48','CEP INVLIDO';
   EXEC INCLUI_ERRCNABR '356','49','CEP SEM PRAA DE COBRANA (NO LOCALIZADO)';
   EXEC INCLUI_ERRCNABR '356','50','CEP REFERENTE A UM BANCO CORRESPONDENTE';
   EXEC INCLUI_ERRCNABR '356','51','CEP INCOMPATVEL COM A UNIDADE DA FEDERAO';
   EXEC INCLUI_ERRCNABR '356','52','UNIDADE DA FEDERAO INVLIDA';
   EXEC INCLUI_ERRCNABR '356','53','TIPO/NMERO DE INSCRIO DO SACADOR/AVALISTA INVLIDOS';
   EXEC INCLUI_ERRCNABR '356','54','SACADOR/AVALISTA NO INFORMADO';
   EXEC INCLUI_ERRCNABR '356','55','NOSSO NMERO NO BANCO CORRESPONDENTE NO INFORMADO';
   EXEC INCLUI_ERRCNABR '356','56','CDIGO DO BANCO CORRESPONDENTE NO INFORMADO';
   EXEC INCLUI_ERRCNABR '356','57','CDIGO DA MULTA INVLIDO';
   EXEC INCLUI_ERRCNABR '356','58','DATA DA MULTA INVLIDA';
   EXEC INCLUI_ERRCNABR '356','59','VALOR/PERCENTUAL DA MULTA INVLIDO';
   EXEC INCLUI_ERRCNABR '356','60','MOVIMENTO PARA TTULO NO CADASTRADO';
   EXEC INCLUI_ERRCNABR '356','61','ALTERAO DA AGNCIA COBRADORA/DV INVLIDA';
   EXEC INCLUI_ERRCNABR '356','62','TIPO DE IMPRESSO INVLIDO';
   EXEC INCLUI_ERRCNABR '356','63','ENTRADA PARA TTULO J CADASTRADO';
   EXEC INCLUI_ERRCNABR '356','64','NMERO DA LINHA INVLIDO';
   EXEC INCLUI_ERRCNABR '356','65','CDIGO DO BANCO PARA DBITO INVLIDO';
   EXEC INCLUI_ERRCNABR '356','66','AGNCIA/CONTA/DV PARA DBITO INVLIDO';
   EXEC INCLUI_ERRCNABR '356','67','DADOS PARA DBITO INCOMPATVEL COM A IDENTIFICAO DA EMISSO DO BLOQUETO';
   EXEC INCLUI_ERRCNABR '356','68','DBITO AUTOMTICO AGENDADO';
   EXEC INCLUI_ERRCNABR '356','69','DBITO NO AGENDADO - ERRO NOS DADOS DA REMESSA';
   EXEC INCLUI_ERRCNABR '356','70','DBITO NO AGENDADO - SACADO NO CONSTA DO CADASTRO DE AUTORIZANTE';
   EXEC INCLUI_ERRCNABR '356','71','DBITO NO AGENDADO - CEDENTE NO AUTORIZADO PELO SACADO ';
   EXEC INCLUI_ERRCNABR '356','72','DBITO NO AGENDADO - CEDENTE NO PARTICIPA DA MODALIDADE DBITO AUTOMTICO';
   EXEC INCLUI_ERRCNABR '356','73','DBITO NO AGENDADO - CDIGO DE MOEDA DIFERENTE DE REAL (R$)';
   EXEC INCLUI_ERRCNABR '356','74','DBITO NO AGENDADO - DATA VENCIMENTO INVLIDA';
   EXEC INCLUI_ERRCNABR '356','75','DBITO NO AGENDADO, CONFORME SEU PEDIDO, TTULO NO REGISTRADO';
   EXEC INCLUI_ERRCNABR '356','76','DBITO NO AGENDADO, TIPO/NUM. INSCRIO DO DEBITADO, INVLIDO';
   EXEC INCLUI_ERRCNABR '356','77','TRANSFERNCIA PARA DESCONTO NO PERMITIDA PARA A CARTEIRA DO TTULO';
   EXEC INCLUI_ERRCNABR '356','78','DATA INFERIOR OU IGUAL AO VENCIMENTO PARA DBITO AUTOMTICO';
   EXEC INCLUI_ERRCNABR '356','79','DATA JUROS DE MORA INVLIDO';
   EXEC INCLUI_ERRCNABR '356','80','DATA DO DESCONTO INVLIDA';
   EXEC INCLUI_ERRCNABR '356','81','TENTATIVAS DE DBITO ESGOTADAS - BAIXADO';
   EXEC INCLUI_ERRCNABR '356','82','TENTATIVAS DE DBITO ESGOTADAS - PENDENTE';
   EXEC INCLUI_ERRCNABR '356','83','LIMITE EXCEDIDO';
   EXEC INCLUI_ERRCNABR '356','84','NMERO AUTORIZAO INEXISTENTE';
   EXEC INCLUI_ERRCNABR '356','85','TTULO COM PAGAMENTO VINCULADO';
   EXEC INCLUI_ERRCNABR '356','86','SEU NMERO INVLIDO';

   -- Banco Banestes 021

   EXEC INCLUI_ERRCNABR '021','01','CDIGO DO BANCO INVLIDO';
   EXEC INCLUI_ERRCNABR '021','02','CDIGO DO REGISTRO DETALHE INVLIDO';
   EXEC INCLUI_ERRCNABR '021','03','CDIGO DO SEGMENTO INVLIDO';
   EXEC INCLUI_ERRCNABR '021','04','CDIGO DE MOVIMENTO NO PERMITIDO PARA CARTEIRA';
   EXEC INCLUI_ERRCNABR '021','05','CDIGO DE MOVIMENTO INVLIDO';
   EXEC INCLUI_ERRCNABR '021','06','TIPO/NMERO DE INSCRIO DO CEDENTE INVLIDOS';
   EXEC INCLUI_ERRCNABR '021','07','AGNCIA/CONTA/DV INVLIDO';
   EXEC INCLUI_ERRCNABR '021','08','NOSSO NMERO INVLIDO';
   EXEC INCLUI_ERRCNABR '021','09','NOSSO NMERO DUPLICADO';
   EXEC INCLUI_ERRCNABR '021','10','CARTEIRA INVLIDA';
   EXEC INCLUI_ERRCNABR '021','11','FORMA DE CADASTRAMENTO DO TTULO INVLIDO';
   EXEC INCLUI_ERRCNABR '021','12','TIPO DE DOCUMENTO INVLIDO';
   EXEC INCLUI_ERRCNABR '021','13','IDENTIFICAO DA EMISSO DO BLOQUETO INVLIDA';
   EXEC INCLUI_ERRCNABR '021','14','IDENTIFICAO DA DISTRIBUIO (POSTAGEM) DO BLOQUETO INVLIDA';
   EXEC INCLUI_ERRCNABR '021','15','CARACTERSTICAS DA COBRANA INCOMPATVEIS';
   EXEC INCLUI_ERRCNABR '021','16','DATA DE VENCIMENTO INVLIDA';
   EXEC INCLUI_ERRCNABR '021','17','DATA DE VENCIMENTO ANTERIOR ADATA DE EMISSO ';
   EXEC INCLUI_ERRCNABR '021','18','VENCIMENTO FORA DO PRAZO DE OPERAO';
   EXEC INCLUI_ERRCNABR '021','19','TTULO A CARGO DE BANCOS CORRESPONDENTES COM VENCIMENTO INFERIOR A XX DIAS';
   EXEC INCLUI_ERRCNABR '021','20','VALOR DO TTULO INVLIDO';
   EXEC INCLUI_ERRCNABR '021','21','ESPCIE DO TTULO INVLIDA';
   EXEC INCLUI_ERRCNABR '021','22','ESPCIE DO TTULO NO PERMITIDA PARA A CARTEIRA';
   EXEC INCLUI_ERRCNABR '021','23','ACEITE INVLIDO';
   EXEC INCLUI_ERRCNABR '021','24','DATA DA EMISSO INVLIDA';
   EXEC INCLUI_ERRCNABR '021','25','DATA DA EMISSO POSTERIOR A DATA DE ENTRADA';
   EXEC INCLUI_ERRCNABR '021','26','CDIGO DE JUROS DE MORA INVLIDO';
   EXEC INCLUI_ERRCNABR '021','27','VALOR/TAXA DE JUROS DE MORA INVLIDO';
   EXEC INCLUI_ERRCNABR '021','28','CDIGO DO DESCONTO INVLIDO';
   EXEC INCLUI_ERRCNABR '021','29','VALOR DO DESCONTO MAIOR OU IGUAL AO VALOR DO TTULO';
   EXEC INCLUI_ERRCNABR '021','30','DESCONTO A CONCEDER NO CONFERE';
   EXEC INCLUI_ERRCNABR '021','31','CONCESSO DE DESCONTO - J EXISTE DESCONTO ANTERIOR';
   EXEC INCLUI_ERRCNABR '021','32','VALOR DO IOF INVLIDO';
   EXEC INCLUI_ERRCNABR '021','33','VALOR DO ABATIMENTO INVLIDO';
   EXEC INCLUI_ERRCNABR '021','34','VALOR DO ABATIMENTO MAIOR OU IGUAL AO VALOR DO TTULO';
   EXEC INCLUI_ERRCNABR '021','35','VALOR A CONCEDER NO CONFERE';
   EXEC INCLUI_ERRCNABR '021','36','CONCESSO DE ABATIMENTO - J EXISTE ABATIMENTO ANTERIOR';
   EXEC INCLUI_ERRCNABR '021','37','CDIGO PARA PROTESTO INVLIDO';
   EXEC INCLUI_ERRCNABR '021','38','PRAZO PARA PROTESTO INVLIDO';
   EXEC INCLUI_ERRCNABR '021','39','PEDIDO DE PROTESTO NO PERMITIDO PARA O TTULO';
   EXEC INCLUI_ERRCNABR '021','40','TTULO COM ORDEM DE PROTESTO EMITIDA';
   EXEC INCLUI_ERRCNABR '021','41','PEDIDO DE CANCELAMENTO / SUSTAO PARA TTULOS SEM INSTRUO DE PROTESTO';
   EXEC INCLUI_ERRCNABR '021','42','CDIGO PARA BAIXA / DEVOLUO INVLIDO';
   EXEC INCLUI_ERRCNABR '021','43','PRAZO PARA BAIXA / DEVOLUO INVLIDO';
   EXEC INCLUI_ERRCNABR '021','44','CDIGO DA MOEDA INVLIDO';
   EXEC INCLUI_ERRCNABR '021','45','NOME DO SACADO NO INFORMADO';
   EXEC INCLUI_ERRCNABR '021','46','TIPO / NMERO DE INSCRIO DO SACADO INVLIDOS';
   EXEC INCLUI_ERRCNABR '021','47','ENDEREO DO SACADO NO INFORMADO';
   EXEC INCLUI_ERRCNABR '021','48','CEP INVLIDO';
   EXEC INCLUI_ERRCNABR '021','49','CEP SEM PRAA DE COBRANA (NO LOCALIZADO)';
   EXEC INCLUI_ERRCNABR '021','50','CEP REFERENTE A UM BANCOCORRESPONDENTE';
   EXEC INCLUI_ERRCNABR '021','51','CEP INCOMPATVEL COM A UNIDADE DA FEDERAO';
   EXEC INCLUI_ERRCNABR '021','52','UNIDADE DA FEDERAO INVLIDA';
   EXEC INCLUI_ERRCNABR '021','53','TIPO / NMERO DE INSCRIO DO SACADOR / AVALISTA INVLIDOS';
   EXEC INCLUI_ERRCNABR '021','54','SACADOR / AVALISTA NO INFORMADO';
   EXEC INCLUI_ERRCNABR '021','55','NOSSO NMERO NO BANCO CORRESPONDENTE NO INFORMADO';
   EXEC INCLUI_ERRCNABR '021','56','CDIGO DO BANCO CORRESPONDENTE NO INFORMADO';
   EXEC INCLUI_ERRCNABR '021','57','CDIGO DA MULTA INVLIDO';
   EXEC INCLUI_ERRCNABR '021','58','DATA DA MULTA INVLIDA';
   EXEC INCLUI_ERRCNABR '021','59','VALOR / PERCENTUAL DA MULTA INVLIDO';
   EXEC INCLUI_ERRCNABR '021','60','MOVIMENTO PARA TTULO NO CADASTRADO';
   EXEC INCLUI_ERRCNABR '021','61','ALTERAO DA AGNCIA COBRADORA / DV INVLIDA';
   EXEC INCLUI_ERRCNABR '021','62','TIPO DE IMPRESSO INVLIDO';
   EXEC INCLUI_ERRCNABR '021','63','ENTRADA PARA TTULO J CADASTRADO';
   EXEC INCLUI_ERRCNABR '021','64','NMERO DA LINHA INVLIDO';
   EXEC INCLUI_ERRCNABR '021','65','CDIGO DO BANCO PARA DBITO INVLIDO';
   EXEC INCLUI_ERRCNABR '021','66','AGNCIA / CONTA / DV PARA DBITO INVLIDO';
   EXEC INCLUI_ERRCNABR '021','67','DADOS PARA DBITO INCOMPATVEL COM A IDENTIFICAO DA EMISSO DO BLOQUETO';
   EXEC INCLUI_ERRCNABR '021','68','DBITO AUTOMTICO AGENDADO';
   EXEC INCLUI_ERRCNABR '021','69','DBITO NO AGENDADO - ERRO NOS DADOS DA REMESSA';
   EXEC INCLUI_ERRCNABR '021','70','DBITO NO AGENDADO - SACADO NO CONSTA DO CADASTRO DE AUTORIZANTE';
   EXEC INCLUI_ERRCNABR '021','71','DBITO NO SGENDADO - CEDENTE NO AUTORIZADO PELO SACADO';
   EXEC INCLUI_ERRCNABR '021','72','DBITO NO AGENDADO - CEDENTE NO PARTICIPA DA MODALIDADE DBITO AUTOMTICO';
   EXEC INCLUI_ERRCNABR '021','73','DBITO NO AGENDADO - CDIGO DE MOEDA DIFERENTE DE REAL (R$)';
   EXEC INCLUI_ERRCNABR '021','74','DBITO NO AGENDADO - DATA VENCIMENTO INVLIDA';
   EXEC INCLUI_ERRCNABR '021','75','DBITO NO AGENDADO, CONFORME SEU PEDIDO, TTULO NO REGISTRADO';
   EXEC INCLUI_ERRCNABR '021','76','DBITO NO AGENDADO, TIPO / NUM. INSCRIO DO DEBITADO, INVLIDO';
   EXEC INCLUI_ERRCNABR '021','77','TRANSFERNCIA PARA DESCONTO NO PERMITIDA PARA A CARTEIRA DO TTULO';
   EXEC INCLUI_ERRCNABR '021','78','DATA INFERIOR OU IGUAL AO VENCIMENTO PARA DBITO AUTOMTICO';
   EXEC INCLUI_ERRCNABR '021','79','DATA DO JUROS DE MORA INVLIDO';
   EXEC INCLUI_ERRCNABR '021','80','DATA DO DESCONTO INVLIDA';
   EXEC INCLUI_ERRCNABR '021','81','TENTATIVAS DE DBITO ESGOTADAS - BAIXADO';
   EXEC INCLUI_ERRCNABR '021','82','TENTATIVAS DE DBITO ESGOTADAS - PENDENTE';
   EXEC INCLUI_ERRCNABR '021','83','LIMITE EXCEDIDO';
   EXEC INCLUI_ERRCNABR '021','84','NMERO AUTORIZAO INEXISTENTE';
   EXEC INCLUI_ERRCNABR '021','85','TTULO COM PAGAMENTO VINCULADO';
   EXEC INCLUI_ERRCNABR '021','86','SEU NMERO INVLIDO';
   EXEC INCLUI_ERRCNABR '021','98','ERRO NA FORMAO DO CARN';
   EXEC INCLUI_ERRCNABR '021','0199','[REMESSA REJEITADA] REMESSA EM DUPLICIDADE';
   EXEC INCLUI_ERRCNABR '021','0299','[REMESSA REJEITADA] ERRO NA SEQNCIA DO REGISTRO';
   EXEC INCLUI_ERRCNABR '021','0399','[REMESSA REJEITADA] CDIGO DO BANCO INVLIDO';
   EXEC INCLUI_ERRCNABR '021','0499','[REMESSA REJEITADA] CEDENTE NO CADASTRADO';
   EXEC INCLUI_ERRCNABR '021','0599','[REMESSA REJEITADA] REGISTRO NO  "HEADER"';
   EXEC INCLUI_ERRCNABR '021','0699','[REMESSA REJEITADA] ARQUIVO NO  REMESSA';
   EXEC INCLUI_ERRCNABR '021','0799','[REMESSA REJEITADA] SERVIO NO  COBRANA';
   EXEC INCLUI_ERRCNABR '021','0899','[REMESSA REJEITADA] CONTA CORRENTE DIFERENTE DO REGISTRO "HEADER"';
   EXEC INCLUI_ERRCNABR '021','0999','[REMESSA REJEITADA] CDIGO DE OCORRNCIA INVLIDO';
   EXEC INCLUI_ERRCNABR '021','1099','[REMESSA REJEITADA] ERRO NA SEQNCIA DO LOTE';
   EXEC INCLUI_ERRCNABR '021','1199','[REMESSA REJEITADA] NMERO DO LOTE DO REGISTRO "DETALHES"DIFERE DO REGISTRO DE "HEADER"';
   EXEC INCLUI_ERRCNABR '021','1299','[REMESSA REJEITADA] FALTA REGISTRO DE "TRAILLER" DO ARQUIVO';
   EXEC INCLUI_ERRCNABR '021','1399','[REMESSA REJEITADA] NMERO DO LOTE DO REGISTRO "TRAILLER" DIFERE DO REGISTRO DE "HEADER"';
   EXEC INCLUI_ERRCNABR '021','1499','[REMESSA REJEITADA] ERRO NA QUANTIDADE DE REGISTRO DO LOTE';
   EXEC INCLUI_ERRCNABR '021','1599','[REMESSA REJEITADA] NMERO DO LOTE DO REGISTRO "TRAILLER" INVLIDO';
   EXEC INCLUI_ERRCNABR '021','1699','[REMESSA REJEITADA] ERRO NA QUANTIDADE DE LOTES DO ARQUIVO';
   EXEC INCLUI_ERRCNABR '021','1799','[REMESSA REJEITADA] CDIGO DO SEGMENTO FORA DE ORDEM';
   EXEC INCLUI_ERRCNABR '021','1899','[REMESSA REJEITADA] CDIGO DO REGISTRO FORA DE ORDEM';
   EXEC INCLUI_ERRCNABR '021','1999','[REMESSA REJEITADA] CDIGO DO REGISTRO INVLIDO';
   EXEC INCLUI_ERRCNABR '021','9999','[REMESSA REJEITADA] OUTROS MOTIVOS';

--Banco Caixa Econmica Federal

  EXEC INCLUI_ERRCNABR '104','01','CDIGO DO BANCO INVLIDO';
  EXEC INCLUI_ERRCNABR '104','02','CODIGO DO REGISTRO DETALHE INVALIDO';
  EXEC INCLUI_ERRCNABR '104','03','CODIGO DO SEGMENTO INVALIDO';
  EXEC INCLUI_ERRCNABR '104','05','CODIGO DE MOVIMENTO INVALIDO.';
  EXEC INCLUI_ERRCNABR '104','06','TIPO/NMERO DE INSCRIO DO CEDENTE INVLIDOS.';
  EXEC INCLUI_ERRCNABR '104','07','AGNCIA/CONTA/DV INVALIDO.';
  EXEC INCLUI_ERRCNABR '104','08','NOSSO NMERO INVLIDO.';
  EXEC INCLUI_ERRCNABR '104','09','NOSSO NMERO DUPLICADO.';
  EXEC INCLUI_ERRCNABR '104','10','CARTEIRA INVLIDA.';
  EXEC INCLUI_ERRCNABR '104','11','FORMA DE CADASTRAMENTO DO TTULO INVLIDO.';
  EXEC INCLUI_ERRCNABR '104','12','TIPO DE DOCUMENTO INVLIDO.';
  EXEC INCLUI_ERRCNABR '104','13','IDENTIFICAO DA EMISSO DO BLOQUETO INVLIDA.';
  EXEC INCLUI_ERRCNABR '104','14','IDENTIFICAO DA DISTRIBUIO DO BLOQUETO INVLIDA.';
  EXEC INCLUI_ERRCNABR '104','15','CARACTERSTICAS DE COBRANA INCOMPATVEIS.';
  EXEC INCLUI_ERRCNABR '104','16','DATA DE VENCIMENTO INVLIDA.';
  EXEC INCLUI_ERRCNABR '104','20','VALOR DO TTULO INVLID0.';
  EXEC INCLUI_ERRCNABR '104','21','ESPCIE DE TTULO INVLIDA.';
  EXEC INCLUI_ERRCNABR '104','23','ACEITE INVLIDO.';
  EXEC INCLUI_ERRCNABR '104','24','DATA DE EMISSO INVLIDA.';
  EXEC INCLUI_ERRCNABR '104','26','CDIGO DE JUROS DE MORA INVLIDO.';
  EXEC INCLUI_ERRCNABR '104','27','VALOR/TAXA DE JUROS DE MORA INVLIDO.';
  EXEC INCLUI_ERRCNABR '104','28','CDIGO DE DESCONTO INVLIDO.';
  EXEC INCLUI_ERRCNABR '104','29','VALOR DE DESCONTO MAIOR OU IGUAL AO VALOR DO TTULO.';
  EXEC INCLUI_ERRCNABR '104','30','DESCONTO A CONCEDER NO CONFERE.';
  EXEC INCLUI_ERRCNABR '104','32','VALOR DO IOF INVLIDO.';
  EXEC INCLUI_ERRCNABR '104','33','VALOR DO ABATIMENTO INVLIDO.';
  EXEC INCLUI_ERRCNABR '104','37','CDIGO PARA PROTESTO INVLIDO.';
  EXEC INCLUI_ERRCNABR '104','38','PRAZO PARA PROTESTO INVLIDO.';
  EXEC INCLUI_ERRCNABR '104','40','TTULO COM ORDEM DE PROTESTO EMITIDA.';
  EXEC INCLUI_ERRCNABR '104','42','CDIGO PARA BAIXA/DEVOLUO INVLIDO.';
  EXEC INCLUI_ERRCNABR '104','43','PRAZO PARA BAIXA/DEVOLUO INVLIDO.';
  EXEC INCLUI_ERRCNABR '104','44','CDIGO DA MOEDA INVLIDO.';
  EXEC INCLUI_ERRCNABR '104','45','NOME DO SACADO NO INFORMADO.';
  EXEC INCLUI_ERRCNABR '104','46','TIPO/NMERO DE INSCRIO DO SACADO INVLIDOS.';
  EXEC INCLUI_ERRCNABR '104','47','ENDEREO DO SACADO NO INFORMADO.';
  EXEC INCLUI_ERRCNABR '104','48','CEP INVLIDO.';
  EXEC INCLUI_ERRCNABR '104','49','CEP SEM PRAA DE COBRANA ,NO LOCALIZADO.';
  EXEC INCLUI_ERRCNABR '104','52','UNIDADE DA FEDERAO INVLIDA.';
  EXEC INCLUI_ERRCNABR '104','53','TIPO/NMERO DE INSCRIO DO SACADOR/AVALISTA INVLIDOS.';
  EXEC INCLUI_ERRCNABR '104','57','CDIGO DA MULTA INVLIDO.';
  EXEC INCLUI_ERRCNABR '104','58','DATA DA MULTA INVLIDA.';
  EXEC INCLUI_ERRCNABR '104','59','VALOR/PERCENTUAL DA MULTA INVLIDO.';
  EXEC INCLUI_ERRCNABR '104','60','MOVIMENTO PARA TTULO NO CADASTRADO.';
  EXEC INCLUI_ERRCNABR '104','61','AGNCIA COBRADORA INVLIDA.';
  EXEC INCLUI_ERRCNABR '104','62','TIPO DE IMPRESSO INVLIDO.';
  EXEC INCLUI_ERRCNABR '104','63','ENTRADA PARA TTULO J CADASTRADO.';  
  EXEC INCLUI_ERRCNABR '104','68','MOVIMENTAO INVLIDA PARA O TTULO.';
  EXEC INCLUI_ERRCNABR '104','69','ALTERAO DE DADOS INVLIDA.';
  EXEC INCLUI_ERRCNABR '104','70','APELIDO DO CLIENTE NO CADASTRADO.';
  EXEC INCLUI_ERRCNABR '104','71','ERRO NA COMPOSIO DO ARQUIVO.';
  EXEC INCLUI_ERRCNABR '104','72','LOTE DE SERVIO INVLIDO.';
  EXEC INCLUI_ERRCNABR '104','73','CDIGO DO CEDENTE INVLIDO.';
  EXEC INCLUI_ERRCNABR '104','74','CEDENTE NO PERTENCE A COBRANA  ELETRNICA/APELIDO NO CONFERE COM CEDENTE.';
  EXEC INCLUI_ERRCNABR '104','75','NOME DA EMPRESA INVLIDO.';
  EXEC INCLUI_ERRCNABR '104','76','NOME DO BANCO INVLIDO.';
  EXEC INCLUI_ERRCNABR '104','77','CDIGO DA REMESSA INVLIDO.';
  EXEC INCLUI_ERRCNABR '104','78','DATA/HORA DA GERAO DO ARQUIVO INVLIDA.';
  EXEC INCLUI_ERRCNABR '104','79','NMERO SEQUENCIAL DO ARQUIVO INVLIDO.';
  EXEC INCLUI_ERRCNABR '104','80','NMERO DA VERSO DO LAYOUT DO ARQUIVO/LOTE INVLIDO.';
  EXEC INCLUI_ERRCNABR '104','81','LITERAL REMESSA-TESTE VLIDA SOMENTE PARA FASE DE TESTES.';
  EXEC INCLUI_ERRCNABR '104','82','LITERAL REMESSA-TESTE OBRIGATRIO PARA FASE DE TESTES.'; 
  EXEC INCLUI_ERRCNABR '104','83','TIPO/NMERO DA INSCRIO DA EMPRESA INVLIDOS.';
  EXEC INCLUI_ERRCNABR '104','84','TIPO DE OPERAO INVLIDO.';
  EXEC INCLUI_ERRCNABR '104','85','TIPO DE SERVIO INVLIDO.';
  EXEC INCLUI_ERRCNABR '104','86','FORMA DE LANAMENTO INVLIDO.';
  EXEC INCLUI_ERRCNABR '104','87','NMERO DA REMESSA INVLIDO.';
  EXEC INCLUI_ERRCNABR '104','88','NMERO DA REMESSA MENOR/IGUAL QUE DA REMESSA ANTERIOR.';
  EXEC INCLUI_ERRCNABR '104','89','LOTE DE SERVIO DIVERGENTE.';
  EXEC INCLUI_ERRCNABR '104','90','NMERO SEQUENCIAL DO REGISTRO INVLIDO.';
  EXEC INCLUI_ERRCNABR '104','91','ERRO NA SEQUENCIAL DO SEGMENTO DO REGISTRO DETALHE.';
  EXEC INCLUI_ERRCNABR '104','92','CDIGO DE MOVIMENTO DIVERGENTE ENTRE GRUPO DE SEGMENTOS INVLIDO.';

-- BANCO PORTUGUES 069

   EXEC INCLUI_ERRCNABR '069', '001', 'Cdigo do Banco invlido';
   EXEC INCLUI_ERRCNABR '069', '002', 'Cdigo do registro detalhe invlido';
   EXEC INCLUI_ERRCNABR '069', '004', 'Cdigo de ocorrncia no permitido para a carteira';
   EXEC INCLUI_ERRCNABR '069', '005', 'Cdigo de ocorrncia no numrico';
   EXEC INCLUI_ERRCNABR '069', '007', 'Agncia/Conta/dgito invlidos';
   EXEC INCLUI_ERRCNABR '069', '008', 'Nosso nmero invlido';
   EXEC INCLUI_ERRCNABR '069', '009', 'Banco Agncia Conta beneficirio no numrico';
   EXEC INCLUI_ERRCNABR '069', '010', 'Carteira invlida';
   EXEC INCLUI_ERRCNABR '069', '015', 'Caractersticas da cobrana incompatveis';
   EXEC INCLUI_ERRCNABR '069', '016', 'Data de vencimento invlida';
   EXEC INCLUI_ERRCNABR '069', '017', 'Data de vencimento anterior a data de emisso';
   EXEC INCLUI_ERRCNABR '069', '018', 'Vencimento fora do prazo de operao';
   EXEC INCLUI_ERRCNABR '069', '020', 'Valor do ttulo invlido';
   EXEC INCLUI_ERRCNABR '069', '021', 'Espcie do Ttulo invlida';
   EXEC INCLUI_ERRCNABR '069', '022', 'Espcie no permitida para a carteira';
   EXEC INCLUI_ERRCNABR '069', '024', 'Data de emisso invlida';
   EXEC INCLUI_ERRCNABR '069', '028', 'Cdigo de desconto via TeleBpn invlido';
   EXEC INCLUI_ERRCNABR '069', '029', 'Valor do desconto maior/igual ao valor do Ttulo';
   EXEC INCLUI_ERRCNABR '069', '030', 'Desconto a conceder no confere';
   EXEC INCLUI_ERRCNABR '069', '031', 'Concesso de desconto - J existe desconto anterior';
   EXEC INCLUI_ERRCNABR '069', '033', 'Valor do abatimento invlido';
   EXEC INCLUI_ERRCNABR '069', '034', 'Valor do abatimento maior/igual ao valor do Ttulo';
   EXEC INCLUI_ERRCNABR '069', '036', 'Concesso abatimento - J existe abatimento anterior';
   EXEC INCLUI_ERRCNABR '069', '038', 'Prazo para protesto invlido';
   EXEC INCLUI_ERRCNABR '069', '039', 'Pedido de protesto no permitido para o Ttulo';
   EXEC INCLUI_ERRCNABR '069', '040', 'Ttulo com ordem de protesto emitido';
   EXEC INCLUI_ERRCNABR '069', '041', 'Pedido cancelamento/sustao para Ttulo sem instruo de protesto';
   EXEC INCLUI_ERRCNABR '069', '042', 'Cdigo para baixa/devoluo invlido';
   EXEC INCLUI_ERRCNABR '069', '045', 'Nome do Sacado no informado';
   EXEC INCLUI_ERRCNABR '069', '046', 'Tipo/nmero de inscrio do Sacado invlidos';
   EXEC INCLUI_ERRCNABR '069', '047', 'Endereo do Sacado no informado';
   EXEC INCLUI_ERRCNABR '069', '048', 'CEP Invlido';
   EXEC INCLUI_ERRCNABR '069', '050', 'CEP referente a um Banco correspondente';
   EXEC INCLUI_ERRCNABR '069', '053', 'Tipo de inscrio do sacador avalista invlidos';
   EXEC INCLUI_ERRCNABR '069', '060', 'Movimento para Ttulo no cadastrado';
   EXEC INCLUI_ERRCNABR '069', '077', 'Transferncia para desconto no permitido para a carteira';
   EXEC INCLUI_ERRCNABR '069', '085', 'Ttulo com pagamento vinculado';
   EXEC INCLUI_ERRCNABR '069', '086', 'Seu nmero invlido';

-- Banco BANRISUL 041

   EXEC INCLUI_ERRCNABR '041', '01', 'CDIGO DO BANCO INVLIDO';
   EXEC INCLUI_ERRCNABR '041', '02', 'CDIGO DE REGISTRO DETALHE INVLIDO';
   EXEC INCLUI_ERRCNABR '041', '03', 'CDIGO DO SEGMENTO INVLIDO';
   EXEC INCLUI_ERRCNABR '041', '04', 'CDIGO DO MOVIMENTO NO PERMITIDO PARA A CARTEIRA';
   EXEC INCLUI_ERRCNABR '041', '05', 'CDIGO DO MOVIMENTO INVLIDO';
   EXEC INCLUI_ERRCNABR '041', '06', 'TIPO/NMERO DE INSCRIO DO CEDENTE INVLIDO';
   EXEC INCLUI_ERRCNABR '041', '07', 'AGNCIA/CONTA/DV INVLIDO';
   EXEC INCLUI_ERRCNABR '041', '08', 'NOSSO NMERO INVLIDO';
   EXEC INCLUI_ERRCNABR '041', '09', 'NOSSO NMERO DUPLICADO';
   EXEC INCLUI_ERRCNABR '041', '10', 'CARTEIRA INVLIDA';
   EXEC INCLUI_ERRCNABR '041', '11', 'FORMA DE CADASTRAMENTO DO TTULO INVLIDO';
   EXEC INCLUI_ERRCNABR '041', '12', 'TIPO DE DOCUMENTO INVLIDO';
   EXEC INCLUI_ERRCNABR '041', '13', 'IDENTIFICAO DA EMISSO DO BLOQUETO INVLIDO';
   EXEC INCLUI_ERRCNABR '041', '14', 'IDENTIFICAO DA DISTRIBUIO DO BLOQUETO INVLIDO';
   EXEC INCLUI_ERRCNABR '041', '15', 'CARACTERSTICAS DA COBRANA INCOMPATVEIS - CARTEIRA/MOEDA:';
   EXEC INCLUI_ERRCNABR '041', '16', 'DATA DE VENCIMENTO INVLIDA:';
   EXEC INCLUI_ERRCNABR '041', '17', 'DATA DE VENCIMENTO ANTERIOR A DATA DE EMISSO';
   EXEC INCLUI_ERRCNABR '041', '18', 'VENCIMENTO FORA DO PRAZO DE OPERAO';
   EXEC INCLUI_ERRCNABR '041', '19', 'TTULO A CARGO DE BANCOS CORRESPONDENTES COM VENCIMENTO INFERIOR A XX DIAS';
   EXEC INCLUI_ERRCNABR '041', '20', 'VALOR DO TTULO INVLIDO (NO NUMRICO)';
   EXEC INCLUI_ERRCNABR '041', '21', 'ESPCIE DO TTULO INVLIDA (ARQUIVO DE REGISTRO)';
   EXEC INCLUI_ERRCNABR '041', '22', 'ESPCIE NO PERMETIDA PARA A CARTEIRA';
   EXEC INCLUI_ERRCNABR '041', '23', 'ACEITE INVLIDO - VERIFICA CONTEDO VLIDO';
   EXEC INCLUI_ERRCNABR '041', '24', 'DATA DE EMISSO INVLIDA - VERIFICA SE A DATA  NUMRICA E SE EST NO FORMATO VLIDO';
   EXEC INCLUI_ERRCNABR '041', '25', 'DATA DE EMISSO POSTERIOR A DATA DE PROCESSAMENTO';
   EXEC INCLUI_ERRCNABR '041', '26', 'CDIGO DE JUROS DE MORA INVLIDO';
   EXEC INCLUI_ERRCNABR '041', '27', 'VALOR/TAXA DE JUROS DE MORA INVLIDO';
   EXEC INCLUI_ERRCNABR '041', '28', 'CDIGO DO DESCONTO INVLIDO';
   EXEC INCLUI_ERRCNABR '041', '29', 'VALOR DO DESCONTO MAIOR OU IGUAL AO VALOR DO TTULO';
   EXEC INCLUI_ERRCNABR '041', '30', 'DESCONTO A CONCEDER NO CONFERE:';
   EXEC INCLUI_ERRCNABR '041', '32', 'VALOR DO IOF INVLIDO';
   EXEC INCLUI_ERRCNABR '041', '33', 'VALOR DO ABATIMENTO INVLIDO';
   EXEC INCLUI_ERRCNABR '041', '34', 'VALOR DO ABATIMENTO MAIOR OU IGUAL AO VALOR DO TTULO';
   EXEC INCLUI_ERRCNABR '041', '35', 'ABATIMENTO A CONCEDER NO CONFERE';
   EXEC INCLUI_ERRCNABR '041', '36', 'CONCESSO DE ABATIMENTO - J EXISTE ABATIMENTO ANTERIOR';
   EXEC INCLUI_ERRCNABR '041', '37', 'CDIGO PARA PROTESTO INVLIDO - REJEITA O TTULO SE O CAMPO FOR DIFERENTE DE BRANCO, 0, 1 OU 3';
   EXEC INCLUI_ERRCNABR '041', '38', 'PRAZO PARA PROTESTO INVLIDO - SE O CDIGO FOR 1 VERIFICA SE O CAMPO  NUMRICO';
   EXEC INCLUI_ERRCNABR '041', '39', 'PEDIDO DE PROTESTO NO PERMITIDO PARA O TTULO - NO PERMITE PROTESTO PARA AS CARTEIRAS R, S E N';
   EXEC INCLUI_ERRCNABR '041', '40', 'TTULO COM ORDEM DE PROTESTO EMITIDA (PARA RETORNO DE ALTERAO)';
   EXEC INCLUI_ERRCNABR '041', '41', 'PEDIDO DE CANCELAMENTO/SUSTAO DE PROTESTO INVLIDO';
   EXEC INCLUI_ERRCNABR '041', '42', 'CDIGO PARA BAIXA/DEVOLUO OU INSTRUO INVLIDO - VERIFICA SE O CDIGO  BRANCO, 0, 1 OU 2';
   EXEC INCLUI_ERRCNABR '041', '43', 'PRAZO PARA BAIXA/DEVOLUO INVLIDO - SE O CDIGO  1 VERIFICA SE O CAMPO PRAZO  NUMRICO';
   EXEC INCLUI_ERRCNABR '041', '44', 'CDIGO DA MOEDA INVLIDO';
   EXEC INCLUI_ERRCNABR '041', '45', 'NOME DO SACADO INVLIDO OU ALTERAO DO SACADO NO PERMITIDA';
   EXEC INCLUI_ERRCNABR '041', '46', 'TIPO/NMERO DE INSCRIO DO SACADO INVLIDO';
   EXEC INCLUI_ERRCNABR '041', '47', 'ENDEREO NO INFORMADO OU ALTERAO DE ENDEREO NO PERMITIDA';
   EXEC INCLUI_ERRCNABR '041', '48', 'CEP INVLIDO OU ALTERAO DE CEP NO PERMITIDA';
   EXEC INCLUI_ERRCNABR '041', '49', 'CEP SEM PRAA DE COBRANA OU ALTERAO DE CIDADE NO PERMITIDA';
   EXEC INCLUI_ERRCNABR '041', '50', 'CEP REFERENTE A UM BANCO CORRESPONDENTE';
   EXEC INCLUI_ERRCNABR '041', '51', 'CEP INCOMPATVEL COM A UNIDADE DA FEDERAO';
   EXEC INCLUI_ERRCNABR '041', '52', 'UNIDADE DE FEDERAO INVLIDA OU ALTERAO DE UF NO PERMITIDA';
   EXEC INCLUI_ERRCNABR '041', '53', 'TIPO/NMERO DE INSCRIO DO SACADOR/AVALISTA INVLIDO';
   EXEC INCLUI_ERRCNABR '041', '54', 'SACADOR/AVALISTA NO INFORMADO - PARA ESPCIE AD O NOME DO SACADOR  OBRIGATRIO';
   EXEC INCLUI_ERRCNABR '041', '57', 'CDIGO DA MULTA INVLIDO';
   EXEC INCLUI_ERRCNABR '041', '58', 'DATA DA MULTA INVLIDA';
   EXEC INCLUI_ERRCNABR '041', '59', 'VALOR/PERCENTUAL DA MULTA INVLIDO';
   EXEC INCLUI_ERRCNABR '041', '60', 'MOVIMENTO PARA TTULO NO CADASTRADO - ALTERAO OU DEVOLUO';
   EXEC INCLUI_ERRCNABR '041', '62', 'TIPO DE IMPRESSO INVLIDO - SEGMENTO 3S ';
   EXEC INCLUI_ERRCNABR '041', '63', 'ENTRADA PARA TTULO J CADASTRADO';
   EXEC INCLUI_ERRCNABR '041', '79', 'DATA DE JUROS DE MORA INVLIDO - VALIDA DATA OU PRAZO NA INSTRUO DE JUROS';
   EXEC INCLUI_ERRCNABR '041', '80', 'DATA DO DESCONTO INVLIDA - VALIDA DATA OU PRAZO DA INSTRUO DE DESCONTO';
   EXEC INCLUI_ERRCNABR '041', '86', 'SEU NMERO INVLIDO (PARA RETORNO DE ALTERAO)';

-- BANCO SANTANDER 033

   EXEC INCLUI_ERRCNABR '033','01','CDIGO DO BANCO INVLIDO';
   EXEC INCLUI_ERRCNABR '033','02','CDIGO DO REGISTRO DETALHE INVLIDO';
   EXEC INCLUI_ERRCNABR '033','03','CDIGO DO SEGMENTO INVLIDO';
   EXEC INCLUI_ERRCNABR '033','04','CDIGO DE MOVIMENTO NO PERMITIDO PARA CARTEIRA';
   EXEC INCLUI_ERRCNABR '033','05','CDIGO DE MOVIMENTO INVLIDO';
   EXEC INCLUI_ERRCNABR '033','06','TIPO/NMERO DE INSCRIO DO CEDENTE INVLIDOS';
   EXEC INCLUI_ERRCNABR '033','07','AGNCIA/CONTA/DV INVLIDO';
   EXEC INCLUI_ERRCNABR '033','08','NOSSO NMERO INVLIDO';
   EXEC INCLUI_ERRCNABR '033','09','NOSSO NMERO DUPLICADO';
   EXEC INCLUI_ERRCNABR '033','10','CARTEIRA INVLIDA';
   EXEC INCLUI_ERRCNABR '033','11','FORMA DE CADASTRAMENTO DO TTULO INVLIDO';
   EXEC INCLUI_ERRCNABR '033','12','TIPO DE DOCUMENTO INVLIDO';
   EXEC INCLUI_ERRCNABR '033','13','IDENTIFICAO DA EMISSO DO BLOQUETO INVLIDA';
   EXEC INCLUI_ERRCNABR '033','14','IDENTIFICAO DA DISTRIBUIO DO BLOQUETO INVLIDA';
   EXEC INCLUI_ERRCNABR '033','15','CARACTERSTICAS DA COBRANA INCOMPATVEIS';
   EXEC INCLUI_ERRCNABR '033','16','DATA DE VENCIMENTO INVLIDA';
   EXEC INCLUI_ERRCNABR '033','17','DATA DE VENCIMENTO ANTERIOR A DATA DE EMISSO';
   EXEC INCLUI_ERRCNABR '033','18','VENCIMENTO FORA DO PRAZO DE OPERAO';
   EXEC INCLUI_ERRCNABR '033','19','TTULO A CARGO DE BANCOS CORRESPONDENTES COM VENCIMENTO INFERIOR A XX DIAS';
   EXEC INCLUI_ERRCNABR '033','20','VALOR DO TTULO INVLIDO';
   EXEC INCLUI_ERRCNABR '033','21','ESPCIE DO TTULO INVLIDA';
   EXEC INCLUI_ERRCNABR '033','22','ESPCIE DO TTULO NO PERMITIDA PARA A CARTEIRA';
   EXEC INCLUI_ERRCNABR '033','23','ACEITE INVLIDO';
   EXEC INCLUI_ERRCNABR '033','24','DATA DA EMISSO INVLIDA';
   EXEC INCLUI_ERRCNABR '033','25','DATA DA EMISSO POSTERIOR A DATA DE ENTRADA';
   EXEC INCLUI_ERRCNABR '033','26','CDIGO DE JUROS DE MORA INVLIDO';
   EXEC INCLUI_ERRCNABR '033','27','VALOR/TAXA DE JUROS DE MORA INVLIDO';
   EXEC INCLUI_ERRCNABR '033','28','CDIGO DO DESCONTO INVLIDO';
   EXEC INCLUI_ERRCNABR '033','29','VALOR DO DESCONTO MAIOR OU IGUAL AO VALOR DO TTULO';
   EXEC INCLUI_ERRCNABR '033','30','DESCONTO A CONCEDER NO CONFERE';
   EXEC INCLUI_ERRCNABR '033','31','CONCESSO DE DESCONTO - J EXISTE DESCONTO ANTERIOR';
   EXEC INCLUI_ERRCNABR '033','32','VALOR DO IOF INVLIDO';
   EXEC INCLUI_ERRCNABR '033','33','VALOR DO ABATIMENTO INVLIDO';
   EXEC INCLUI_ERRCNABR '033','34','VALOR DO ABATIMENTO MAIOR OU IGUAL AO VALOR DO TTULO';
   EXEC INCLUI_ERRCNABR '033','35','VALOR A CONCEDER NO CONFERE';
   EXEC INCLUI_ERRCNABR '033','36','CONCESSO DE ABATIMENTO - J EXISTE ABATIMENTO ANTERIOR';
   EXEC INCLUI_ERRCNABR '033','37','CDIGO PARA PROTESTO INVLIDO';
   EXEC INCLUI_ERRCNABR '033','38','PRAZO PARA PROTESTO INVLIDO';
   EXEC INCLUI_ERRCNABR '033','39','PEDIDO DE PROTESTO NO PERMITIDO PARA O TTULO';
   EXEC INCLUI_ERRCNABR '033','40','TTULO COM ORDEM DE PROTESTO EMITIDA';
   EXEC INCLUI_ERRCNABR '033','41','PEDIDO DE CANCELAMENTO/SUSTAO PARA TTULOS SEM INSTRUO DE PROTESTO';
   EXEC INCLUI_ERRCNABR '033','42','CDIGO PARA BAIXA/DEVOLUO INVLIDO';
   EXEC INCLUI_ERRCNABR '033','43','PRAZO PARA BAIXA/DEVOLUO INVLIDO';
   EXEC INCLUI_ERRCNABR '033','44','CDIGO DA MOEDA INVLIDO ';
   EXEC INCLUI_ERRCNABR '033','45','NOME DO SACADO NO INFORMADO';
   EXEC INCLUI_ERRCNABR '033','46','TIPO/NMERO DE INSCRIO DO SACADO INVLIDOS';
   EXEC INCLUI_ERRCNABR '033','47','ENDEREO DO SACADO NO INFORMADO';
   EXEC INCLUI_ERRCNABR '033','48','CEP INVLIDO';
   EXEC INCLUI_ERRCNABR '033','49','CEP SEM PRAA DE COBRANA (NO LOCALIZADO)';
   EXEC INCLUI_ERRCNABR '033','50','CEP REFERENTE A UM BANCO CORRESPONDENTE';
   EXEC INCLUI_ERRCNABR '033','51','CEP INCOMPATVEL COM A UNIDADE DA FEDERAO';
   EXEC INCLUI_ERRCNABR '033','52','UNIDADE DA FEDERAO INVLIDA';
   EXEC INCLUI_ERRCNABR '033','53','TIPO/NMERO DE INSCRIO DO SACADOR/AVALISTA INVLIDOS';
   EXEC INCLUI_ERRCNABR '033','54','SACADOR/AVALISTA NO INFORMADO';
   EXEC INCLUI_ERRCNABR '033','55','NOSSO NMERO NO BANCO CORRESPONDENTE NO INFORMADO';
   EXEC INCLUI_ERRCNABR '033','56','CDIGO DO BANCO CORRESPONDENTE NO INFORMADO';
   EXEC INCLUI_ERRCNABR '033','57','CDIGO DA MULTA INVLIDO';
   EXEC INCLUI_ERRCNABR '033','58','DATA DA MULTA INVLIDA';
   EXEC INCLUI_ERRCNABR '033','59','VALOR/PERCENTUAL DA MULTA INVLIDO';
   EXEC INCLUI_ERRCNABR '033','60','MOVIMENTO PARA TTULO NO CADASTRADO';
   EXEC INCLUI_ERRCNABR '033','61','ALTERAO DA AGNCIA COBRADORA/DV INVLIDA';
   EXEC INCLUI_ERRCNABR '033','62','TIPO DE IMPRESSO INVLIDO';
   EXEC INCLUI_ERRCNABR '033','63','ENTRADA PARA TTULO J CADASTRADO';
   EXEC INCLUI_ERRCNABR '033','64','NMERO DA LINHA INVLIDO';
   EXEC INCLUI_ERRCNABR '033','A4','SACADO DDA';

-- BANCO SOFISA 637

   EXEC INCLUI_ERRCNABR '637', '03', 'CEP invlido  No temos cobrador  Cobrador no Localizado';
   EXEC INCLUI_ERRCNABR '637', '04', 'Sigla do Estado invlida';
   EXEC INCLUI_ERRCNABR '637', '05', 'Data de Vencimento invlida ou fora do prazo mnimo';
   EXEC INCLUI_ERRCNABR '637', '06', 'Cdigo do Banco invlido';
   EXEC INCLUI_ERRCNABR '637', '08', 'Nome do sacado no informado';
   EXEC INCLUI_ERRCNABR '637', '10', 'Logradouro no informado';
   EXEC INCLUI_ERRCNABR '637', '14', 'Registro em duplicidade';
   EXEC INCLUI_ERRCNABR '637', '19', 'Data de desconto invlida ou maior que a data de vencimento';
   EXEC INCLUI_ERRCNABR '637', '20', 'Valor de IOF no numrico';
   EXEC INCLUI_ERRCNABR '637', '22', 'Valor de desconto + abatimento maior que o valor do ttulo';
   EXEC INCLUI_ERRCNABR '637', '25', 'CGC ou CPF do sacado invlido (aceito com restries)';
   EXEC INCLUI_ERRCNABR '637', '26', 'Espcies de documento invlida (difere de 01...10,13 e 99)';
   EXEC INCLUI_ERRCNABR '637', '27', 'Data de emisso do ttulo invlida';
   EXEC INCLUI_ERRCNABR '637', '28', 'Seu nmero no informado';
   EXEC INCLUI_ERRCNABR '637', '29', 'CEP  igual a espao ou zeros; ou no numrico';
   EXEC INCLUI_ERRCNABR '637', '30', 'Valor do ttulo no numrico ou invlido';
   EXEC INCLUI_ERRCNABR '637', '36', 'Valor de permanncia no numrico';
   EXEC INCLUI_ERRCNABR '637', '37', 'Valor de permanncia inconsistente, pois, dentro de um ms, ser maior que o valor do ttulo';
   EXEC INCLUI_ERRCNABR '637', '38', 'Valor de desconto/abatimento no numrico ou invlido';
   EXEC INCLUI_ERRCNABR '637', '39', 'Valor de abatimento no numrico';
   EXEC INCLUI_ERRCNABR '637', '42', 'Ttulo j existente em nossos registros. Nosso nmero no aceito';
   EXEC INCLUI_ERRCNABR '637', '43', 'Ttulo enviado em duplicidade nesse movimento';
   EXEC INCLUI_ERRCNABR '637', '44', 'Ttulo zerado ou em branco; ou no numrico na remessa';
   EXEC INCLUI_ERRCNABR '637', '46', 'Ttulo enviado fora da faixa de Nosso Nmero, estipulada para o cliente.';
   EXEC INCLUI_ERRCNABR '637', '53', 'Prazo de vencimento do ttulo excede ao da contratao';
   EXEC INCLUI_ERRCNABR '637', '54', 'Banco informado no  nosso correspondente 140-142';
   EXEC INCLUI_ERRCNABR '637', '55', 'Banco correspondente informado no cobra este CEP ou no possui faixas de CEP cadastradas';
   EXEC INCLUI_ERRCNABR '637', '56', 'Nosso nmero no correspondente no foi informado';
   EXEC INCLUI_ERRCNABR '637', '57', 'Remessa contendo duas instrues incompatveis  no protestar e dias de protesto ou prazo para protesto invlido.';
   EXEC INCLUI_ERRCNABR '637', '58', 'Entradas Rejeitadas  Reprovado no Represamento para Anlise';
   EXEC INCLUI_ERRCNABR '637', '60', 'CGC/CPF do sacado invlido  ttulo recusado';
   EXEC INCLUI_ERRCNABR '637', '87', 'Excede Prazo mximo entre emisso e vencimento';
   EXEC INCLUI_ERRCNABR '637', 'AG', 'Movimento no permitido  Ttulo  vista ou contra apresentao';
   EXEC INCLUI_ERRCNABR '637', 'AK', 'Ttulo pertence a outro cliente';
   EXEC INCLUI_ERRCNABR '637', 'AL', 'Sacado impedido de entrar nesta cobrana';
   EXEC INCLUI_ERRCNABR '637', 'AY', 'Ttulo deve estar em aberto e vencido para acatar protesto';
   EXEC INCLUI_ERRCNABR '637', 'BC', 'Anlise gerencial-sacado invlido p/operao crdito';
   EXEC INCLUI_ERRCNABR '637', 'BD', 'Anlise gerencial-sacado inadimplente';
   EXEC INCLUI_ERRCNABR '637', 'BE', 'Anlise gerencial-sacado difere do exigido';
   EXEC INCLUI_ERRCNABR '637', 'BF', 'Anlise gerencial-vencto excede vencto da operao de crdito';
   EXEC INCLUI_ERRCNABR '637', 'BG', 'Anlise gerencial-sacado com baixa liquidez';
   EXEC INCLUI_ERRCNABR '637', 'BH', 'Anlise gerencial-sacado excede concentrao';
   EXEC INCLUI_ERRCNABR '637', 'CB', 'Ttulo possui protesto efetivado/a efetivar hoje';
   EXEC INCLUI_ERRCNABR '637', 'CC', 'Valor de iof incompatvel com a espcie documento';
   EXEC INCLUI_ERRCNABR '637', 'CD', 'Efetivao de protesto sem agenda vlida';
   EXEC INCLUI_ERRCNABR '637', 'CE', 'Ttulo no aceito - pessoa fsica';
   EXEC INCLUI_ERRCNABR '637', 'CF', 'Excede prazo mximo da entrada ao vencimento';
   EXEC INCLUI_ERRCNABR '637', 'CG', 'Ttulo no aceito  por anlise gerencial';
   EXEC INCLUI_ERRCNABR '637', 'CH', 'Ttulo em espera  em anlise pelo banco';

-- BANCO SICREDI 748

   EXEC INCLUI_ERRCNABR '748', '01', 'Cdigo do Banco invlido';
   EXEC INCLUI_ERRCNABR '748', '02', 'Cdigo do registro detalhe invlido';
   EXEC INCLUI_ERRCNABR '748', '03', 'Cdigo da Ocorrncia invlido';
   EXEC INCLUI_ERRCNABR '748', '04', 'Cdigo da Ocorrncia no permitido para a carteira';
   EXEC INCLUI_ERRCNABR '748', '05', 'Cdigo de Ocorrncia no numrico';
   EXEC INCLUI_ERRCNABR '748', '07', 'Cooperativa/agncia/conta/dgito invlidos';
   EXEC INCLUI_ERRCNABR '748', '08', 'Nosso nmero invlido';
   EXEC INCLUI_ERRCNABR '748', '09', 'Nosso nmero duplicado';
   EXEC INCLUI_ERRCNABR '748', '10', 'Carteira invlida';
   EXEC INCLUI_ERRCNABR '748', '14', 'Ttulo Protestado';
   EXEC INCLUI_ERRCNABR '748', '15', 'Cooperativa/agncia/conta/nosso nmero invlidos';
   EXEC INCLUI_ERRCNABR '748', '16', 'Data de vencimento invlida';
   EXEC INCLUI_ERRCNABR '748', '17', 'Data de vencimento anterior  data de emisso';
   EXEC INCLUI_ERRCNABR '748', '18', 'Vencimento fora do prazo de operao';
   EXEC INCLUI_ERRCNABR '748', '20', 'Valor do ttulo invlido';
   EXEC INCLUI_ERRCNABR '748', '21', 'Espcie do ttulo invlida';
   EXEC INCLUI_ERRCNABR '748', '22', 'Espcie no permitida para a carteira';
   EXEC INCLUI_ERRCNABR '748', '24', 'Data de emisso invlida';
   EXEC INCLUI_ERRCNABR '748', '29', 'Valor de desconto maior/igual ao valor do ttulo';
   EXEC INCLUI_ERRCNABR '748', '31', 'Concesso de desconto - existe desconto anterior';
   EXEC INCLUI_ERRCNABR '748', '33', 'Valor do abatimento invlido';
   EXEC INCLUI_ERRCNABR '748', '34', 'Valor do abatimento maior/igual ao valor do ttulo';
   EXEC INCLUI_ERRCNABR '748', '36', 'Concesso de abatimento - existe abatimento anterior';
   EXEC INCLUI_ERRCNABR '748', '38', 'Prazo para protesto invlido';
   EXEC INCLUI_ERRCNABR '748', '39', 'Pedido para protesto no permitido para o ttulo';
   EXEC INCLUI_ERRCNABR '748', '40', 'Ttulo com ordem de protesto emitida';
   EXEC INCLUI_ERRCNABR '748', '41', 'Pedido cancelamento/sustao sem instruo de de protesto';
   EXEC INCLUI_ERRCNABR '748', '44', 'Cooperativa de crdito/agncia cedente no prevista';
   EXEC INCLUI_ERRCNABR '748', '45', 'Nome do sacado invlido';
   EXEC INCLUI_ERRCNABR '748', '46', 'Tipo/nmero de inscrio do sacado invlidos';
   EXEC INCLUI_ERRCNABR '748', '47', 'Endereo do sacado no informado';
   EXEC INCLUI_ERRCNABR '748', '48', 'CEP irregular';
   EXEC INCLUI_ERRCNABR '748', '49', 'Nmero de inscrio do sacador/avalista invlido';
   EXEC INCLUI_ERRCNABR '748', '50', 'Sacador/avalista no informado';
   EXEC INCLUI_ERRCNABR '748', '60', 'Movimento para ttulo no cadastrado';
   EXEC INCLUI_ERRCNABR '748', '63', 'Entrada para ttulo j cadastrado';
   EXEC INCLUI_ERRCNABR '748', 'A', 'Aceito';
   EXEC INCLUI_ERRCNABR '748', 'D', 'Desprezado';
   EXEC INCLUI_ERRCNABR '748', 'A1', 'Praa do Sacado no cadastrada';
   EXEC INCLUI_ERRCNABR '748', 'A2', 'Tipo de cobrana do ttulo divergente com a praa do sacado';
   EXEC INCLUI_ERRCNABR '748', 'A3', 'Cooperativa/agncia depositaria divergente: atualiza o cadastro de praas da Coop./agncia cedente';
   EXEC INCLUI_ERRCNABR '748', 'A4', 'Cedente no cadastrado ou possui CGC/CIC invlido';
   EXEC INCLUI_ERRCNABR '748', 'A5', 'Sacado no cadastrado';
   EXEC INCLUI_ERRCNABR '748', 'A6', 'Data da instruo/ocorrncia invlida';
   EXEC INCLUI_ERRCNABR '748', 'A7', 'Ocorrncia no pode ser comandada';
   EXEC INCLUI_ERRCNABR '748', 'A8', 'Recebimento da liquidao fora do SICREDI - via compensao eletrnica';
   EXEC INCLUI_ERRCNABR '748', 'B4', 'Tipo de moeda invlido';
   EXEC INCLUI_ERRCNABR '748', 'B5', 'Tipo de desconto/juros invlido';
   EXEC INCLUI_ERRCNABR '748', 'B6', 'Mensagem padro no cadastrada';
   EXEC INCLUI_ERRCNABR '748', 'B7', 'Seu nmero invlido';
   EXEC INCLUI_ERRCNABR '748', 'B8', 'Percentual de multa invlido';
   EXEC INCLUI_ERRCNABR '748', 'B9', 'Valor ou percentual de juros invlido';
   EXEC INCLUI_ERRCNABR '748', 'C1', 'Data limite para concesso de desconto invlida';
   EXEC INCLUI_ERRCNABR '748', 'C2', 'Aceite do ttulo invlido';
   EXEC INCLUI_ERRCNABR '748', 'C3', 'Campo alterado na instruo: 31 - Alterao de outros dados, invlido';
   EXEC INCLUI_ERRCNABR '748', 'C4', 'Ttulo ainda no foi confirmado pela centralizadora';
   EXEC INCLUI_ERRCNABR '748', 'C5', 'Ttulo rejeitado pela centralizadora';
   EXEC INCLUI_ERRCNABR '748', 'C6', 'Ttulo j liquidado';
   EXEC INCLUI_ERRCNABR '748', 'C7', 'Ttulo j baixado';
   EXEC INCLUI_ERRCNABR '748', 'C8', 'Existe mesma instruo pendente de confirmao para este ttulo';
   EXEC INCLUI_ERRCNABR '748', 'C9', 'Instruo prvia de concesso de abatimento no existe ou no confirmada';
   EXEC INCLUI_ERRCNABR '748', 'D1', 'Ttulo dentro do prazo de vencimentos  em dia)';
   EXEC INCLUI_ERRCNABR '748', 'D2', 'Espcie de documento no permite protesto de ttulo';
   EXEC INCLUI_ERRCNABR '748', 'D3', 'Ttulo possui instruo de baixa pendente de confirmao';
   EXEC INCLUI_ERRCNABR '748', 'D4', 'Quantidade de mensagens padro excede o limite permitido';
   EXEC INCLUI_ERRCNABR '748', 'D5', 'Quantidade invlida no pedido de bloquetos pr-impressos da cobrana sem registro';
   EXEC INCLUI_ERRCNABR '748', 'D6', 'Tipo de impresso invlida para cobrana sem registro';
   EXEC INCLUI_ERRCNABR '748', 'D7', 'Cidade ou Estado do sacado no informado';
   EXEC INCLUI_ERRCNABR '748', 'D8', 'Sequncia para composio do nosso nmero do ano atual esgotada';
   EXEC INCLUI_ERRCNABR '748', 'D9', 'Registro mensagem para ttulo no cadastrado';
   EXEC INCLUI_ERRCNABR '748', 'E2', 'Registro complementar ao cadastro do ttulo da cobrana com e sem registro no cadastrado';
   EXEC INCLUI_ERRCNABR '748', 'E3', 'Tipo de postagem invlido, diferente de S, N e branco';
   EXEC INCLUI_ERRCNABR '748', 'E4', 'Pedido de bloquetos pr-impressos';
   EXEC INCLUI_ERRCNABR '748', 'E5', 'Confirmao/rejeio para pedidos de bloquetos no cadastrado';
   EXEC INCLUI_ERRCNABR '748', 'E6', 'Sacador/avalista no cadastrado';
   EXEC INCLUI_ERRCNABR '748', 'E7', 'Informao para atualizao do valor do ttulo para protesto invlido';
   EXEC INCLUI_ERRCNABR '748', 'E8', 'Tipo de impresso invlido, diferente de A, B e branco';
   EXEC INCLUI_ERRCNABR '748', 'E9', 'Cdigo do sacado do ttulo divergente com o cdigo da cooperativa de crdito';
   EXEC INCLUI_ERRCNABR '748', 'F1', 'Liquidado no sistema do cliente';
   EXEC INCLUI_ERRCNABR '748', 'F2', 'Baixado no sistema do cliente';
   EXEC INCLUI_ERRCNABR '748', 'F3', 'Instruo invlida, este ttulo est caucionado/descontado';
   EXEC INCLUI_ERRCNABR '748', 'F4', 'Instruo fixa com caracteres invlidos';
   EXEC INCLUI_ERRCNABR '748', 'F6', 'Nosso nmero / nmero da parcela fora de sequencia - total de parcelas invlido';
   EXEC INCLUI_ERRCNABR '748', 'F7', 'Falta de comprovante de prestao de servios';
   EXEC INCLUI_ERRCNABR '748', 'F8', 'Nome do cedente incompleto/incorreto';
   EXEC INCLUI_ERRCNABR '748', 'F9', 'CNPJ/CPF incompatvel com o nome do sacado / sacador avalista';
   EXEC INCLUI_ERRCNABR '748', 'G1', 'CNPJ/CPF do sacador incompatvel com a espcie';
   EXEC INCLUI_ERRCNABR '748', 'G2', 'Ttulo aceito: sem a assinatura do sacado';
   EXEC INCLUI_ERRCNABR '748', 'G3', 'Ttulo aceito: rasurado ou rasgado';
   EXEC INCLUI_ERRCNABR '748', 'G4', 'Ttulo aceito: falta ttulo (cooperativa/ag. cedente dever envi-lo)';
   EXEC INCLUI_ERRCNABR '748', 'G5', 'Praa de pagamento incomptivel com o endereo';
   EXEC INCLUI_ERRCNABR '748', 'G6', 'Ttulo aceito: sem endosso ou cedente irregular';
   EXEC INCLUI_ERRCNABR '748', 'G7', 'Ttulo aceito: valor por extenso diferente do valor numrico';
   EXEC INCLUI_ERRCNABR '748', 'G8', 'Saldo maior que o valor do ttulo';
   EXEC INCLUI_ERRCNABR '748', 'G9', 'Tipo de endosso invlido';
   EXEC INCLUI_ERRCNABR '748', 'H1', 'Nome sacador incompleto/incorreto';
   EXEC INCLUI_ERRCNABR '748', 'H2', 'Sustao judicial';
   EXEC INCLUI_ERRCNABR '748', 'H3', 'Sacado no encontrado';
   EXEC INCLUI_ERRCNABR '748', 'H4', 'Alterao da carteira';
   EXEC INCLUI_ERRCNABR '748', 'H5', 'Recebimento da liquidao fora da rede SICREDI - VLB inferior - Via compensao';
   EXEC INCLUI_ERRCNABR '748', 'H6', 'Recebimento da liquidao fora da rede SICREDI - VLB superior - Via compensao';
   EXEC INCLUI_ERRCNABR '748', 'H7', 'Espcie de documento necessita cedente ou avalista PJ';
   EXEC INCLUI_ERRCNABR '748', 'H8', 'Recebimento da liquidao fora da rede SICREDI - Contingncia Via Compe';
   EXEC INCLUI_ERRCNABR '748', 'H9', 'Dados do ttulo no conferem com disquete';
   EXEC INCLUI_ERRCNABR '748', 'I1', 'Sacado e sacador avalista so a mesma pessoa';
   EXEC INCLUI_ERRCNABR '748', 'I2', 'Aguardar um dia til aps o vencimento para protestar';
   EXEC INCLUI_ERRCNABR '748', 'I3', 'Data do vencimento rasurada';
   EXEC INCLUI_ERRCNABR '748', 'I4', 'Vencimento - extenso no confere com nmero';
   EXEC INCLUI_ERRCNABR '748', 'I5', 'Falta data de vencimento no ttulo';
   EXEC INCLUI_ERRCNABR '748', 'I6', 'DM/DMI sem comprovante autenticado ou declarao';
   EXEC INCLUI_ERRCNABR '748', 'I7', 'Comprovante ilegvel para conferncia e microfilmagem';
   EXEC INCLUI_ERRCNABR '748', 'I8', 'Nome solicitado no confere com emitente ou sacado';
   EXEC INCLUI_ERRCNABR '748', 'I9', 'Confirmar se so 2 emitentes. Se sim, indicar os dados dos 2';
   EXEC INCLUI_ERRCNABR '748', 'J1', 'Endereo do sacado igual ao do sacador ou do portador';
   EXEC INCLUI_ERRCNABR '748', 'J2', 'Endereo do apresentante incompleto ou no informado';
   EXEC INCLUI_ERRCNABR '748', 'J3', 'Rua/nmero inexistente no endereo';
   EXEC INCLUI_ERRCNABR '748', 'J4', 'Falta endosso do favorecido para o apresentante';
   EXEC INCLUI_ERRCNABR '748', 'J5', 'Data de emisso rasurada';
   EXEC INCLUI_ERRCNABR '748', 'J6', 'Falta assinatura do sacador no ttulo';
   EXEC INCLUI_ERRCNABR '748', 'J7', 'Nome do apresentante no informado/incompleto/incorreto';
   EXEC INCLUI_ERRCNABR '748', 'J8', 'Erro de preenchimento de ttulo';
   EXEC INCLUI_ERRCNABR '748', 'J9', 'Ttulo com direito de regresso vencido';
   EXEC INCLUI_ERRCNABR '748', 'K1', 'Ttulo apresentado em duplicidade';
   EXEC INCLUI_ERRCNABR '748', 'K2', 'Ttulo j protestado';
   EXEC INCLUI_ERRCNABR '748', 'K3', 'Letra de cambio vencida - falta aceite do sacado';
   EXEC INCLUI_ERRCNABR '748', 'K4', 'Falta declarao de saldo assinada no ttulo';
   EXEC INCLUI_ERRCNABR '748', 'K5', 'Contrato de cambio - Falta conta grfica';
   EXEC INCLUI_ERRCNABR '748', 'K6', 'Ausncia do documento fsico';
   EXEC INCLUI_ERRCNABR '748', 'K7', 'Sacado falecido';
   EXEC INCLUI_ERRCNABR '748', 'K8', 'Sacado apresentou quitao do ttulo';
   EXEC INCLUI_ERRCNABR '748', 'K9', 'Ttulo de outra jurisdio territorial';
   EXEC INCLUI_ERRCNABR '748', 'L1', 'Ttulo com emisso anterior a concordata do sacado';
   EXEC INCLUI_ERRCNABR '748', 'L2', 'Sacado consta na lista de falncia';
   EXEC INCLUI_ERRCNABR '748', 'L3', 'Apresentante no aceita publicao de edital';
   EXEC INCLUI_ERRCNABR '748', 'L4', 'Dados do Sacado em Branco ou invlido';
   EXEC INCLUI_ERRCNABR '748', 'L5', 'Cdigo do Sacado na agncia cedente est duplicado';
   EXEC INCLUI_ERRCNABR '748', 'M1', 'Reconhecimento da dvida pelo Sacado';
   EXEC INCLUI_ERRCNABR '748', 'M2', 'No reconhecimento da dvida pelo Sacado';
   EXEC INCLUI_ERRCNABR '748', 'X1', 'Regularizao Centralizadora - Rede SICREDI';
   EXEC INCLUI_ERRCNABR '748', 'X2', 'Regularizao Centralizadora - Compensao';
   EXEC INCLUI_ERRCNABR '748', 'X3', 'Regularizao Centralizadora - Banco correspondente';
   EXEC INCLUI_ERRCNABR '748', 'X4', 'Regularizao Centralizadora - VLB Inferior - via compensao';
   EXEC INCLUI_ERRCNABR '748', 'X5', 'Regularizao Centralizadora - VLB Inferior - via compensao';
   EXEC INCLUI_ERRCNABR '748', 'X0', 'Pago com cheque';
   EXEC INCLUI_ERRCNABR '748', 'X6', 'Pago com cheque - bloqueado 24 horas';
   EXEC INCLUI_ERRCNABR '748', 'X7', 'Pago com cheque - bloqueado 48 horas';
   EXEC INCLUI_ERRCNABR '748', 'X8', 'Pago com cheque - bloqueado 72 horas';
   EXEC INCLUI_ERRCNABR '748', 'X9', 'Pago com cheque - bloqueado 96 horas';
   EXEC INCLUI_ERRCNABR '748', 'XA', 'Pago com cheque - bloqueado 120 horas';
   EXEC INCLUI_ERRCNABR '748', 'XB', 'Pago com cheque - bloqueado 144 horas';

-- BANCO SICOOB 756

   EXEC INCLUI_ERRCNABR '756', '0200', '[Entrada confirmada] Ocorrncia aceita';
   EXEC INCLUI_ERRCNABR '756', '0217', '[Entrada confirmada] Data de vencimento anterior a data de emisso';
   EXEC INCLUI_ERRCNABR '756', '0221', '[Entrada confirmada] Espcie do Ttulo invlido';
   EXEC INCLUI_ERRCNABR '756', '0224', '[Entrada confirmada] Data da emisso invlida';
   EXEC INCLUI_ERRCNABR '756', '0238', '[Entrada confirmada] Prazo para protesto invlido';
   EXEC INCLUI_ERRCNABR '756', '0239', '[Entrada confirmada] Pedido para protesto no permitido para ttulo';
   EXEC INCLUI_ERRCNABR '756', '0243', '[Entrada confirmada] Prazo para baixa e devoluo invlido';
   EXEC INCLUI_ERRCNABR '756', '0245', '[Entrada confirmada] Nome do Sacado invlido';
   EXEC INCLUI_ERRCNABR '756', '0246', '[Entrada confirmada] Tipo/num. de inscrio do Sacado invlidos';
   EXEC INCLUI_ERRCNABR '756', '0247', '[Entrada confirmada] Endereo do Sacado no informado';
   EXEC INCLUI_ERRCNABR '756', '0248', '[Entrada confirmada] CEP irregular';
   EXEC INCLUI_ERRCNABR '756', '0250', '[Entrada confirmada] CEP referente a Banco correspondente';
   EXEC INCLUI_ERRCNABR '756', '0253', '[Entrada confirmada] N de inscrio do Sacador/avalista invlidos (CPF/CGC)';
   EXEC INCLUI_ERRCNABR '756', '0254', '[Entrada confirmada] Sacador/avalista no informado';
   EXEC INCLUI_ERRCNABR '756', '0267', '[Entrada confirmada] Dbito automtico agendado';
   EXEC INCLUI_ERRCNABR '756', '0268', '[Entrada confirmada] Dbito no agendado  Erro nos dados de remessa';
   EXEC INCLUI_ERRCNABR '756', '0269', '[Entrada confirmada] Dbito no agendado  Sacado no consta no cadastro de autorizante';
   EXEC INCLUI_ERRCNABR '756', '0270', '[Entrada confirmada] Dbito no agendado  Cedente no autorizado pelo Sacado';
   EXEC INCLUI_ERRCNABR '756', '0271', '[Entrada confirmada] Dbito no agendado  Cedente no participa da modalidade de dbito automtico';
   EXEC INCLUI_ERRCNABR '756', '0272', '[Entrada confirmada] Dbito no agendado  Cdigo de moeda diferente de R$';
   EXEC INCLUI_ERRCNABR '756', '0273', '[Entrada confirmada] Dbito no agendado  Data de vencimento invlida';
   EXEC INCLUI_ERRCNABR '756', '0275', '[Entrada confirmada] Dbito no agendado  Tipo do nmero de inscrio do sacado debitado invlido';
   EXEC INCLUI_ERRCNABR '756', '0286', '[Entrada confirmada] Seu nmero do documento invlido';
   EXEC INCLUI_ERRCNABR '756', '0302', '[Entrada Rejeitada] Cdigo do registro detalhe invlido';
   EXEC INCLUI_ERRCNABR '756', '0303', '[Entrada Rejeitada] Cdigo da ocorrncia invlida';
   EXEC INCLUI_ERRCNABR '756', '0304', '[Entrada Rejeitada] Cdigo de ocorrncia no permitida para a carteira';
   EXEC INCLUI_ERRCNABR '756', '0305', '[Entrada Rejeitada] Cdigo de ocorrncia no numrico';
   EXEC INCLUI_ERRCNABR '756', '0307', '[Entrada Rejeitada] Agncia/conta/Digito  Invlido';
   EXEC INCLUI_ERRCNABR '756', '0308', '[Entrada Rejeitada] Nosso nmero invlido';
   EXEC INCLUI_ERRCNABR '756', '0309', '[Entrada Rejeitada] Nosso nmero duplicado';
   EXEC INCLUI_ERRCNABR '756', '0310', '[Entrada Rejeitada] Carteira invlida';
   EXEC INCLUI_ERRCNABR '756', '0316', '[Entrada Rejeitada] Data de vencimento invlida';
   EXEC INCLUI_ERRCNABR '756', '0318', '[Entrada Rejeitada] Vencimento fora do prazo de operao';
   EXEC INCLUI_ERRCNABR '756', '0320', '[Entrada Rejeitada] Valor do Ttulo invlido';
   EXEC INCLUI_ERRCNABR '756', '0321', '[Entrada Rejeitada] Espcie do Ttulo invlida';
   EXEC INCLUI_ERRCNABR '756', '0322', '[Entrada Rejeitada] Espcie no permitida para a carteira';
   EXEC INCLUI_ERRCNABR '756', '0324', '[Entrada Rejeitada] Data de emisso invlida';
   EXEC INCLUI_ERRCNABR '756', '0338', '[Entrada Rejeitada] Prazo para protesto invlido';
   EXEC INCLUI_ERRCNABR '756', '0344', '[Entrada Rejeitada] Agncia Cedente no prevista';
   EXEC INCLUI_ERRCNABR '756', '0350', '[Entrada Rejeitada] CEP irregular  Banco Correspondente';
   EXEC INCLUI_ERRCNABR '756', '0363', '[Entrada Rejeitada] Entrada para Ttulo j cadastrado';
   EXEC INCLUI_ERRCNABR '756', '0368', '[Entrada Rejeitada] Dbito no agendado  Erro nos dados de remessa';
   EXEC INCLUI_ERRCNABR '756', '0369', '[Entrada Rejeitada] Dbito no agendado  Sacado no consta no cadastro de autorizante';
   EXEC INCLUI_ERRCNABR '756', '0370', '[Entrada Rejeitada] Dbito no agendado  Cedente no autorizado pelo Sacado';
   EXEC INCLUI_ERRCNABR '756', '0371', '[Entrada Rejeitada] Dbito no agendado  Cedente no participa da modalidade de dbito automtico';
   EXEC INCLUI_ERRCNABR '756', '0372', '[Entrada Rejeitada] Dbito no agendado  Cdigo de moeda diferente de R$';
   EXEC INCLUI_ERRCNABR '756', '0373', '[Entrada Rejeitada] Dbito no agendado  Data de vencimento invlida';
   EXEC INCLUI_ERRCNABR '756', '0374', '[Entrada Rejeitada] Dbito no agendado  Conforme seu pedido, Ttulo no registrado';
   EXEC INCLUI_ERRCNABR '756', '0375', '[Entrada Rejeitada] Dbito no agendado  Tipo de nmero de inscrio do debitado invlido';
   EXEC INCLUI_ERRCNABR '756', '0910', '[Baixado Automaticamente via Arquivo] Baixa comandada pelo cliente';
   EXEC INCLUI_ERRCNABR '756', '1000', '[Baixado Conforme Instrues da Agncia] Baixa Comandada';
   EXEC INCLUI_ERRCNABR '756', '1014', '[Baixado Conforme Instrues da Agncia] Ttulo Protestado';
   EXEC INCLUI_ERRCNABR '756', '1015', '[Baixado Conforme Instrues da Agncia] Ttulo excludo';
   EXEC INCLUI_ERRCNABR '756', '2448', '[Entrada Rejeitada por CEP irregular] CEP invlido';
   EXEC INCLUI_ERRCNABR '756', '2704', '[Baixa Rejeitada] Cdigo de ocorrncia no permitido para a carteira';
   EXEC INCLUI_ERRCNABR '756', '2707', '[Baixa Rejeitada] Agncia/Conta/dgito invlidos';
   EXEC INCLUI_ERRCNABR '756', '2708', '[Baixa Rejeitada] Nosso nmero invlido';
   EXEC INCLUI_ERRCNABR '756', '2710', '[Baixa Rejeitada] Carteira invlida';
   EXEC INCLUI_ERRCNABR '756', '2715', '[Baixa Rejeitada] Carteira/Agncia/Conta/nosso nmero invlidos';
   EXEC INCLUI_ERRCNABR '756', '2740', '[Baixa Rejeitada] Ttulo com ordem de protesto emitido';
   EXEC INCLUI_ERRCNABR '756', '2742', '[Baixa Rejeitada] Cdigo para baixa/devoluo via Telebradesco invlido';
   EXEC INCLUI_ERRCNABR '756', '2760', '[Baixa Rejeitada] Movimento para Ttulo no cadastrado';
   EXEC INCLUI_ERRCNABR '756', '2777', '[Baixa Rejeitada] Transferncia para desconto no permitido para a carteira';
   EXEC INCLUI_ERRCNABR '756', '2785', '[Baixa Rejeitada] Ttulo com pagamento vinculado';
   EXEC INCLUI_ERRCNABR '756', '2803', '[Dbito de Tarifas/Custas] Tarifa de sustao';
   EXEC INCLUI_ERRCNABR '756', '2804', '[Dbito de Tarifas/Custas] Tarifa de protesto';
   EXEC INCLUI_ERRCNABR '756', '2808', '[Dbito de Tarifas/Custas] Custas de protesto';
   EXEC INCLUI_ERRCNABR '756', '3001', '[Alterao de Outros Dados Rejeitados] Cdigo do Banco invlido';
   EXEC INCLUI_ERRCNABR '756', '3004', '[Alterao de Outros Dados Rejeitados] Cdigo de ocorrncia no permitido para a carteira';
   EXEC INCLUI_ERRCNABR '756', '3005', '[Alterao de Outros Dados Rejeitados] Cdigo da ocorrncia no numrico';
   EXEC INCLUI_ERRCNABR '756', '3008', '[Alterao de Outros Dados Rejeitados] Nosso nmero invlido';
   EXEC INCLUI_ERRCNABR '756', '3015', '[Alterao de Outros Dados Rejeitados] Caracterstica da cobrana imcoptivel';
   EXEC INCLUI_ERRCNABR '756', '3016', '[Alterao de Outros Dados Rejeitados] Data de vencimento invlido';
   EXEC INCLUI_ERRCNABR '756', '3017', '[Alterao de Outros Dados Rejeitados] Data de vencimento anterior a data de emisso';
   EXEC INCLUI_ERRCNABR '756', '3018', '[Alterao de Outros Dados Rejeitados] Vencimento fora do prazo de operao';
   EXEC INCLUI_ERRCNABR '756', '3024', '[Alterao de Outros Dados Rejeitados] Data de emisso Invlida';
   EXEC INCLUI_ERRCNABR '756', '3029', '[Alterao de Outros Dados Rejeitados] Valor do desconto maior/igual ao valor do Ttulo';
   EXEC INCLUI_ERRCNABR '756', '3030', '[Alterao de Outros Dados Rejeitados] Desconto a conceder no confere';
   EXEC INCLUI_ERRCNABR '756', '3031', '[Alterao de Outros Dados Rejeitados] Concesso de desconto j existente (Desconto anterior)';
   EXEC INCLUI_ERRCNABR '756', '3033', '[Alterao de Outros Dados Rejeitados] Valor do abatimento invlido';
   EXEC INCLUI_ERRCNABR '756', '3034', '[Alterao de Outros Dados Rejeitados] Valor do abatimento maior/igual ao valor do Ttulo';
   EXEC INCLUI_ERRCNABR '756', '3038', '[Alterao de Outros Dados Rejeitados] Prazo para protesto invlido';
   EXEC INCLUI_ERRCNABR '756', '3039', '[Alterao de Outros Dados Rejeitados] Pedido de protesto no permitido para o Ttulo';
   EXEC INCLUI_ERRCNABR '756', '3040', '[Alterao de Outros Dados Rejeitados] Ttulo com ordem de protesto emitido';
   EXEC INCLUI_ERRCNABR '756', '3042', '[Alterao de Outros Dados Rejeitados] Cdigo para baixa/devoluo invlido';
   EXEC INCLUI_ERRCNABR '756', '3060', '[Alterao de Outros Dados Rejeitados] Movimento para Ttulo no cadastrado';
   EXEC INCLUI_ERRCNABR '756', '3085', '[Alterao de Outros Dados Rejeitados] Ttulo com Pagamento Vinculado';
   EXEC INCLUI_ERRCNABR '756', '3201', '[Instruo Rejeitada] Cdigo do Banco invlido';
   EXEC INCLUI_ERRCNABR '756', '3202', '[Instruo Rejeitada] Cdigo do registro detalhe invlido';
   EXEC INCLUI_ERRCNABR '756', '3204', '[Instruo Rejeitada] Cdigo de ocorrncia no permitido para a carteira';
   EXEC INCLUI_ERRCNABR '756', '3205', '[Instruo Rejeitada] Cdigo de ocorrncia no numrico';
   EXEC INCLUI_ERRCNABR '756', '3207', '[Instruo Rejeitada] Agncia/Conta/dgito invlidos';
   EXEC INCLUI_ERRCNABR '756', '3208', '[Instruo Rejeitada] Nosso nmero invlido';
   EXEC INCLUI_ERRCNABR '756', '3210', '[Instruo Rejeitada] Carteira invlida';
   EXEC INCLUI_ERRCNABR '756', '3215', '[Instruo Rejeitada] Caractersticas da cobrana incompatveis';
   EXEC INCLUI_ERRCNABR '756', '3216', '[Instruo Rejeitada] Data de vencimento invlida';
   EXEC INCLUI_ERRCNABR '756', '3217', '[Instruo Rejeitada] Data de vencimento anterior a data de emisso';
   EXEC INCLUI_ERRCNABR '756', '3218', '[Instruo Rejeitada] Vencimento fora do prazo de operao';
   EXEC INCLUI_ERRCNABR '756', '3220', '[Instruo Rejeitada] Valor do ttulo invlido';
   EXEC INCLUI_ERRCNABR '756', '3221', '[Instruo Rejeitada] Espcie do Ttulo invlida';
   EXEC INCLUI_ERRCNABR '756', '3222', '[Instruo Rejeitada] Espcie no permitida para a carteira';
   EXEC INCLUI_ERRCNABR '756', '3224', '[Instruo Rejeitada] Data de emisso invlida';
   EXEC INCLUI_ERRCNABR '756', '3228', '[Instruo Rejeitada] Cdigo de desconto via Telebradesco invlido';
   EXEC INCLUI_ERRCNABR '756', '3229', '[Instruo Rejeitada] Valor do desconto maior/igual ao valor do Ttulo';
   EXEC INCLUI_ERRCNABR '756', '3230', '[Instruo Rejeitada] Desconto a conceder no confere';
   EXEC INCLUI_ERRCNABR '756', '3231', '[Instruo Rejeitada] Concesso de desconto  J existe desconto anterior';
   EXEC INCLUI_ERRCNABR '756', '3233', '[Instruo Rejeitada] Valor do abatimento invlido';
   EXEC INCLUI_ERRCNABR '756', '3234', '[Instruo Rejeitada] Valor do abatimento maior/igual ao valor do Ttulo';
   EXEC INCLUI_ERRCNABR '756', '3236', '[Instruo Rejeitada] Concesso abatimento  J existe abatimento anterior';
   EXEC INCLUI_ERRCNABR '756', '3238', '[Instruo Rejeitada] Prazo para protesto invlido';
   EXEC INCLUI_ERRCNABR '756', '3239', '[Instruo Rejeitada] Pedido de protesto no permitido para o Ttulo';
   EXEC INCLUI_ERRCNABR '756', '3240', '[Instruo Rejeitada] Ttulo com ordem de protesto emitido';
   EXEC INCLUI_ERRCNABR '756', '3241', '[Instruo Rejeitada] Pedido cancelamento/sustao para Ttulo sem instruo de protesto';
   EXEC INCLUI_ERRCNABR '756', '3242', '[Instruo Rejeitada] Cdigo para baixa/devoluo invlido';
   EXEC INCLUI_ERRCNABR '756', '3245', '[Instruo Rejeitada] Nome do Sacado no informado';
   EXEC INCLUI_ERRCNABR '756', '3246', '[Instruo Rejeitada] Tipo/nmero de inscrio do Sacado invlidos';
   EXEC INCLUI_ERRCNABR '756', '3247', '[Instruo Rejeitada] Endereo do Sacado no informado';
   EXEC INCLUI_ERRCNABR '756', '3248', '[Instruo Rejeitada] CEP Invlido';
   EXEC INCLUI_ERRCNABR '756', '3250', '[Instruo Rejeitada] CEP referente a um Banco correspondente';
   EXEC INCLUI_ERRCNABR '756', '3253', '[Instruo Rejeitada] Tipo de inscrio do sacador avalista invlidos';
   EXEC INCLUI_ERRCNABR '756', '3260', '[Instruo Rejeitada] Movimento para Ttulo no cadastrado';
   EXEC INCLUI_ERRCNABR '756', '3285', '[Instruo Rejeitada] Ttulo com pagamento vinculado';
   EXEC INCLUI_ERRCNABR '756', '3286', '[Instruo Rejeitada] Seu nmero invlido';
   EXEC INCLUI_ERRCNABR '756', '3581', '[Desagendamento do Dbito Automtico] Tentativas esgotadas, baixado';
   EXEC INCLUI_ERRCNABR '756', '3582', '[Desagendamento do Dbito Automtico] Tentativas esgotadas, pendente';
	
--Banco Daycoval
	EXEC INCLUI_ERRCNABR '707', '0303', '[Entrada Rejeitada] CEP invlido  No temos cobrador  Cobrador no Localizado';
	EXEC INCLUI_ERRCNABR '707', '0304', '[Entrada Rejeitada] Sigla do Estado invlida';
	EXEC INCLUI_ERRCNABR '707', '0305', '[Entrada Rejeitada] Data de Vencimento invlida ou fora do prazo mnimo';
	EXEC INCLUI_ERRCNABR '707', '0306', '[Entrada Rejeitada] Cdigo do Banco invlido';
	EXEC INCLUI_ERRCNABR '707', '0308', '[Entrada Rejeitada] Nome do sacado no informado';
	EXEC INCLUI_ERRCNABR '707', '0310', '[Entrada Rejeitada] Logradouro no informado';
	EXEC INCLUI_ERRCNABR '707', '0314', '[Entrada Rejeitada] Registro em duplicidade';
	EXEC INCLUI_ERRCNABR '707', '0319', '[Entrada Rejeitada] Data de desconto invlida ou maior que a data de vencimento';
	EXEC INCLUI_ERRCNABR '707', '0320', '[Entrada Rejeitada] Valor de IOF no numrico';
	EXEC INCLUI_ERRCNABR '707', '0322', '[Entrada Rejeitada] Valor de desconto + abatimento maior que o valor do ttulo';
	EXEC INCLUI_ERRCNABR '707', '0325', '[Entrada Rejeitada] CNPJ ou CPF do sacado invlido aceito com restries';
	EXEC INCLUI_ERRCNABR '707', '0326', '[Entrada Rejeitada] Espcies de documento invlida difere de 01...10,13 e 99';
	EXEC INCLUI_ERRCNABR '707', '0327', '[Entrada Rejeitada] Data de emisso do ttulo invlida';
	EXEC INCLUI_ERRCNABR '707', '0328', '[Entrada Rejeitada] Seu nmero no informado';
	EXEC INCLUI_ERRCNABR '707', '0329', '[Entrada Rejeitada] CEP  igual a espao ou zeros; ou no numrico';
	EXEC INCLUI_ERRCNABR '707', '0330', '[Entrada Rejeitada] Valor do ttulo no numrico ou invlido';
	EXEC INCLUI_ERRCNABR '707', '0336', '[Entrada Rejeitada] Valor de permanncia no numrico';
	EXEC INCLUI_ERRCNABR '707', '0337', '[Entrada Rejeitada] Valor de permanncia inconsistente, pois, dentro de um ms, ser maior que o valor do ttulo';
	EXEC INCLUI_ERRCNABR '707', '0338', '[Entrada Rejeitada] Valor de desconto/abatimento no numrico ou invlido';
	EXEC INCLUI_ERRCNABR '707', '0339', '[Entrada Rejeitada] Valor de abatimento no numrico';
	EXEC INCLUI_ERRCNABR '707', '0342', '[Entrada Rejeitada] Ttulo j existente em nossos registros. Nosso nmero no aceito';
	EXEC INCLUI_ERRCNABR '707', '0343', '[Entrada Rejeitada] Ttulo enviado em duplicidade nesse movimento';
	EXEC INCLUI_ERRCNABR '707', '0344', '[Entrada Rejeitada] Ttulo zerado ou em branco; ou no numrico na remessa';
	EXEC INCLUI_ERRCNABR '707', '0346', '[Entrada Rejeitada] Ttulo enviado fora da faixa de Nosso Nmero, estipulada para o cliente.';
	EXEC INCLUI_ERRCNABR '707', '0351', '[Entrada Rejeitada] Tipo/Nmero de Inscrio Sacador/Avalista Invlido';
	EXEC INCLUI_ERRCNABR '707', '0353', '[Entrada Rejeitada] Prazo de vencimento do ttulo excede ao da contratao';
	EXEC INCLUI_ERRCNABR '707', '0354', '[Entrada Rejeitada] Banco informado no  nosso correspondente 140-142';
	EXEC INCLUI_ERRCNABR '707', '0355', '[Entrada Rejeitada] Banco correspondente informado no cobra este CEP ou no possui faixas de CEP cadastradas';
	EXEC INCLUI_ERRCNABR '707', '0356', '[Entrada Rejeitada] Nosso nmero no correspondente no foi informado';
	EXEC INCLUI_ERRCNABR '707', '0357', '[Entrada Rejeitada] Remessa contendo duas instrues incompatveis  no protestar e dias de protesto ou prazo para protesto invlido.';
	EXEC INCLUI_ERRCNABR '707', '0358', '[Entrada Rejeitada] Entrada Rejeitada  Reprovado no Represamento para Anlise';
	EXEC INCLUI_ERRCNABR '707', '0360', '[Entrada Rejeitada] CNPJ/CPF do sacado invlido  ttulo recusado';
	EXEC INCLUI_ERRCNABR '707', '0387', '[Entrada Rejeitada] Excede Prazo mximo entre emisso e vencimento';
	EXEC INCLUI_ERRCNABR '707', '0399', '[Entrada Rejeitada] Ttulo no acatado pelo banco  entrar em contato Gerente da conta';
	EXEC INCLUI_ERRCNABR '707', '03AE', '[Entrada Rejeitada] Ttulo no possui abatimento';
	EXEC INCLUI_ERRCNABR '707', '03AG', '[Entrada Rejeitada] Movimento no permitido  Ttulo  vista ou contra apresentao';
	EXEC INCLUI_ERRCNABR '707', '03AK', '[Entrada Rejeitada] Ttulo pertence a outro cliente';
	EXEC INCLUI_ERRCNABR '707', '03AL', '[Entrada Rejeitada] Sacado impedido de entrar nesta cobrana';
	EXEC INCLUI_ERRCNABR '707', '03AY', '[Entrada Rejeitada] Ttulo deve estar em aberto e vencido para acatar protesto';
	EXEC INCLUI_ERRCNABR '707', '03BC', '[Entrada Rejeitada] Anlise gerencial-sacado invlido p/operao crdito';
	EXEC INCLUI_ERRCNABR '707', '03BD', '[Entrada Rejeitada] Anlise gerencial-sacado inadimplente';
	EXEC INCLUI_ERRCNABR '707', '03BE', '[Entrada Rejeitada] Anlise gerencial-sacado difere do exigido';
	EXEC INCLUI_ERRCNABR '707', '03BF', '[Entrada Rejeitada] Anlise gerencial-vencto excede vencto da operao de crdito';
	EXEC INCLUI_ERRCNABR '707', '03BG', '[Entrada Rejeitada] Anlise gerencial-sacado com baixa liquidez';
	EXEC INCLUI_ERRCNABR '707', '03BH', '[Entrada Rejeitada] Anlise gerencial-sacado excede concentrao';
	EXEC INCLUI_ERRCNABR '707', '03CB', '[Entrada Rejeitada] Ttulo possui protesto efetivado/a efetivar hoje';
	EXEC INCLUI_ERRCNABR '707', '03CC', '[Entrada Rejeitada] Valor de iof incompatvel com a espcie documento';
	EXEC INCLUI_ERRCNABR '707', '03CD', '[Entrada Rejeitada] Efetivao de protesto sem agenda vlida';
	EXEC INCLUI_ERRCNABR '707', '03CE', '[Entrada Rejeitada] Ttulo no aceito - pessoa fsica';
	EXEC INCLUI_ERRCNABR '707', '03CF', '[Entrada Rejeitada] Excede prazo mximo da entrada ao vencimento';
	EXEC INCLUI_ERRCNABR '707', '03CG', '[Entrada Rejeitada] Ttulo no aceito  por anlise gerencial';
	EXEC INCLUI_ERRCNABR '707', '03CH', '[Entrada Rejeitada] Ttulo em espera  em anlise pelo banco';
	EXEC INCLUI_ERRCNABR '707', '03CJ', '[Entrada Rejeitada] Anlise gerencial-vencto do titulo abaixo przcurto';
	EXEC INCLUI_ERRCNABR '707', '03CK', '[Entrada Rejeitada] Anlise gerencial-vencto do titulo abaixo przlongo';
	EXEC INCLUI_ERRCNABR '707', '03CS', '[Entrada Rejeitada] Ttulo rejeitado pela checagem de duplicatas';
	EXEC INCLUI_ERRCNABR '707', '03CT', '[Entrada Rejeitada] Ttulo j baixado';
	EXEC INCLUI_ERRCNABR '707', '03DA', '[Entrada Rejeitada] Anlise gerencial  Entrada de Ttulo Descontado com limite cancelado';
	EXEC INCLUI_ERRCNABR '707', '03DB', '[Entrada Rejeitada] Anlise gerencial  Entrada de Ttulo Descontado com limite vencido';
	EXEC INCLUI_ERRCNABR '707', '03DC', '[Entrada Rejeitada] Anlise gerencial - cedente com limite cancelado';
	EXEC INCLUI_ERRCNABR '707', '03DD', '[Entrada Rejeitada] Anlise gerencial  cedente  sacado e teve seu limite cancelado';
	EXEC INCLUI_ERRCNABR '707', '03DE', '[Entrada Rejeitada] Anlise gerencial - apontamento no Serasa';
	EXEC INCLUI_ERRCNABR '707', '03DG', '[Entrada Rejeitada] Endereo sacador/avalista no informado';
	EXEC INCLUI_ERRCNABR '707', '03DH', '[Entrada Rejeitada] Cep do sacador/avalista no informado';
	EXEC INCLUI_ERRCNABR '707', '03DI', '[Entrada Rejeitada] Cidade do sacador/avalista no informado';
	EXEC INCLUI_ERRCNABR '707', '03DJ', '[Entrada Rejeitada] Estado do sacador/avalista invlido ou n informado';
	EXEC INCLUI_ERRCNABR '707', '03DM', '[Entrada Rejeitada] Cliente sem Cdigo de Flash cadastrado no cobrador';
	EXEC INCLUI_ERRCNABR '707', '03DN', '[Entrada Rejeitada] Ttulo Descontado com Prazo ZERO  Recusado';
	EXEC INCLUI_ERRCNABR '707', '03DO', '[Entrada Rejeitada] Ttulo em Prejuzo';
	EXEC INCLUI_ERRCNABR '707', '03DP', '[Entrada Rejeitada] Data de Referncia menor que a Data de Emisso do Ttulo';
	EXEC INCLUI_ERRCNABR '707', '03DT', '[Entrada Rejeitada] Nosso Nmero do Correspondente no deve ser informado';
	EXEC INCLUI_ERRCNABR '707', '03EB', '[Entrada Rejeitada] HSBC no aceita endereo de sacado com mais de 38 caracteres';
	EXEC INCLUI_ERRCNABR '707', '1505', '[Baixa Rejeitada] Solicitao de baixa para ttulo j baixado ou liquidado';
	EXEC INCLUI_ERRCNABR '707', '1506', '[Baixa Rejeitada] Solicitao de baixa para ttulo no registrado no sistema';
	EXEC INCLUI_ERRCNABR '707', '1508', '[Baixa Rejeitada] Solicitao de baixa para ttulo em float';
	EXEC INCLUI_ERRCNABR '707', '1605', '[Instruo Rejeitada] Solicitao de baixa para ttulo j baixado ou liquidado';
	EXEC INCLUI_ERRCNABR '707', '1604', '[Instruo Rejeitada] Data de Vencimento no numrica ou invlida';
	EXEC INCLUI_ERRCNABR '707', '1614', '[Instruo Rejeitada] Registro em duplicidade';
	EXEC INCLUI_ERRCNABR '707', '1620', '[Instruo Rejeitada] Campo livre informado';
	EXEC INCLUI_ERRCNABR '707', '1621', '[Instruo Rejeitada] Ttulo no registrado no sistema';
	EXEC INCLUI_ERRCNABR '707', '1622', '[Instruo Rejeitada] Ttulo baixada ou liquidado';
	EXEC INCLUI_ERRCNABR '707', '1627', '[Instruo Rejeitada] Instruo no aceita, pr no ter sido emitida ordem de protesto ao cartrio';
	EXEC INCLUI_ERRCNABR '707', '1628', '[Instruo Rejeitada] Ttulo tem instruo de cartrio ativa';
	EXEC INCLUI_ERRCNABR '707', '1629', '[Instruo Rejeitada] Ttulo no tem instruo de cartrio ativa';
	EXEC INCLUI_ERRCNABR '707', '1630', '[Instruo Rejeitada] Existe instruo de no protestar, ativa para o ttulo';
	EXEC INCLUI_ERRCNABR '707', '1637', '[Instruo Rejeitada] Ttulo Descontado - Instruo no permitida para a carteira';
	EXEC INCLUI_ERRCNABR '707', '1638', '[Instruo Rejeitada] Valor do abatimento no numrico ou maior que a soma do valor do ttulo + pemanncia + multa';
	EXEC INCLUI_ERRCNABR '707', '1639', '[Instruo Rejeitada] Ttulo em cartrio';
	EXEC INCLUI_ERRCNABR '707', '1640', '[Instruo Rejeitada] Instruo recusada - cobrana vinculada / caucionada';
	EXEC INCLUI_ERRCNABR '707', '1699', '[Instruo Rejeitada] Ocorrncia desconhecida na remessa';	
	
--Banco Factoring
	EXEC INCLUI_ERRCNABR '888', '0000', 'Instruo aprovada';
	EXEC INCLUI_ERRCNABR '888', '0002', 'Cdigo do registro de detalhe invlido';
	EXEC INCLUI_ERRCNABR '888', '0003', 'Cdigo de ocorrncia invlido';
	EXEC INCLUI_ERRCNABR '888', '0004', 'Cdigo de ocorrncia no permitida para esta carteira';
	EXEC INCLUI_ERRCNABR '888', '0005', 'Cdigo de ocorrncia no numrico';
	EXEC INCLUI_ERRCNABR '888', '0007', 'Cdigo da Empresa Invlido';
	EXEC INCLUI_ERRCNABR '888', '0008', 'Nosso nmero invlido';
	EXEC INCLUI_ERRCNABR '888', '0009', 'Nosso nmero duplicado';
	EXEC INCLUI_ERRCNABR '888', '0010', 'Carteira Invlida';
	EXEC INCLUI_ERRCNABR '888', '0016', 'Data de vencimento invlida';
	EXEC INCLUI_ERRCNABR '888', '0021', 'Espcie do ttulo invlida';
	EXEC INCLUI_ERRCNABR '888', '0022', 'Espcie do ttulo no permitida para a carteira';
	EXEC INCLUI_ERRCNABR '888', '0024', 'Data de emisso invlida';
	EXEC INCLUI_ERRCNABR '888', '0029', 'Valor do desconto invlido';
	EXEC INCLUI_ERRCNABR '888', '0031', 'Concesso de desconto j existente';
	EXEC INCLUI_ERRCNABR '888', '0033', 'Valor do abatimento invlido';
	EXEC INCLUI_ERRCNABR '888', '0034', 'Concesso de abatimento j existente';
	EXEC INCLUI_ERRCNABR '888', '0038', 'Prazo para protesto invlido';
	EXEC INCLUI_ERRCNABR '888', '0039', 'Pedido de protesto no permitido para o ttulo';
	EXEC INCLUI_ERRCNABR '888', '0040', 'Ttulo com ordem de protesto emitido';
	EXEC INCLUI_ERRCNABR '888', '0041', 'Pedido de cancelamento/sustao para ttulo sem instruo de protesto';
	EXEC INCLUI_ERRCNABR '888', '0060', 'Movimento para ttulo no cadastrado';
	EXEC INCLUI_ERRCNABR '888', '0101', 'CGC ou CPF invlido *';
	EXEC INCLUI_ERRCNABR '888', '0102', 'CEP Invlido *';
	EXEC INCLUI_ERRCNABR '888', '0103', 'Nmero do ttulo no invlido *';
	EXEC INCLUI_ERRCNABR '888', '0104', 'Valor do ttulo no informado *';
	EXEC INCLUI_ERRCNABR '888', '0105', 'Data de emisso no informada *';
	EXEC INCLUI_ERRCNABR '888', '0106', 'Data de vencimento invlida *';
	EXEC INCLUI_ERRCNABR '888', '0107', 'Espcie do ttulo invlida *';
	EXEC INCLUI_ERRCNABR '888', '0108', 'Nosso nmero invlido *';
	EXEC INCLUI_ERRCNABR '888', '0109', 'Cdigo do registro de detalhe invlido *';
	EXEC INCLUI_ERRCNABR '888', '0110', 'Cdigo de ocorrncia invlido *';
	EXEC INCLUI_ERRCNABR '888', '0111', 'Sacado com ttulo protestado *';
	EXEC INCLUI_ERRCNABR '888', '0112', 'Sacado com cheque devolvido *';
	EXEC INCLUI_ERRCNABR '888', '0113', 'Sacado com limite de crdito ultrapassado *';
	EXEC INCLUI_ERRCNABR '888', '0114', 'Ttulo com prazo longo *';
	EXEC INCLUI_ERRCNABR '888', '0115', 'Cedente com limite de crdito ultrapassado *';
	EXEC INCLUI_ERRCNABR '888', '0116', 'Nome do sacado invlido *';
	EXEC INCLUI_ERRCNABR '888', '0150', 'Titulo recusado na operao *';
	EXEC INCLUI_ERRCNABR '888', '9001', 'Nome do arquivo invlido *';
	EXEC INCLUI_ERRCNABR '888', '9002', 'Identificao do registro header invlido *';
	EXEC INCLUI_ERRCNABR '888', '9003', 'Cdigo de servio invlido *';
	EXEC INCLUI_ERRCNABR '888', '9004', 'Tamanho do registro invlido *';
	EXEC INCLUI_ERRCNABR '888', '9005', 'Cdigo do Cliente no header invlido *';
	EXEC INCLUI_ERRCNABR '888', '9006', 'Data da gravao invlida *';
	EXEC INCLUI_ERRCNABR '888', '9007', 'Sequencial do registro header invlido *';
	EXEC INCLUI_ERRCNABR '888', '9008', 'Cdigo do cliente no registro detalhe invlido *';
	EXEC INCLUI_ERRCNABR '888', '9009', 'Sequencial do registro detalhe invlido *';
	EXEC INCLUI_ERRCNABR '888', '9010', 'Sequencial do registro trailler invlido *';
	EXEC INCLUI_ERRCNABR '888', '9011', 'Registro invlido *';
	EXEC INCLUI_ERRCNABR '888', '9012', 'Cdigo de barras invlido *';
	EXEC INCLUI_ERRCNABR '888', '9013', 'Ttulo j existe com o cdigo informado *';	
-- VERSAO --
EXEC ATUVEROBJ 'INCLUI_ERRCNABR','5.85.xxx';
GO